<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://cohhe.com/
 * @since             1.0
 * @package           db_func
 *
 * @wordbress-plugin
 * Plugin Name:       Directory builder
 * Plugin URI:        https://cohhe.com/
 * Description:       Directory builder provides listing functionality for your theme.
 * Version:           1.3.6
 * Author:            Cohhe
 * Author URI:        https://cohhe.com/
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       directory-builder
 * Domain Path:       /languages
 */


if ( ! defined( 'ABSPATH' ) ) exit; // If this file is called directly, abort.

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-db-functionality-activator.php
 */
function db_activate_db_func() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-db-functionality-activator.php';
	db_func_Activator::db_activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-db-functionality-deactivator.php
 */
function db_deactivate_db_func() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-db-functionality-deactivator.php';
	db_func_Deactivator::db_deactivate();
}

register_activation_hook( __FILE__, 'db_activate_db_func' );
register_deactivation_hook( __FILE__, 'db_deactivate_db_func' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
define('DB_PLUGIN', plugin_dir_path( __FILE__ ));
define('DB_PLUGIN_URI', plugin_dir_url( __FILE__ ));
define('DB_PLUGIN_DASH_PAGE', 'directory-builder-dashboard');
define('DB_PLUGIN_FIELD_PAGE', 'directory-builder-fields');
define('DB_PLUGIN_SETTING_PAGE', 'directory-builder-settings');
define('DB_PLUGIN_PACKAGE_PAGE', 'directory-builder-packages');
define('DB_PLUGIN_THEME_PAGE', 'directory-builder-themes');

define('DB_PLUGIN_DASH_PAGE_URL', get_admin_url() . 'admin.php?page=' . DB_PLUGIN_DASH_PAGE);
define('DB_PLUGIN_FIELD_PAGE_URL', get_admin_url() . 'admin.php?page=' . DB_PLUGIN_FIELD_PAGE);
define('DB_PLUGIN_SETTING_PAGE_URL', get_admin_url() . 'admin.php?page=' . DB_PLUGIN_SETTING_PAGE);
define('DB_PLUGIN_PACKAGE_PAGE_URL', get_admin_url() . 'admin.php?page=' . DB_PLUGIN_PACKAGE_PAGE);
define('DB_PLUGIN_THEME_PAGE_URL', get_admin_url() . 'admin.php?page=' . DB_PLUGIN_THEME_PAGE);

require plugin_dir_path( __FILE__ ) . 'includes/class-db-functionality.php';


/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_db_func() {

	$plugin = new db_func();
	$plugin->db_run();

}
run_db_func();

function db_register_manager_menu_page() {
	add_menu_page(
		__( 'Directory', 'directory-builder' ),
		__( 'Directory', 'directory-builder' ),
		'manage_options',
		DB_PLUGIN_DASH_PAGE,
		'',
		'dashicons-location',
		26
	);

	add_submenu_page(
		DB_PLUGIN_DASH_PAGE,
		__('Dashboard', 'directory-builder'),
		__('Dashboard', 'directory-builder'),
		'manage_options',
		DB_PLUGIN_DASH_PAGE,
		'db_main_html'
	);

	add_submenu_page(
		DB_PLUGIN_DASH_PAGE,
		__('Custom fields', 'directory-builder'),
		__('Custom fields', 'directory-builder'),
		'manage_options',
		DB_PLUGIN_FIELD_PAGE,
		'db_field_html'
	);

	add_submenu_page(
		DB_PLUGIN_DASH_PAGE,
		__('Packages', 'directory-builder'),
		__('Packages', 'directory-builder'),
		'manage_options',
		DB_PLUGIN_PACKAGE_PAGE,
		'db_package_html'
	);

	add_submenu_page(
		DB_PLUGIN_DASH_PAGE,
		__('Themes', 'directory-builder'),
		__('Themes', 'directory-builder'),
		'manage_options',
		DB_PLUGIN_THEME_PAGE,
		'db_theme_html'
	);

	add_submenu_page(
		DB_PLUGIN_DASH_PAGE,
		__('Settings', 'directory-builder'),
		__('Settings', 'directory-builder'),
		'manage_options',
		DB_PLUGIN_SETTING_PAGE,
		'db_settings_html'
	);

}
add_action( 'admin_menu', 'db_register_manager_menu_page' );

add_action( 'init', 'vh_create_post_type' );
function vh_create_post_type() {
	$main_settings = get_option( 'db_main_settings', array());

	register_post_type( 'listings',
		array(
		'labels' => array(
			'name' => __( 'Listings', "directory-builder" ),
			'singular_name' => __( 'Listing', "directory-builder" ),
			'add_new' => 'Add New Listing',
			'add_new_item' => 'Add New Listing',
			'edit_item' => 'Edit Listing',
			'new_item' => 'New Listing',
			'view_item' => 'View listing',
		),
		'taxonomies' => array('listing_category'),
		'rewrite' => array('slug'=>$main_settings['directory_slug'],'with_front'=>false),
		'public' => true,
		'has_archive' => true,
		'supports' => array(
			'title',
			'editor',
			'revisions',
			'thumbnail',
			'comments',
			'excerpt'
			),
		'menu_icon' => 'dashicons-location',
		'menu_position' => '25'
		)
	);

	register_taxonomy( 'listing_category',
		array (
			0 => 'listings',
		),
		array( 
			'hierarchical' => true, 
			'label' => 'Listing categories',
			'show_ui' => true,
			'query_var' => true,
			'rewrite' => array('slug' => $main_settings['category_slug'], 'with_front'=>false),
			'singular_label' => 'Listing category'
		) 
	);
}

function db_available_icons() {
	return array( 'dbicon-heart', 'dbicon-heart-empty', 'dbicon-star', 'dbicon-star-empty', 'dbicon-star-half', 'dbicon-mail', 'dbicon-music', 'dbicon-glass', 'dbicon-video', 'dbicon-picture', 'dbicon-ok-circled2', 'dbicon-ok-circled', 'dbicon-ok', 'dbicon-users', 'dbicon-cancel', 'dbicon-cancel-circled', 'dbicon-cancel-circled2', 'dbicon-home', 'dbicon-link', 'dbicon-attach', 'dbicon-lock', 'dbicon-eye', 'dbicon-eye-off', 'dbicon-tag', 'dbicon-pin', 'dbicon-thumbs-down', 'dbicon-thumbs-up', 'dbicon-edit', 'dbicon-print', 'dbicon-bell', 'dbicon-attention', 'dbicon-location', 'dbicon-trash-empty', 'dbicon-phone', 'dbicon-basket', 'dbicon-calendar', 'dbicon-volume-up', 'dbicon-headphones', 'dbicon-clock', 'dbicon-target', 'dbicon-globe', 'dbicon-cloud', 'dbicon-flash', 'dbicon-umbrella', 'dbicon-flight', 'dbicon-leaf', 'dbicon-font', 'dbicon-bold', 'dbicon-scissors', 'dbicon-briefcase', 'dbicon-road', 'dbicon-barcode', 'dbicon-book', 'dbicon-truck', 'dbicon-key', 'dbicon-credit-card', 'dbicon-floppy', 'dbicon-feather', 'dbicon-address', 'dbicon-map', 'dbicon-alert', 'dbicon-tools', 'dbicon-bag', 'dbicon-mic-1', 'dbicon-adjust', 'dbicon-light-up', 'dbicon-globe-1', 'dbicon-water', 'dbicon-droplet', 'dbicon-gauge', 'dbicon-link-ext', 'dbicon-phone-squared', 'dbicon-rss', 'dbicon-docs', 'dbicon-mail-alt', 'dbicon-comment-empty', 'dbicon-chat-empty', 'dbicon-lightbulb', 'dbicon-stethoscope', 'dbicon-bell-alt', 'dbicon-coffee', 'dbicon-food', 'dbicon-building', 'dbicon-hospital', 'dbicon-ambulance', 'dbicon-medkit', 'dbicon-plus-squared', 'dbicon-desktop', 'dbicon-laptop', 'dbicon-tablet', 'dbicon-mobile', 'dbicon-smile', 'dbicon-frown', 'dbicon-meh', 'dbicon-gamepad', 'dbicon-keyboard', 'dbicon-flag-empty', 'dbicon-star-half-alt', 'dbicon-direction', 'dbicon-unlink', 'dbicon-info', 'dbicon-attention-alt', 'dbicon-mic', 'dbicon-mute', 'dbicon-lock-open-alt', 'dbicon-ticket', 'dbicon-ok-squared', 'dbicon-pencil-squared', 'dbicon-compass', 'dbicon-euro', 'dbicon-pound', 'dbicon-dollar', 'dbicon-rupee', 'dbicon-yen', 'dbicon-rouble', 'dbicon-won', 'dbicon-bitcoin', 'dbicon-female', 'dbicon-male', 'dbicon-sun', 'dbicon-moon', 'dbicon-wheelchair', 'dbicon-try', 'dbicon-plus-squared-alt', 'dbicon-graduation-cap', 'dbicon-language', 'dbicon-child', 'dbicon-paw', 'dbicon-spoon', 'dbicon-cubes', 'dbicon-cab', 'dbicon-taxi', 'dbicon-paper-plane', 'dbicon-paper-plane-empty', 'dbicon-sliders', 'dbicon-share', 'dbicon-share-squared', 'dbicon-cc-visa', 'dbicon-cc-mastercard', 'dbicon-cc-discover', 'dbicon-cc-amex', 'dbicon-cc-paypal', 'dbicon-cc-stripe', 'dbicon-bell-off', 'dbicon-bell-off-empty', 'dbicon-trash', 'dbicon-bicycle', 'dbicon-bus', 'dbicon-shekel', 'dbicon-ship', 'dbicon-motorcycle', 'dbicon-heartbeat', 'dbicon-bed', 'dbicon-viacoin', 'dbicon-train', 'dbicon-subway', 'dbicon-cc-jcb', 'dbicon-cc-diners-club', 'dbicon-hourglass-3', 'dbicon-tripadvisor', 'dbicon-calendar-plus-o', 'dbicon-calendar-minus-o', 'dbicon-calendar-times-o', 'dbicon-calendar-check-o', 'dbicon-address-card', 'dbicon-address-card-o', 'dbicon-thermometer-3', 'dbicon-thermometer-0', 'dbicon-shower', 'dbicon-bath', 'dbicon-podcast', 'wl-health', 'wl-catering', 'wl-beauty', 'wl-finances', 'wl-plants' );
}


add_action ( 'listing_category_add_form_fields', 'db_add_category_fields');
function db_add_category_fields( $tag ) {
	$cat_meta = array();
	?>
	<div class="form-field term-default-image-wrap">
		<label for="tag-default-image">Default listing image</label>
		<div class="db-image-container">
			<?php echo (isset($cat_meta['tag-default-image'])&&$cat_meta['tag-default-image']!=''?'<img src="'.$cat_meta['tag-default-image'].'" alt="">':''); ?>
		</div>
		<input type="hidden" class="upload-field-value" name="tag-default-image" value="<?php echo (isset($cat_meta['tag-default-image'])&&$cat_meta['tag-default-image']!=''?$cat_meta['tag-default-image']:''); ?>">
		<input type="button" id="tag-default-image" class="db-image-upload" value="Upload image">
		<input type="button" class="db-image-delete" value="Delete image" <?php echo (!isset($cat_meta['tag-default-image'])||$cat_meta['tag-default-image']==''?'style="display: none;"':''); ?>>
		<p>Choose a default "No image".</p>
	</div>
	<div class="form-field term-category-icon-wrap">
		<label for="tag-category-icon">Category icon</label>
		<?php echo __('Icon selected: ', 'directory-builder').'<i class="db-active-category-icon "></i>'; ?>
		<div class="clearfix"></div>
		<input type="hidden" name="tag-category-icon" value="<?php echo (isset($cat_meta['tag-category-icon'])&&$cat_meta['tag-category-icon']!=''?$cat_meta['tag-category-icon']:''); ?>">
		<input type="button" id="db-choose-category-icon" value="Choose icon">
		<div class="db-category-icon-dialog main-card">
			<div class="db-category-icon-dialog-inner">
				<span class="db-category-icon-dialog-close dbicon-cancel"></span>
				<?php
					$icons = db_available_icons();
					foreach ($icons as $icon_value) {
						echo '<i class="db-category-icon-select '.$icon_value.'" data-id="'.$icon_value.'"></i>';
					}
				?>
			</div>
		</div>
		<p>Choose category icon.</p>
	</div>
	<div class="form-field term-category-icon-wrap">
		<label for="tag-category-color">Category color</label>
		<input type="text" id="db-choose-category-color" name="tag-category-color" value="<?php echo (isset($cat_meta['tag-category-color'])&&$cat_meta['tag-category-color']!=''?$cat_meta['tag-category-color']:''); ?>">
	</div>
	<?php
}

add_action ( 'listing_category_edit_form_fields', 'db_edit_category_fields');
function db_edit_category_fields( $tag ) {
	$t_id = $tag->term_id;
	$cat_meta = get_option( "listing_category_$t_id");
	?>
	<tr class="form-field term-default-image-wrap">
		<th scope="row"><label for="description">Default listing image</label></th>
		<td>
			<div class="db-image-container">
				<?php echo (isset($cat_meta['tag-default-image'])&&$cat_meta['tag-default-image']!=''?'<img src="'.$cat_meta['tag-default-image'].'" alt="">':''); ?>
			</div>
			<input type="hidden" class="upload-field-value" name="tag-default-image" value="<?php echo (isset($cat_meta['tag-default-image'])&&$cat_meta['tag-default-image']!=''?$cat_meta['tag-default-image']:''); ?>">
			<input type="button" id="tag-default-image" class="db-image-upload" value="Upload image">
			<input type="button" class="db-image-delete" value="Delete image" <?php echo (!isset($cat_meta['tag-default-image'])||$cat_meta['tag-default-image']==''?'style="display: none;"':''); ?>>
			<p class="description">Choose a default "No image".</p>
		</td>
	</tr>
	<tr class="form-field term-category-icon-wrap">
		<th scope="row"><label for="description">Category icon</label></th>
		<td>
			<?php echo __('Icon selected: ', 'directory-builder').'<i class="db-active-category-icon '.(isset($cat_meta['tag-category-icon'])?$cat_meta['tag-category-icon']:'').'"></i>'; ?>
			<div class="clearfix"></div>
			<input type="hidden" name="tag-category-icon" value="<?php echo (isset($cat_meta['tag-category-icon'])&&$cat_meta['tag-category-icon']!=''?$cat_meta['tag-category-icon']:''); ?>">
			<input type="button" id="db-choose-category-icon" value="Choose icon">
			<div class="db-category-icon-dialog main-card">
				<div class="db-category-icon-dialog-inner">
					<span class="db-category-icon-dialog-close dbicon-cancel"></span>
					<?php
						$icons = db_available_icons();
						foreach ($icons as $icon_value) {
							echo '<i class="db-category-icon-select '.$icon_value.'" data-id="'.$icon_value.'"></i>';
						}
					?>
				</div>
			</div>
			<p>Choose category icon.</p>
		</td>
	</tr>
	<tr class="form-field term-category-icon-wrap">
		<th scope="row"><label for="description">Category color</label></th>
		<td>
			<input type="text" id="db-choose-category-color" name="tag-category-color" value="<?php echo (isset($cat_meta['tag-category-color'])&&$cat_meta['tag-category-color']!=''?$cat_meta['tag-category-color']:''); ?>">
		</td>
	</tr>
	<?php
}

add_action ( 'edited_listing_category', 'db_save_category_fields');
add_action ( 'create_listing_category', 'db_save_category_fields');
function db_save_category_fields( $term_id ) {
	$saved_options = 0;
	$t_id = $term_id;
	$cat_meta = get_option( "listing_category_$t_id");
	if ( isset( $_POST['tag-default-image'] ) ) {
		$cat_meta['tag-default-image'] = esc_url($_POST['tag-default-image']);
		$saved_options++;
	}

	if ( isset( $_POST['tag-category-icon'] ) ) {
		$cat_meta['tag-category-icon'] = sanitize_key($_POST['tag-category-icon']);
		$saved_options++;
	}

	if ( isset( $_POST['tag-category-color'] ) ) {
		$cat_meta['tag-category-color'] = sanitize_text_field($_POST['tag-category-color']);
		$saved_options++;
	}
	
	if ( $saved_options > 0 ) {
		update_option( "listing_category_$t_id", $cat_meta );
	}
}

function db_main_html() {
	if ( !current_user_can('manage_options') )  {
		wp_die( __('You do not have sufficient permissions to access this page.', 'directory-builder') );
	}
	?>
	<div class="db-main-wrapper container-fluid" id="db-main-wrapper">
		<div class="db-main-content main-card">
			<div class="db-box-title">
				<h3 class="db-main-title">Custom templates</h3>
			</div>
			<p>There are 3 destinations for templates, the default one in the plugin, inside your theme and custom ones saved in your WordPress <b>wp-content/db-plugin-themes</b> directory. The default theme inside the plugin is always the newest one and gets updated along with the plugin updates. The theme inside a theme directory is updated eather by you or your theme author. The custom themes uploaded via a zip file is updated and maintained by the custom theme author.</p>
			<br>
			<p>A valid custom theme counts as a <b>.zip</b> file containing <b>theme_data.json</b>, if you want to create a custom theme we suggest you to copy the default theme that's located in the plugin folder(<b>directory-builder/template</b>) and rename it into an unique name. From there you can start editing the template files by adding or removing information. Next step would be to edit the themes <b>theme_data.json</b> file that contains information about your custom theme like version, author and description. The last and final step is to archive your new template folder into a <b>.zip</b> file.</p>
		</div>
		<div class="db-main-content main-card db-m-t-20">
			<div class="db-box-title">
				<h3 class="db-main-title">Available shortcodes</h3>
			</div>
			<div class="db-row">
				<div class="db-row-group clearfix">
					<span class="db-row-label col-sm-2"><b>[directory_listings]</b></span>
					<div class="col-sm-10">
						This shortcode is going to show listing search with a map, you can control search settings at the Dashboard > Directory > Settings
					</div>
				</div>
			</div>
			<div class="db-row">
				<div class="db-row-group clearfix">
					<span class="db-row-label col-sm-2"><b>[directory_add_listing]</b></span>
					<div class="col-sm-10">
						This shortcode is going to add the add listing form so your users can add their listings to your page!
					</div>
				</div>
			</div>
			<div class="db-row">
				<div class="db-row-group clearfix">
					<span class="db-row-label col-sm-2"><b>[directory_account]</b></span>
					<div class="col-sm-10">
						This shortcode is going to show all of the user listings with the ability to edit and/or delete them.
					</div>
				</div>
			</div>
			<div class="db-row">
				<div class="db-row-group clearfix">
					<span class="db-row-label col-sm-2"><b>[directory_login]</b></span>
					<div class="col-sm-10">
						This shortcode is going to show the login form so your users can login to your page.
					</div>
				</div>
			</div>
			<div class="db-row">
				<div class="db-row-group clearfix">
					<span class="db-row-label col-sm-2"><b>[directory_register]</b></span>
					<div class="col-sm-10">
						This shortcode is going to show the register form so your users can register and start adding their listings!
					</div>
				</div>
			</div>
		</div>
	</div>

	<?php
}

function db_field_html() {
	if ( !current_user_can('manage_options') )  {
		wp_die( __('You do not have sufficient permissions to access this page.', 'directory-builder') );
	}
	?>
	<div class="db-main-wrapper container-fluid" id="db-main-wrapper">
		<div class="db-main-content main-card">
			<?php if ( !isset($_GET['field_type']) && !isset($_GET['field_id']) ) { ?>
				<a href="javascript:void(0)" class="db-add-new-field db-button db-primary-button">Add new</a>
				<table class="table table-striped table-hover">
					<thead>
						<tr>
							<th style="width: 5%;">Order</th>
							<th style="width: 65%;">Name</th>
							<th style="width: 15%;">Type</th>
							<th style="width: 15%;">Action</th>
						</tr>
					</thead>
					<tbody>
						<?php
						global $wpdb;
						$field_list = $wpdb->get_results('SELECT * FROM '.$wpdb->prefix.'directory_fields ORDER BY field_order, ID ASC');
						if ( !empty($field_list) ) {
							foreach ($field_list as $field_value) {
								$field_settings = json_decode($field_value->field_settings, true);
								$is_child = (isset($field_settings['child'])&&$field_settings['child']=='true'?'db-child-field':'');
								$disabled_settings = (isset($field_settings['disabled'])?explode(',', $field_settings['disabled']):array());

								echo '
								<tr class="'.$is_child.'">
									<td class="db-field-order">'.($is_child==''?$field_settings['display_order']:'').'</td>
									<td class="db-field-name">'.$field_settings['admin_title'].'</td>
									<td class="db-custom-field-type">'.$field_settings['field_type'].'</td>
									<td class="db-field-actions">';
										if ( !in_array('edit', $disabled_settings) ) {
											echo '<a href="'.DB_PLUGIN_FIELD_PAGE_URL.'&field_id='.$field_value->ID.'" class="db-edit-field">Edit</a>';
										}
										echo ' ';
										if ( !in_array('delete', $disabled_settings) ) {
											echo '<a href="javascript:void(0)" class="db-delete-field" data-id="'.$field_value->ID.'">Delete</a>';
										}
									echo '
									</td>
								</tr>';
							}
						}
						?>
					</tbody>
				</table>
				<div class="db-custom-field-dialog main-card" style="display: none;">
					<div class="db-field-row clearfix">
						<label class="field-label">Field type</label>
						<select class="db-field-type">
							<option value="text">Text</option>
							<option value="number">Number</option>
							<option value="textarea">Textarea</option>
							<option value="checkbox">Checkbox</option>
							<option value="radio">Radio</option>
							<option value="select">Select</option>
							<option value="multi-select">Multi select</option>
							<option value="url">URL</option>
							<option value="file-upload">File upload</option>
							<option value="date">Date</option>
							<option value="time">Time</option>
							<option value="email">Email</option>
							<option value="html">HTML</option>
							<option value="hoursofoperation">Hours of operation</option>
						</select>
					</div>
					<a href="javascript:void(0)" class="db-proceed-field db-button db-primary-button">Proceed</a>
				</div>
				<div class="db-dialog-overlay" style="display: none;"></div>
			<?php } else if ( isset($_GET['field_type']) || isset($_GET['field_id']) ) {
				$field_settings = array();
				$disabled_settings = array();
				$is_child = false;
				if ( isset($_GET['field_id']) ) {
					global $wpdb;
					$field_data = $wpdb->get_results('SELECT * FROM '.$wpdb->prefix.'directory_fields WHERE ID="'.intval($_GET['field_id']).'"');
					$field_settings = json_decode($field_data['0']->field_settings, true);
					$disabled_settings = (isset($field_settings['disabled'])?explode(',', $field_settings['disabled']):array());
					$is_child = (isset($field_settings['child'])&&$field_settings['child']=='true'?true:false);
				}
				$field_type = (isset($_GET['field_type'])?sanitize_text_field($_GET['field_type']):$field_settings['field_type']);
				?>
				<div class="db-custom-field">
					<div class="db-box-title">
						<h3 class="db-main-title">Custom field</h3>
					</div>
					<?php if ( !in_array('delete', $disabled_settings) ) { ?>
						<div class="db-field-row <?php echo(isset($field_settings['field_name'])&&$field_settings['field_name']!=''?'active':''); ?> clearfix">
							<label class="field-label">Field name <span class="db-required">*</span></label>
							<div class="db-field-input">
								<input type="text" class="db-create-field-name" data-required="true" value="<?php echo(isset($field_settings['field_name'])?$field_settings['field_name']:''); ?>">
								<span class="field-description">Unique name only from letters a-z</span>
								<span class="db-field-required">This field is required</span>
							</div>
						</div>
					<?php } ?>
					<div class="db-field-row <?php echo(isset($field_settings['admin_title'])&&$field_settings['admin_title']!=''?'active':''); ?> clearfix">
						<label class="field-label">Admin title</label>
						<div class="db-field-input">
							<input type="text" class="db-create-admin-title" value="<?php echo(isset($field_settings['admin_title'])?$field_settings['admin_title']:''); ?>">
							<span class="field-description">This is the name how you'll see it at the back-end field list</span>
						</div>
					</div>
					<div class="db-field-row <?php echo(isset($field_settings['frontend_title'])&&$field_settings['frontend_title']!=''?'active':''); ?> clearfix">
						<label class="field-label">Frontend title <span class="db-required">*</span></label>
						<div class="db-field-input">
							<input type="text" class="db-create-frontend-title" data-required="true" value="<?php echo(isset($field_settings['frontend_title'])?$field_settings['frontend_title']:''); ?>">
							<span class="field-description">How this field is going to be shown to other users</span>
							<span class="db-field-required">This field is required</span>
						</div>
					</div>
					<div class="db-field-row <?php echo(isset($field_settings['frontend_description'])&&$field_settings['frontend_description']!=''?'active':''); ?> clearfix">
						<label class="field-label">Frontend description</label>
						<div class="db-field-input">
							<input type="text" class="db-create-frontend-description" value="<?php echo(isset($field_settings['frontend_description'])?$field_settings['frontend_description']:''); ?>">
							<span class="field-description">The description which is going to be shown to users</span>
						</div>
					</div>
					<?php if ( ( isset($_GET['field_type']) && sanitize_key($_GET['field_type']) != 'hoursofoperation' ) || ( !isset($_GET['field_type']) && sanitize_key($field_settings['field_type']) != 'hoursofoperation' ) ) { ?>
					<div class="db-field-row <?php echo(isset($field_settings['default_value'])&&$field_settings['default_value']!=''?'active':''); ?> clearfix">
						<label class="field-label">Default value</label>
						<div class="db-field-input">
							<input type="text" class="db-create-default-value" value="<?php echo(isset($field_settings['default_value'])?$field_settings['default_value']:''); ?>">
							<span class="field-description"><?php echo ($field_type!='url'?'If this field has a default value, enter it here':'Link text for frontend'); ?></span>
						</div>
					</div>
					<?php } ?>
					<div class="db-field-row <?php echo(isset($field_settings['display_order'])&&$field_settings['display_order']!=''?'active':''); ?> clearfix">
						<label class="field-label">Display order</label>
						<div class="db-field-input">
							<input type="number" class="db-create-display-order" value="<?php echo(isset($field_settings['display_order'])?$field_settings['display_order']:''); ?>" <?php echo(in_array('display_order', $disabled_settings)?'disabled':''); ?>>
							<span class="field-description">The order in which it's goint to be shown to users</span>
						</div>
					</div>
					<div class="db-field-row focused active clearfix">
						<label class="field-label">Active?</label>
						<div class="db-field-input">
							<select class="db-create-field-active" <?php echo(in_array('field_active', $disabled_settings)?'disabled':''); ?>>
								<option value="yes" <?php echo(isset($field_settings['field_active'])&&$field_settings['field_active']=='yes'?'selected':''); ?>>Yes</option>
								<option value="no" <?php echo(isset($field_settings['field_active'])&&$field_settings['field_active']=='no'?'selected':''); ?>>No</option>
							</select>
							<span class="field-description">Do you want to show this field to users?</span>
						</div>
					</div>
					<div class="db-field-row focused active clearfix">
						<label class="field-label">For admins?</label>
						<div class="db-field-input">
							<select class="db-create-for-admins">
								<option value="no" <?php echo(isset($field_settings['for_admins'])&&$field_settings['for_admins']=='no'?'selected':''); ?>>No</option>
								<option value="yes" <?php echo(isset($field_settings['for_admins'])&&$field_settings['for_admins']=='yes'?'selected':''); ?>>Yes</option>
							</select>
							<span class="field-description">Only admins will be able to edit it</span>
						</div>
					</div>
					<div class="db-field-row focused active clearfix">
						<label class="field-label">Required?</label>
						<div class="db-field-input">
							<select class="db-create-required">
								<option value="yes" <?php echo(isset($field_settings['required'])&&$field_settings['required']=='yes'?'selected':''); ?>>Yes</option>
								<option value="no" <?php echo(isset($field_settings['required'])&&$field_settings['required']=='no'?'selected':''); ?>>No</option>
							</select>
							<span class="field-description">Is it required to fill this field in?</span>
						</div>
					</div>
					<div class="db-field-row <?php echo(isset($field_settings['required_message'])&&$field_settings['required_message']!=''?'active':''); ?> clearfix">
						<label class="field-label">Required message</label>
						<div class="db-field-input">
							<input type="text" class="db-create-required-message" value="<?php echo(isset($field_settings['required_message'])?$field_settings['required_message']:''); ?>">
							<span class="field-description">Message to be shown to users if they do not fill this field in.</span>
						</div>
					</div>
					<div class="db-field-row focused active clearfix">
						<label class="field-label">Show on list pages?</label>
						<div class="db-field-input">
							<select class="db-create-on-listing">
								<option value="no" <?php echo(isset($field_settings['on_listing'])&&$field_settings['on_listing']=='no'?'selected':''); ?>>No</option>
								<option value="yes" <?php echo(isset($field_settings['on_listing'])&&$field_settings['on_listing']=='yes'?'selected':''); ?>>Yes</option>
							</select>
							<span class="field-description">Do you want to show this field on pages that display listings in lists (for example search)?</span>
						</div>
					</div>
					<div class="db-field-row focused active clearfix">
						<label class="field-label">Show on details page?</label>
						<div class="db-field-input">
							<select class="db-create-on-detail">
								<option value="no" <?php echo(isset($field_settings['on_detail'])&&$field_settings['on_detail']=='no'?'selected':''); ?>>No</option>
								<option value="yes" <?php echo(isset($field_settings['on_detail'])&&$field_settings['on_detail']=='yes'?'selected':''); ?>>Yes</option>
							</select>
							<span class="field-description">Do you want to show this field on single listing page?</span>
						</div>
					</div>
					<div class="db-field-row focused active clearfix">
						<label class="field-label">Show on contact section?</label>
						<div class="db-field-input">
							<select class="db-create-on-contact">
								<option value="no" <?php echo(isset($field_settings['on_contact'])&&$field_settings['on_contact']=='no'?'selected':''); ?>>No</option>
								<option value="yes" <?php echo(isset($field_settings['on_contact'])&&$field_settings['on_contact']=='yes'?'selected':''); ?>>Yes</option>
							</select>
							<span class="field-description">Do you want to show this field on the contact section at the single listing pages?</span>
						</div>
					</div>
					<?php
					$sorting_types = array( 'text', 'number', 'textarea', 'checkbox', 'radio', 'select', 'multi-select', 'url', 'date', 'time', 'email' );
					if ( in_array($field_type, $sorting_types) ) { ?>
						<div class="db-field-row focused active clearfix">
							<label class="field-label">Show in sorting options?</label>
							<div class="db-field-input">
								<select class="db-create-on-sorting">
									<option value="no" <?php echo(isset($field_settings['on_sorting'])&&$field_settings['on_sorting']=='no'?'selected':''); ?>>No</option>
									<option value="yes" <?php echo(isset($field_settings['on_sorting'])&&$field_settings['on_sorting']=='yes'?'selected':''); ?>>Yes</option>
								</select>
								<span class="field-description">Do you want to show this field in sorting options at the search page?</span>
							</div>
						</div>
					<?php } ?>
					<div class="db-field-row focused active clearfix">
						<label class="field-label">Custom field icon</label>
						<div class="db-field-input">
							<div class="db-field-input">
								<?php echo __('Icon selected: ', 'directory-builder').'<i class="db-active-category-icon '.(isset($field_settings['field_icon'])&&$field_settings['field_icon']!=''?$field_settings['field_icon']:'').'"></i>'; ?>
								<div class="clearfix"></div>
								<input type="hidden" class="db-create-field-icon" value="<?php echo (isset($field_settings['field_icon'])&&$field_settings['field_icon']!=''?$field_settings['field_icon']:''); ?>">
								<input type="button" id="db-choose-category-icon" value="<?php esc_html_e('Choose icon', 'directory-builder'); ?>">
								<input type="button" id="db-delete-field-icon" value="<?php esc_html_e('Delete icon', 'directory-builder'); ?>" class="<?php echo (isset($field_settings['field_icon'])&&$field_settings['field_icon']!=''?'db-button-visible':''); ?>">
								<div class="db-category-icon-dialog main-card">
									<div class="db-category-icon-dialog-inner">
										<span class="db-category-icon-dialog-close dbicon-cancel"></span>
										<?php
											$icons = db_available_icons();
											$icons[] = 'wl-location';
											$icons[] = 'wl-phone';
											$icons[] = 'wl-link';
											foreach ($icons as $icon_value) {
												echo '<i class="db-category-icon-select '.$icon_value.'" data-id="'.$icon_value.'"></i>';
											}
										?>
									</div>
								</div>
							</div>
						</div>
					</div>
					<?php if ( isset( $field_settings['disabled'] ) ) { ?>
						<input type="hidden" class="db-create-disabled" value="<?php echo $field_settings['disabled']; ?>">
					<?php } ?>
					<?php if ( in_array('delete', $disabled_settings) ) { ?>
						<input type="hidden" class="db-create-field-name" data-required="true" value="<?php echo(isset($field_settings['field_name'])?$field_settings['field_name']:''); ?>">
					<?php } ?>
					<?php if ( $field_type == 'text' ) { ?>
						<div class="db-field-row <?php echo(isset($field_settings['validation_pattern'])&&$field_settings['validation_pattern']!=''?'active':''); ?> clearfix">
							<label class="field-label">Validation pattern</label>
							<div class="db-field-input">
								<input type="text" class="db-create-validation-pattern" value="<?php echo(isset($field_settings['validation_pattern'])?$field_settings['validation_pattern']:''); ?>">
								<span class="field-description">Validation pattern for HTML5 validation</span>
								<span class="field-description">Example: <strong>[A-Za-z]{3}</strong> - Any 3 letters from a to z</span>
							</div>
						</div>
						<div class="db-field-row <?php echo(isset($field_settings['validation_pattern_message'])&&$field_settings['validation_pattern_message']!=''?'active':''); ?> clearfix">
							<label class="field-label">Validation pattern message</label>
							<div class="db-field-input">
								<input type="text" class="db-create-validation-pattern-message" value="<?php echo(isset($field_settings['validation_pattern_message'])?$field_settings['validation_pattern_message']:''); ?>">
								<span class="field-description">Validation pattern message for HTML5 validation</span>
							</div>
						</div>
					<?php } else if ( $field_type == 'radio' ) { ?>
						<div class="db-field-row <?php echo(isset($field_settings['radio_options'])&&$field_settings['radio_options']!=''?'active':''); ?> clearfix">
							<label class="field-label">Radio button values</label>
							<div class="db-field-input">
								<input type="text" class="db-create-radio-options" value="<?php echo(isset($field_settings['radio_options'])?$field_settings['radio_options']:''); ?>">
								<span class="field-description">Provide radio button values separated with comma:</span>
								<span class="field-description">No WiFi,WiFi included,Nagotiable</span>
							</div>
						</div>
					<?php } else if ( $field_type == 'select' ) { ?>
						<div class="db-field-row <?php echo(isset($field_settings['select_options'])&&$field_settings['select_options']!=''?'active':''); ?> clearfix">
							<label class="field-label">Select values</label>
							<div class="db-field-input">
								<textarea class="db-create-select-options"><?php echo(isset($field_settings['select_options'])?$field_settings['select_options']:''); ?></textarea>
								<span class="field-description">Provide select option values, field name:field value, each value in a new line like so:</span>
								<span class="field-description">no-wifi:No WiFi<br>wifi-included:WiFi included</span>
							</div>
						</div>
					<?php } else if ( $field_type == 'file-upload' ) {
						$all_selected_types = (isset($field_settings['allowed_types'])?$field_settings['allowed_types']:array()); ?>
						<div class="db-field-row active clearfix">
							<label class="field-label">Allowed file types</label>
							<div class="db-field-input">
								<select class="db-create-allowed-types" multiple>
									<option value="*" selected="selected">All types</option>
									<optgroup label="Image formats">
											<option value="jpg" <?php echo(in_array('jpg',$all_selected_types)?'selected':''); ?>>.jpg</option>
											<option value="jpe" <?php echo(in_array('jpe',$all_selected_types)?'selected':''); ?>>.jpe</option>
											<option value="jpeg" <?php echo(in_array('jpeg',$all_selected_types)?'selected':''); ?>>.jpeg</option>
											<option value="gif" <?php echo(in_array('gif',$all_selected_types)?'selected':''); ?>>.gif</option>
											<option value="png" <?php echo(in_array('png',$all_selected_types)?'selected':''); ?>>.png</option>
											<option value="bmp" <?php echo(in_array('bmp',$all_selected_types)?'selected':''); ?>>.bmp</option>
											<option value="ico" <?php echo(in_array('ico',$all_selected_types)?'selected':''); ?>>.ico</option>
										</optgroup>
									<optgroup label="Video formats">
											<option value="asf" <?php echo(in_array('asf',$all_selected_types)?'selected':''); ?>>.asf</option>
											<option value="avi" <?php echo(in_array('avi',$all_selected_types)?'selected':''); ?>>.avi</option>
											<option value="flv" <?php echo(in_array('flv',$all_selected_types)?'selected':''); ?>>.flv</option>
											<option value="mkv" <?php echo(in_array('mkv',$all_selected_types)?'selected':''); ?>>.mkv</option>
											<option value="mp4" <?php echo(in_array('mp4',$all_selected_types)?'selected':''); ?>>.mp4</option>
											<option value="mpeg" <?php echo(in_array('mpeg',$all_selected_types)?'selected':''); ?>>.mpeg</option>
											<option value="mpg" <?php echo(in_array('mpg',$all_selected_types)?'selected':''); ?>>.mpg</option>
											<option value="wmv" <?php echo(in_array('wmv',$all_selected_types)?'selected':''); ?>>.wmv</option>
											<option value="3gp" <?php echo(in_array('3gp',$all_selected_types)?'selected':''); ?>>.3gp</option>
										</optgroup>
									<optgroup label="Audio formats">
											<option value="ogg" <?php echo(in_array('ogg',$all_selected_types)?'selected':''); ?>>.ogg</option>
											<option value="mp3" <?php echo(in_array('mp3',$all_selected_types)?'selected':''); ?>>.mp3</option>
											<option value="wav" <?php echo(in_array('wav',$all_selected_types)?'selected':''); ?>>.wav</option>
											<option value="wma" <?php echo(in_array('wma',$all_selected_types)?'selected':''); ?>>.wma</option>
										</optgroup>
									<optgroup label="Text formats">
											<option value="css" <?php echo(in_array('css',$all_selected_types)?'selected':''); ?>>.css</option>
											<option value="csv" <?php echo(in_array('csv',$all_selected_types)?'selected':''); ?>>.csv</option>
											<option value="htm" <?php echo(in_array('htm',$all_selected_types)?'selected':''); ?>>.htm</option>
											<option value="html" <?php echo(in_array('html',$all_selected_types)?'selected':''); ?>>.html</option>
											<option value="txt" <?php echo(in_array('txt',$all_selected_types)?'selected':''); ?>>.txt</option>
											<option value="rtx" <?php echo(in_array('rtx',$all_selected_types)?'selected':''); ?>>.rtx</option>
											<option value="vtt" <?php echo(in_array('vtt',$all_selected_types)?'selected':''); ?>>.vtt</option>
										</optgroup>
									<optgroup label="Application formats">
											<option value="doc" <?php echo(in_array('doc',$all_selected_types)?'selected':''); ?>>.doc</option>
											<option value="docx" <?php echo(in_array('docx',$all_selected_types)?'selected':''); ?>>.docx</option>
											<option value="exe" <?php echo(in_array('exe',$all_selected_types)?'selected':''); ?>>.exe</option>
											<option value="js" <?php echo(in_array('js',$all_selected_types)?'selected':''); ?>>.js</option>
											<option value="odt" <?php echo(in_array('odt',$all_selected_types)?'selected':''); ?>>.odt</option>
											<option value="pdf" <?php echo(in_array('pdf',$all_selected_types)?'selected':''); ?>>.pdf</option>
											<option value="pot" <?php echo(in_array('pot',$all_selected_types)?'selected':''); ?>>.pot</option>
											<option value="ppt" <?php echo(in_array('ppt',$all_selected_types)?'selected':''); ?>>.ppt</option>
											<option value="pptx" <?php echo(in_array('pptx',$all_selected_types)?'selected':''); ?>>.pptx</option>
											<option value="psd" <?php echo(in_array('psd',$all_selected_types)?'selected':''); ?>>.psd</option>
											<option value="rar" <?php echo(in_array('rar',$all_selected_types)?'selected':''); ?>>.rar</option>
											<option value="rtf" <?php echo(in_array('rtf',$all_selected_types)?'selected':''); ?>>.rtf</option>
											<option value="swf" <?php echo(in_array('swf',$all_selected_types)?'selected':''); ?>>.swf</option>
											<option value="tar" <?php echo(in_array('tar',$all_selected_types)?'selected':''); ?>>.tar</option>
											<option value="xls" <?php echo(in_array('xls',$all_selected_types)?'selected':''); ?>>.xls</option>
											<option value="xlsx" <?php echo(in_array('xlsx',$all_selected_types)?'selected':''); ?>>.xlsx</option>
											<option value="zip" <?php echo(in_array('zip',$all_selected_types)?'selected':''); ?>>.zip</option>
										</optgroup>
								</select>
							</div>
						</div>
					<?php } else if ( $field_type == 'date' ) { ?>
						<div class="db-field-row <?php echo(isset($field_settings['date_format'])&&$field_settings['date_format']!=''?'active':'active'); ?> clearfix">
							<label class="field-label">Date format</label>
							<div class="db-field-input">
								<input type="text" class="db-create-date-format" value="<?php echo(isset($field_settings['date_format'])?$field_settings['date_format']:'mm/dd/yy'); ?>">
								<span class="field-description">Provide date format for the datepicker</span>
							</div>
						</div>
					<?php } else if ( $field_type == 'multi-select' ) { ?>
						<div class="db-field-row focused active clearfix">
							<label class="field-label">Multiselect type</label>
							<div class="db-field-input">
								<select class="db-create-multiselect-type">
									<option value="select" <?php echo(isset($field_settings['multiselect_type'])&&$field_settings['multiselect_type']=='select'?'selected':''); ?>>Select</option>
									<option value="checkbox" <?php echo(isset($field_settings['multiselect_type'])&&$field_settings['multiselect_type']=='checkbox'?'selected':''); ?>>Checkbox</option>
								</select>
								<span class="field-description">What type of multiselect field is this?</span>
							</div>
						</div>
						<div class="db-field-row <?php echo(isset($field_settings['select_options'])&&$field_settings['select_options']!=''?'active':''); ?> clearfix">
							<label class="field-label">Multiselect values</label>
							<div class="db-field-input">
								<textarea class="db-create-select-options"><?php echo(isset($field_settings['select_options'])?$field_settings['select_options']:''); ?></textarea>
								<span class="field-description">Provide select option values, field name:field value, each value in a new line like so:</span>
								<span class="field-description">no-wifi:No WiFi<br>wifi-included:WiFi included</span>
							</div>
						</div>
					<?php } else if ( $field_type == 'checkbox' ) { ?>
						<div class="db-field-row <?php echo(isset($field_settings['checkbox_true'])&&$field_settings['checkbox_true']!=''?'active':''); ?> clearfix">
							<label class="field-label">Checked checkbox value</label>
							<div class="db-field-input">
								<input type="text" class="db-create-checkbox-true" value="<?php echo(isset($field_settings['checkbox_true'])?$field_settings['checkbox_true']:''); ?>">
								<span class="field-description">When checkbox is shown as checked, this value will be shown.</span>
							</div>
						</div>
						<div class="db-field-row <?php echo(isset($field_settings['checkbox_false'])&&$field_settings['checkbox_false']!=''?'active':''); ?> clearfix">
							<label class="field-label">Un-checked checkbox value</label>
							<div class="db-field-input">
								<input type="text" class="db-create-checkbox-false" value="<?php echo(isset($field_settings['checkbox_false'])?$field_settings['checkbox_false']:''); ?>">
								<span class="field-description">When checkbox is shown as un-checked, this value will be shown.</span>
							</div>
						</div>
					<?php } ?>
					<input type="hidden" class="db-create-field-type" value="<?php echo $field_type; ?>">
					<?php if ( !isset($_GET['field_id']) ) { ?>
						<a href="javascript:void(0)" class="db-save-field db-button db-primary-button" data-save="insert">Create field</a>
					<?php } else {
						if ( $is_child ) {
							?><input type="hidden" class="db-create-child" value="true"><?php
						} ?>
						<a href="javascript:void(0)" class="db-save-field db-button db-primary-button" data-save="update" data-id="<?php echo esc_attr($_GET['field_id']); ?>">Save field</a>
					<?php } ?>
				</div>
			<?php } ?>
		</div>
	</div>
	<?php
}

function db_save_field() {
	if ( !current_user_can('manage_options') ) die(0);

	global $wpdb;
	$field_settings = ( isset($_POST['field_settings']) ? sanitize_text_field($_POST['field_settings']) : '' );
	$save_type = ( isset($_POST['save_type']) ? sanitize_key($_POST['save_type']) : '' );
	$field_id = ( isset($_POST['field_id']) ? intval($_POST['field_id']) : '' );
	
	$field_decoded_settings = json_decode(stripslashes($field_settings), true);
	if ( isset($field_decoded_settings) ) {
		$field_order = $field_decoded_settings['display_order'];
		$field_active = $field_decoded_settings['field_active'];

		if ( $save_type == 'insert' ) {
			$save_query = $wpdb->query('INSERT INTO '.$wpdb->prefix.'directory_fields (`field_order`, `field_active`, `field_settings`) VALUES ("'.$field_order.'", "'.$field_active.'", "'.$field_settings.'")');
		} else {
			$save_query = $wpdb->query('UPDATE '.$wpdb->prefix.'directory_fields SET field_order="'.$field_order.'", field_active="'.$field_active.'", field_settings="'.$field_settings.'" WHERE ID="'.$field_id.'"');
			if ( $field_decoded_settings['field_name'] == 'listing_address' ) {
				$wpdb->query('UPDATE '.$wpdb->prefix.'directory_fields SET field_order="'.$field_order.'" WHERE field_settings LIKE "%\"field_name\":\"listing_city\"%"');
				$wpdb->query('UPDATE '.$wpdb->prefix.'directory_fields SET field_order="'.$field_order.'" WHERE field_settings LIKE "%\"field_name\":\"listing_neighborhood\"%"');
				$wpdb->query('UPDATE '.$wpdb->prefix.'directory_fields SET field_order="'.$field_order.'" WHERE field_settings LIKE "%\"field_name\":\"listing_zip\"%"');
				$wpdb->query('UPDATE '.$wpdb->prefix.'directory_fields SET field_order="'.$field_order.'" WHERE field_settings LIKE "%\"field_name\":\"listing_state\"%"');
				$wpdb->query('UPDATE '.$wpdb->prefix.'directory_fields SET field_order="'.$field_order.'" WHERE field_settings LIKE "%\"field_name\":\"listing_country\"%"');
				$wpdb->query('UPDATE '.$wpdb->prefix.'directory_fields SET field_order="'.$field_order.'" WHERE field_settings LIKE "%\"field_name\":\"listing_address_lat\"%"');
				$wpdb->query('UPDATE '.$wpdb->prefix.'directory_fields SET field_order="'.$field_order.'" WHERE field_settings LIKE "%\"field_name\":\"listing_address_lng\"%"');
			}
		}

		if ( $save_query === false ) {
			echo '{"save_response": "failed"}';
		} else {
			echo '{"save_response": "'.$wpdb->insert_id.'", "redirect": "'.DB_PLUGIN_FIELD_PAGE_URL.'"}';
		}
	}

	die(0);
}
add_action( 'wp_ajax_db_save_field', 'db_save_field' );

function db_save_package() {
	if ( !current_user_can('manage_options') ) die(0);

	global $wpdb;
	$package_settings = ( isset($_POST['package_settings']) ? sanitize_text_field($_POST['package_settings']) : '' );
	$save_type = ( isset($_POST['save_type']) ? sanitize_key($_POST['save_type']) : '' );
	$package_id = ( isset($_POST['package_id']) ? intval($_POST['package_id']) : '' );
	
	$package_decoded_settings = json_decode(stripslashes($package_settings), true);
	if ( isset($package_decoded_settings) ) {
		if ( $save_type == 'insert' ) {
			$save_query = $wpdb->query('INSERT INTO '.$wpdb->prefix.'directory_packages (`package_name`, `package_settings`) VALUES ("'.$package_decoded_settings['fee_label'].'", "'.$package_settings.'")');
		} else {
			$save_query = $wpdb->query('UPDATE '.$wpdb->prefix.'directory_packages SET package_name="'.$package_decoded_settings['fee_label'].'", package_settings="'.$package_settings.'" WHERE ID="'.$package_id.'"');
		}

		if ( $save_query === false ) {
			echo '{"save_response": "failed"}';
		} else {
			echo '{"save_response": "'.$wpdb->insert_id.'", "redirect": "'.DB_PLUGIN_PACKAGE_PAGE_URL.'"}';
		}
	}

	die(0);
}
add_action( 'wp_ajax_db_save_package', 'db_save_package' );

function db_delete_field() {
	if ( !current_user_can('manage_options') ) die(0);

	global $wpdb;
	$field_id = ( isset($_POST['field_id']) ? intval($_POST['field_id']) : '' );

	if ( $wpdb->query('DELETE FROM '.$wpdb->prefix.'directory_fields WHERE ID="'.$field_id.'"') === false ) {
		echo '{"save_response": "failed"}';
	} else {
		echo '{"save_response": "'.$wpdb->insert_id.'"}';
	}

	die(0);
}
add_action( 'wp_ajax_db_delete_field', 'db_delete_field' );

add_action( 'load-post.php', 'db_metabox_setup' );
add_action( 'load-post-new.php', 'db_metabox_setup' );
function db_metabox_setup() {

	/* Add meta boxes on the 'add_meta_boxes' hook. */
	add_action( 'add_meta_boxes', 'db_add_metabox' );

	/* Save post meta on the 'save_post' hook. */
	add_action( 'save_post', 'db_save_field_metabox', 10, 2 );
}

function db_save_field_metabox( $post_id, $post ) {
	/* Verify the nonce before proceeding. */
	if ( !isset( $_POST['db_listing_field_nonce'] ) || !wp_verify_nonce( $_POST['db_listing_field_nonce'], basename( __FILE__ ) ) || $post->post_type == 'revision' )
	return $post_id;

	/* Get the post type object. */
	$post_type = get_post_type_object( $post->post_type );

	/* Check if the current user has permission to edit the post. */
	if ( !current_user_can( $post_type->cap->edit_post, $post_id ) )
	return $post_id;

	$meta_values = array(
		'listing_gallery_img',
		'db_listing_custom_img'
	);

	global $wpdb;
	$field_list = $wpdb->get_results('SELECT * FROM '.$wpdb->prefix.'directory_fields WHERE field_active="yes" ORDER BY field_order DESC');
	if ( !empty($field_list) ) {
		foreach ($field_list as $field_value) {
			$field_settings = json_decode($field_value->field_settings, true);
			$meta_values[] = $field_settings['field_name'];
		}
	}

	foreach ($meta_values as $a_meta_value) {
		/* Get the posted data and sanitize it for use as an HTML class. */
		$new_meta_value   = ( isset( $_POST[$a_meta_value] ) ? ( !is_array( $_POST[$a_meta_value] ) ? sanitize_text_field( $_POST[$a_meta_value] ) : db_sanitize_array( $_POST[$a_meta_value] ) ) : '' );
		
		/* Get the meta key. */
		$meta_key   = sanitize_key($a_meta_value);

		/* Get the meta value of the custom field key. */
		$meta_value   = get_post_meta( $post_id, $meta_key, true );

		/* If a new meta value was added and there was no previous value, add it. */
		if ( $new_meta_value && '' != $new_meta_value )
		update_post_meta( $post_id, $meta_key, $new_meta_value );

		/* If there is no new meta value but an old value exists, delete it. */
		elseif ( '' == $new_meta_value && $meta_value )
		delete_post_meta( $post_id, $meta_key, $meta_value );
	}

	// Update paid category
	$sanitized_categories = array();
	$unsanitized_categories = $_POST['tax_input']['listing_category'];
	if ( is_array($unsanitized_categories) && !empty($unsanitized_categories) ) {
		foreach ($unsanitized_categories as $cat_value) {
			$sanitized_categories[] = intval($cat_value);
		}
	}
	$order_options = get_post_meta( $post_id, 'db_order_info', true );
	$order_options['category'] = implode(',', $sanitized_categories);
	update_post_meta( $post_id, 'db_order_info', $order_options );
}

function db_sanitize_array( $data ) {
	if ( !empty($data) ) {
		foreach ($data as $field_key => $field_value) {
			$data[$field_key] = sanitize_text_field( $field_value );
		}
	}

	return $data;
}

function db_add_metabox() {

	add_meta_box(
		'directory_listing_fields',                                      // Unique ID
		esc_html__( 'Advanced listing fields', 'directory-builder' ),    // Title
		'db_field_metabox_function',                                     // Callback function
		'listings',                                                      // Admin page (or post type)
		'advanced',                                                      // Context
		'high'                                                           // Priority
	);

	add_meta_box(
		'directory_listing_orders',                                      // Unique ID
		esc_html__( 'Listing transactions', 'directory-builder' ),    // Title
		'db_order_metabox_function',                                     // Callback function
		'listings',                                                      // Admin page (or post type)
		'side',                                                      // Context
		'high'                                                           // Priority
	);

	add_meta_box(
		'directory_listing_image',                                      // Unique ID
		esc_html__( 'Open listing image', 'directory-builder' ),    // Title
		'db_listing_img_metabox_function',                                     // Callback function
		'listings',                                                      // Admin page (or post type)
		'side',                                                      // Context
		'low'                                                           // Priority
	);

}

function db_field_metabox_function( $object, $box ) { ?>

	<?php
		wp_nonce_field( basename( __FILE__ ), 'db_listing_field_nonce' );
		$listing_images = esc_attr( get_post_meta( $object->ID, 'listing_gallery_img', true ) );
		$main_settings = get_option( 'db_main_settings');

		$listing_address = (get_post_meta( $object->ID, 'listing_address', true )?get_post_meta( $object->ID, 'listing_address', true ):$main_settings['default_location']);
		$listing_address_lat = (get_post_meta( $object->ID, 'listing_address_lat', true )?get_post_meta( $object->ID, 'listing_address_lat', true ):$main_settings['default_location_lat']);
		$listing_address_lng = (get_post_meta( $object->ID, 'listing_address_lng', true )?get_post_meta( $object->ID, 'listing_address_lng', true ):$main_settings['default_location_lng']);
	?>

	<style type="text/css">
		.db-field-row-label, .db-field-row-description, .db-radio-label, .db-checkbox-label { display: block; }
		.db-field-row { margin-bottom: 1em; }
		.db-field-row input:not([type="radio"]):not([type="checkbox"]):not([type="button"]), .db-field-row select, .db-field-row textarea { display: block; width: 100%; }
	</style>

	<?php
	global $wpdb;
	$field_list = $wpdb->get_results('SELECT * FROM '.$wpdb->prefix.'directory_fields WHERE field_active="yes" ORDER BY field_order ASC');
	if ( !empty($field_list) ) {
		foreach ($field_list as $field_value) {
			$field_settings = json_decode($field_value->field_settings, true);

			$default_value = get_post_meta( $object->ID, $field_settings['field_name'], true );

			if ( $field_settings['field_name'] == 'listing_address' && $default_value == '' ) {
				$default_value = $default_location;
			} else if ( $field_settings['field_name'] == 'listing_address_lat' && $default_value == '' ) {
				$default_value = $default_location_lat;
			} else if ( $field_settings['field_name'] == 'listing_address_lng' && $default_value == '' ) {
				$default_value = $default_location_lng;
			}

			echo db_get_custom_field( $field_settings, '', $default_value );

			if ( $field_settings['field_name'] == 'listing_address_lng' ) { ?>
				<a href="javascript:void(0)" class="db-set-address button button-primary button-large">Set address</a>
				<br /><br />
				<script async defer src="https://maps.googleapis.com/maps/api/js?key=<?php echo $main_settings['google_key']; ?>" type="text/javascript"></script>
				<script type="text/javascript">
					jQuery(window).load(function() {
						var $geocoder;
						var $map;
						var $first_marker;
						function db_start_geolocation() {
							$geocoder = new google.maps.Geocoder()
							var address = <?php echo (isset($listing_address)&&$listing_address!=''?'"'.$listing_address.'";':'"'.$default_location.'";'); ?>
							$geocoder.geocode( { "address": address}, function(results, status) {

								if (status == google.maps.GeocoderStatus.OK) {
									db_initialize(results[0].geometry.location);
									jQuery('#listing_address_lat').val(results[0].geometry.location.lat());
									jQuery('#listing_address_lng').val(results[0].geometry.location.lng());
								} 
							});
						}
						
						function db_initialize(location) {
							var mapCanvas = document.getElementById("db-listing-map");
							var myLatlng = location;
							var mapOptions = {
								center: location,
								zoom: 13,
								mapTypeId: google.maps.MapTypeId.ROADMAP,
								scrollwheel: false,
								navigationControl: false,
								mapTypeControl: false,
								scaleControl: false,
								disableDefaultUI: false
							}
							$map = new google.maps.Map(mapCanvas, mapOptions);

							$first_marker = new google.maps.Marker({
								position: myLatlng,
								map: $map,
								draggable: true
							});
							db_add_dragend_event( $first_marker );
						}

						function db_add_dragend_event( marker_obj ) {
							google.maps.event.addListener(marker_obj, 'dragend', function (event) {
								jQuery('#listing_address_lat').val(this.getPosition().lat());
								jQuery('#listing_address_lng').val(this.getPosition().lng());
								jQuery('.db-set-address').addClass('dragged').click();
							});
						}
						<?php if ( $listing_address_lat != '' && $listing_address_lng != '' ) { ?>
							db_initialize( new google.maps.LatLng(jQuery('#listing_address_lat').val(), jQuery('#listing_address_lng').val()) );
						<?php } else { ?>
							db_start_geolocation();
						<?php } ?>
						jQuery(document).on('click', '.db-set-address', function() {
							var google_json_address;
							if ( !jQuery(this).hasClass('dragged') ) {
								google_json_address = encodeURIComponent( jQuery('#listing_address').val() );
							} else {
								google_json_address = encodeURIComponent( jQuery('#listing_address_lat').val()+','+jQuery('#listing_address_lng').val() );
							}
							jQuery.get('https://maps.googleapis.com/maps/api/geocode/json?address='+google_json_address+'&key=<?php echo $main_settings['google_key']; ?>&language=en', function( data ) {
								if ( data.status == 'OK' ) {
									$first_marker.setMap(null);
									var marker = new google.maps.Marker({ position: data.results['0'].geometry.location, map: $map, draggable: true });
									$first_marker = marker;
									db_add_dragend_event( $first_marker );

									jQuery('#listing_city, #listing_zip, #listing_neighborhood, #listing_state').val('');
									jQuery.each(data.results['0'].address_components, function( index, address_comp ) {
										if( ( address_comp.types[0] == "locality" && address_comp.types[1] == "political" ) || address_comp.types[0] == "postal_town" ) {
											jQuery('#listing_city').val( address_comp.long_name );
										}

										if( address_comp.types[0] == "country" && address_comp.types[1] == "political" ) {
											if ( jQuery('[name="listing_country"] option[value="'+address_comp.long_name+'"]').length ) {
												jQuery('[name="listing_country"]').val( address_comp.long_name );
											} else {
												jQuery('[name="listing_country"]').append('<option value="'+address_comp.long_name+'">'+address_comp.long_name+'</option>').val( address_comp.long_name );
											}
										}

										if( address_comp.types[0] == "postal_code" ) {
											jQuery('#listing_zip').val( address_comp.long_name );
										}

										if ( ( address_comp.types[0] == "administrative_area_level_1" && address_comp.types[1] == "political" ) || address_comp.types[0] == "neighborhood" && address_comp.types[1] == "political" ) {
											jQuery('#listing_neighborhood').val( address_comp.long_name );
										}

										if ( address_comp.types[0] == "administrative_area_level_2" && address_comp.types[1] == "political" ) {
											jQuery('#listing_state').val( address_comp.long_name );
										}
									});

									jQuery('#listing_address').val( data.results['0'].formatted_address );

									jQuery('#listing_address_lat').val(data.results['0'].geometry.location.lat);
									jQuery('#listing_address_lng').val(data.results['0'].geometry.location.lng);

									$map.setCenter(data.results['0'].geometry.location);
									jQuery('.db-set-address').removeClass('dragged');
								} else {
									alert('Your address couldn\'t be found');
								}
							});
						});
					});
				</script>
				<div id="db-listing-map" style="width: 100%; height: 300px;"></div>
				<br />
				<?php
			}
		}
	}
	?>

	<p>
		<label for="listing_address"><?php _e( "Listing images ", 'directory-builder' ); ?></label>
		<br />
		<div class="db-listing-uploaded-images clearfix">
			<?php
				if ( $listing_images != '' ) {
					$listing_images_parsed = explode('|', $listing_images);
					foreach ($listing_images_parsed as $image_value) {
						if ( $image_value == '' ) {
							continue;
						}
						$gallery_image = wp_get_attachment_image_src($image_value);
						echo '<div class="db-uploaded-img-row"><span class="db-uploaded-img-delete dbicon-cancel"></span><img src="'.$gallery_image['0'].'"></div>';
					}
				}
			?>
		</div>
		<input type="hidden" name="listing_gallery_img" id="listing_gallery_img" value="<?php echo $listing_images; ?>" />
		<a href="javascript:void(0)" class="db-upload-listing-images button button-primary button-large">Upload images</a>
	</p>

	<?php
}

function db_order_metabox_function( $object, $box ) { ?>
	<?php
		$order_data = get_post_meta( $object->ID, 'db_order_info', true );
		$listing_expiration_date = '';
		if ( $order_data != '' ) {
			$all_categories = explode(',', $order_data['category']);
			$category_names = array();
			foreach ($all_categories as $category_id) {
				if ( $category_id != 0 ) {
					$category = get_term($category_id, 'listing_category');
					$category_names[] = $category->name;
				}
			}
			
			$featured_listings = get_option('db_sticky_listings', array());
			$listing_sticky = (in_array($object->ID, $featured_listings)?'Yes':'No');

			global $wpdb;
			$package_list = $wpdb->get_results('SELECT * FROM '.$wpdb->prefix.'directory_packages ORDER BY ID ASC');
			if ( !empty($package_list) ) {
				$field_settings = json_decode($package_list['0']->package_settings, true);
			}

			if ( isset($order_data['listing_expires']) && !is_numeric($order_data['listing_expires']) && isset($order_data['completed_on']) && $field_settings['listing_run_type'] == 'days' ) {
				$order_data['listing_expires'] = date( get_option('date_format'), strtotime('+'.$field_settings['listing_run_days'].' days', $order_data['completed_on']));
			} else if ( !isset($order_data['listing_expires']) ) {
				$order_data['listing_expires'] = 'Unknown';
			}
		} else {
			$order_data = array(
					'listing_package' => __('No information', 'directory-builder'),
					'listing_package_name' => __('No information', 'directory-builder'),
					'paid_amount' => __('No information', 'directory-builder'),
					'payment_history' => array(),
					'payment_status' => __('No information', 'directory-builder'),
					'category' => __('No information', 'directory-builder'),
					'listing_expires' => __('No information', 'directory-builder'),
					'listing_sticky' => __('No information', 'directory-builder')
				);

			$category = (object)[];
			$category->name = 'No information';
			$package_list = array();
			$listing_sticky = __('No information', 'directory-builder');
			$category_names = array( __('No information', 'directory-builder') );
		}

		if ( $field_settings['listing_run_type'] == 'forever' ) {
			$listing_expiration = '<a href="javascript:void(0)" class="db-expiration-select">'.__('Never', 'directory-builder').'</a>';
		} else if ( $field_settings['listing_run_type'] == 'days' && $order_data['listing_expires'] != 'Unknown' ) {
			$listing_expiration = '<a href="javascript:void(0)" class="db-expiration-select">'.date( get_option('date_format'), $order_data['listing_expires']).'</a>';
			$listing_expiration_date = date( 'Y-m-d', $order_data['listing_expires']);
		} else {
			$listing_expiration = '<a href="javascript:void(0)" class="db-expiration-select">'.__('Unknown', 'directory-builder').'</a>';
		}
	?>

	<div class="db-order-wrapper">
		<div class="db-order-row">
			<span class="db-order-label">Listing author:</span>
			<span class="db-order-value"><a href="<?php echo admin_url('user-edit.php?user_id='.$object->post_author); ?>"><?php echo get_the_author_meta('nicename', $object->post_author); ?></a></span>
		</div>
		<div class="db-order-row">
			<span class="db-order-label">Listing status:</span>
			<span class="db-order-value">
				<?php echo (isset($order_data['payment_status'])?'<a href="javascript:void(0)" class="db-status-select" data-id="">'.$order_data['payment_status'].'</a>':''); ?>
				<div class="db-listing-status-container" style="display: none;">
					<select class="db-listing-status">
						<option value="Processing" <?php echo ($order_data['payment_status']=='Processing'?'selected':'') ?>>Processing</option>
						<option value="Completed" <?php echo ($order_data['payment_status']=='Completed'?'selected':'') ?>>Completed</option>
						<option value="Pending" <?php echo ($order_data['payment_status']=='Pending'?'selected':'') ?>>Pending</option>
						<option value="Refunded" <?php echo ($order_data['payment_status']=='Refunded'?'selected':'') ?>>Refunded</option>
					</select>
					<a href="javascript:void(0)" class="db-listing-status-save" data-id="<?php echo $object->ID; ?>"><?php _e('Change', 'directory-builder'); ?></a>
				</div>
			</span>
		</div>
		<div class="db-order-row">
			<span class="db-order-label">Listing package:</span>
			<span class="db-order-value"><?php echo (isset($order_data['listing_package_name'])?'<a href="javascript:void(0)" class="db-order-select" data-id="'.$order_data['listing_package'].'">'.$order_data['listing_package_name'].'</a>':''); ?>
				<div class="db-order-package-container" style="display: none;">
					<select class="db-order-package">
					<?php
						if ( !empty($package_list) ) {
							foreach ($package_list as $package_value) {
								echo '<option value="'.$package_value->ID.'"'.($order_data['listing_package_name']==$package_value->package_name?' selected':'').'>'.$package_value->package_name.'</option>';
							}
						}
					?>
					</select>
					<a href="javascript:void(0)" class="db-order-package-save" data-id="<?php echo $object->ID; ?>"><?php _e('Change', 'directory-builder'); ?></a>
				</div>
			</span>
		</div>
		<div class="db-order-row">
			<span class="db-order-label">Listing cost:</span>
			<span class="db-order-value"><?php echo (isset($order_data['paid_amount'])?$order_data['paid_amount']:''); ?></span>
		</div>
		<div class="db-order-row">
			<span class="db-order-label">Listing expiration:</span>
			<span class="db-order-value"><?php echo $listing_expiration; ?>
				<div class="db-expiration-dialog" style="display: none;">
					<input type="date" class="db-listing-expiration-date" value="<?php echo $listing_expiration_date; ?>">
					<a href="javascript:void(0)" class="db-expiration-save" data-id="<?php echo $object->ID; ?>"><?php _e('Change', 'directory-builder'); ?></a>
				</div>
			</span>

		</div>
		<div class="db-order-row">
			<span class="db-order-label">Listing featured:</span>
			<span class="db-order-value">
				<a href="javascript:void(0)" class="db-featured-listing"><?php echo $listing_sticky; ?></a>
				<div class="db-featured-dialog" style="display: none;">
					<select class="db-featured-status">
						<option value="Yes" <?php echo (in_array($object->ID, $featured_listings)?'selected':''); ?>>Yes</option>
						<option value="No" <?php echo (!in_array($object->ID, $featured_listings)?'selected':''); ?>>No</option>
					</select>
					<a href="javascript:void(0)" class="db-featured-save" data-id="<?php echo $object->ID; ?>"><?php _e('Change', 'directory-builder'); ?></a>
				</div>
			</span>
		</div>
		<div class="db-order-row">
			<span class="db-order-label">Paid category:</span>
			<span class="db-order-value"><?php echo implode(', ', $category_names); ?></span>
		</div>
		<div class="db-order-row">
			<span class="db-order-label">Payment history:</span>
			<?php if ( isset($order_data['payment_history']) && !empty($order_data['payment_history']) ) {
				$listing_billing = get_post_meta( $object->ID, 'db_billing_info', true );

				foreach ($order_data['payment_history'] as $payment_value) {
					$payment_data = explode('===', $payment_value); ?>
					<div class="clearfix"></div>
					<div class="db-order-history-row">
						<span class="db-order-value-left"><?php echo date( get_option('date_format'), strtotime($payment_data['0']) ); ?></span>
						<div class="db-payment-dialog">
							<div class="db-payment-dialog-row">
								<?php echo __('Payment:', 'directory-builder').' <strong>'.date( get_option('date_format').' '.get_option('time_format'), strtotime($payment_data['0']) ).'</strong>'; ?>
							</div>
							<div class="db-payment-dialog-row">
								<?php echo __('Status:', 'directory-builder').' <strong>'.$payment_data['2'].'</strong>'; ?>
							</div>
							<div class="db-payment-dialog-row">
								<?php echo __('Gateway:', 'directory-builder').' <strong>'.(isset($payment_data['3'])?$payment_data['3']:'-').'</strong>'; ?>
							</div>
							<div class="db-payment-dialog-row">
								<?php echo __('Item:', 'directory-builder').' <strong>'.$order_data['listing_package_name'].'</strong>'; ?>
							</div>
							<div class="db-payment-dialog-row">
								<?php echo __('Total:', 'directory-builder').' <strong>'.$payment_data['1'].'</strong>'; ?>
							</div>
							<?php if ( !empty($listing_billing) ) {
								echo '<h3>'.__('Billing information', 'directory-builder').'</h3>';
								foreach ($listing_billing as $billing_key => $billing_value) {
									switch ( $billing_key ) {
										case 'x_full_name': $billing_label = __('Full name', 'directory-builder'); break;
										case 'x_company': $billing_label = __('Company', 'directory-builder'); break;
										case 'x_phone': $billing_label = __('Phone', 'directory-builder'); break;
										case 'x_email': $billing_label = __('Email', 'directory-builder'); break;
										case 'x_country': $billing_label = __('Country', 'directory-builder'); break;
										case 'x_address': $billing_label = __('Address', 'directory-builder'); break;
										case 'x_city': $billing_label = __('City', 'directory-builder'); break;
										case 'x_state': $billing_label = __('State', 'directory-builder'); break;
										case 'x_zip': $billing_label = __('ZIP', 'directory-builder'); break;
										case 'auth-code': $billing_label = __('Card Auth Code', 'directory-builder'); break;
										case 'trans-id': $billing_label = __('Transaction ID', 'directory-builder'); break;
										case 'subscription': $billing_label = __('Subscription ID', 'directory-builder'); break;

										default: break;
									}
									?>
									<div class="db-payment-dialog-row">
										<?php echo $billing_label.': <strong>'.($billing_value!=''?$billing_value:'-').'</strong>'; ?>
									</div>
									<?php
								}
							} ?>
						</div>
						<span class="db-order-value-center"><?php echo $payment_data['1']; ?></span>
						<span class="db-order-value-right <?php echo strtolower($payment_data['2']); ?>"><?php echo $payment_data['2']; ?></span>
						<div class="clearfix"></div>
					</div>
				<?php } ?>
			<?php } else { ?>
				<span class="db-order-value"><?php _e('None', 'directory-builder'); ?></span>
			<?php } ?>
		</div>
	</div>
	
	<?php
}

function db_listing_img_metabox_function( $object, $box ) {
	$listing_custom_image = esc_attr( get_post_meta( $object->ID, 'db_listing_custom_img', true ) );
	?>
	<div class="db-custom-img-wrapper">
		<div class="db-custom-img-item empty <?php echo ($listing_custom_image==''?'active':''); ?>">
			<a href="javascript:void(0)" class="db-set-custom-image">Set custom image</a>
			<p>If custom image is not set, then the featured image is going to be used!</p>
		</div>
		<div class="db-custom-img-item set <?php echo ($listing_custom_image!=''?'active':''); ?>">
			<img src="<?php echo wp_get_attachment_url($listing_custom_image); ?>" alt="" style="max-width: 100%;">
			<a href="javascript:void(0)" class="db-remove-custom-image">Remove custom image</a>
		</div>
		<input type="hidden" name="db_listing_custom_img" id="db_listing_custom_img" value="<?php echo $listing_custom_image; ?>" />
	</div>
	
	<?php
}

function db_get_custom_field( $field_settings, $custom_class = '', $def_value = '' ) {
	if ( empty($field_settings) ) {
		return;
	}
	$output = '';

	$field_name = $field_settings['field_name'];
	$field_title = $field_settings['frontend_title'];
	$field_description = $field_settings['frontend_description'];
	$field_default = (isset($field_settings['default_value'])?$field_settings['default_value']:'');

	if ( $def_value != '' ) { 
		$field_default = $def_value;
	}

	$field_required = ($field_settings['required']=='yes'?' required':'');
	$field_required_message = $field_settings['required_message'];

	switch ( $field_settings['field_type'] ) {
		case 'text':
			$field_validation_pattern = (isset($field_settings['validation_pattern'])&&$field_settings['validation_pattern']!=''?' pattern="'.$field_settings['validation_pattern'].'"':'');
			$field_validation_pattern_message = (isset($field_settings['validation_pattern_message'])&&$field_settings['validation_pattern_message']!=''?' title="'.$field_settings['validation_pattern_message'].'"':'');

			$output .= '
			<div class="db-field-row'.$field_required.'">';
				if ( $field_title != '' ) {
					$output .= '<label class="db-field-row-label" for="'.$field_name.'">'.$field_title.'</label>';
				}
				$output .= '<input type="text" id="'.$field_name.'" name="'.$field_name.'" class="'.$custom_class.'" placeholder="'.$field_title.'" value="'.$field_default.'"'.$field_validation_pattern.$field_validation_pattern_message.' autocomplete="off">';
				if ( $field_name == 'listing_address' && !is_admin() ) {
					$output .= '<span class="db-autolocate-me"><svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" width="15px" height="15px" viewBox="0 0 15 15" version="1.1"> <g id="Welcome" stroke="none" stroke-width="1" fill="none" fill-rule="evenodd"> <g id="All-listings" transform="translate(-964.000000, -626.000000)" fill-rule="nonzero" fill="#9B9B9B"> <g id="Group-4-Copy" transform="translate(731.000000, 611.000000)"> <g id="target-with-circle" transform="translate(233.000000, 15.000000)"> <g id="Capa_1"> <path d="M7.48790875,4.76543726 C5.98346008,4.76543726 4.76543726,5.98346008 4.76543726,7.48790875 C4.76543726,8.99235741 5.98346008,10.2103802 7.48790875,10.2103802 C8.99235741,10.2103802 10.2103802,8.99235741 10.2103802,7.48790875 C10.2103802,5.98346008 8.99235741,4.76543726 7.48790875,4.76543726 Z M13.5730894,6.80652091 C13.2604848,3.96798479 11.0072338,1.71473384 8.16869772,1.40272814 L8.16869772,0 L6.80714829,0 L6.80714829,1.40272814 C3.96858365,1.71473384 1.71536122,3.96798479 1.40210076,6.80652091 L0,6.80652091 L0,8.1693251 L1.40272814,8.1693251 C1.71596008,11.0078612 3.96921103,13.2611122 6.80774715,13.5731179 L6.80774715,14.975846 L8.16929658,14.975846 L8.16929658,13.5731179 C11.0078327,13.2611122 13.2610837,11.0078897 13.5736882,8.1693251 L14.975789,8.1693251 L14.975789,6.80652091 C14.975846,6.80652091 13.5730894,6.80652091 13.5730894,6.80652091 Z M7.48790875,12.253346 C4.85341255,12.253346 2.72247148,10.1224049 2.72247148,7.48790875 C2.72247148,4.85341255 4.85341255,2.72247148 7.48790875,2.72247148 C10.1224049,2.72247148 12.253346,4.85341255 12.253346,7.48790875 C12.253346,10.1224049 10.1224049,12.253346 7.48790875,12.253346 Z" id="Shape"/> </g> </g> </g> </g> </g> </svg></span>';
				}
				if ( $field_description != '' || ( $field_settings['required'] == 'yes' && $field_required_message != '' ) ) {
					$output .= '<div class="db-field-meta">';
						if ( $field_description != '' ) {
							$output .= '<span class="db-field-row-description">'.$field_description.'</span>';
						}
						if ( $field_settings['required'] == 'yes' && $field_required_message != '' && !is_admin() ) {
							$output .= '<span class="db-field-row-required">'.$field_required_message.'</span>';
						}
					$output .= '</div>';
				}
			$output .= '
			</div>';
			break;

		case 'number':
			$output .= '
			<div class="db-field-row'.$field_required.'">';
				if ( $field_title != '' ) {
					$output .= '<label class="db-field-row-label" for="'.$field_name.'">'.$field_title.'</label>';
				}
				$output .= '<input type="number" id="'.$field_name.'" name="'.$field_name.'" class="'.$custom_class.'" placeholder="'.$field_title.'" value="'.$field_default.'">';
				if ( $field_description != '' || ( $field_settings['required'] == 'yes' && $field_required_message != '' ) ) {
					$output .= '<div class="db-field-meta">';
						if ( $field_description != '' ) {
							$output .= '<span class="db-field-row-description">'.$field_description.'</span>';
						}
						if ( $field_settings['required'] == 'yes' && $field_required_message != '' && !is_admin() ) {
							$output .= '<span class="db-field-row-required">'.$field_required_message.'</span>';
						}
					$output .= '</div>';
				}
			$output .= '
			</div>';
			break;

		case 'textarea':
			$output .= '
			<div class="db-field-row'.$field_required.'">';
				if ( $field_title != '' ) {
					$output .= '<label class="db-field-row-label" for="'.$field_name.'">'.$field_title.'</label>';
				}
				$output .= '<textarea id="'.$field_name.'" name="'.$field_name.'" class="'.$custom_class.'" placeholder="'.$field_title.'">'.$field_default.'</textarea>';
				if ( $field_description != '' || ( $field_settings['required'] == 'yes' && $field_required_message != '' ) ) {
					$output .= '<div class="db-field-meta">';
						if ( $field_description != '' ) {
							$output .= '<span class="db-field-row-description">'.$field_description.'</span>';
						}
						if ( $field_settings['required'] == 'yes' && $field_required_message != '' && !is_admin() ) {
							$output .= '<span class="db-field-row-required">'.$field_required_message.'</span>';
						}
					$output .= '</div>';
				}
			$output .= '
			</div>';
			break;

		case 'checkbox':
			$output .= '
			<div class="db-field-row'.$field_required.' checkbox-label">';
			global $post;
				if ( has_shortcode( $post->post_content, 'directory_add_listing' ) ) {
					$is_checked = ($field_default==$field_settings['checkbox_true']||$field_default=='true'?true:false);
				} else {
					$is_checked = ($field_default=='true'?true:false);
				}
				$output .= '<input type="checkbox" id="'.$field_name.'" name="'.$field_name.'" class="'.$custom_class.'" value="true"'.($is_checked?' checked':'').'>';
				if ( $field_title != '' ) {
					$output .= '<label class="db-field-row-label'.($is_checked?' active':'').'" for="'.$field_name.'">'.$field_title.'</label>';
				}
				$output .= '<div class="clearfix"></div>';
				if ( $field_description != '' || ( $field_settings['required'] == 'yes' && $field_required_message != '' ) ) {
					$output .= '<div class="db-field-meta">';
						if ( $field_description != '' ) {
							$output .= '<span class="db-field-row-description">'.$field_description.'</span>';
						}
						if ( $field_settings['required'] == 'yes' && $field_required_message != '' && !is_admin() ) {
							$output .= '<span class="db-field-row-required">'.$field_required_message.'</span>';
						}
					$output .= '</div>';
				}
			$output .= '
			</div>';
			break;

		case 'radio':
			$radio_options = $field_settings['radio_options'];
			$radio_values = explode(',', $radio_options);

			$output .= '
			<div class="db-field-row'.$field_required.' default-label radio">';
				if ( $field_title != '' ) {
					$output .= '<label class="db-field-row-label">'.$field_title.'</label>';
				}
				if ( !empty($radio_values) ) {
					foreach ($radio_values as $radio_value) {
						$is_checked = (isset($field_default['0'])&&$field_default['0']==$radio_value?' checked':'');
						$output .= '<label class="db-radio-label"><input type="radio" name="'.$field_name.'[]" class="'.$custom_class.'" value="'.$radio_value.'"'.$is_checked.'>'.$radio_value.'</label>';
					}
				}
				if ( $field_description != '' || ( $field_settings['required'] == 'yes' && $field_required_message != '' ) ) {
					$output .= '<div class="db-field-meta">';
						if ( $field_description != '' ) {
							$output .= '<span class="db-field-row-description">'.$field_description.'</span>';
						}
						if ( $field_settings['required'] == 'yes' && $field_required_message != '' && !is_admin() ) {
							$output .= '<span class="db-field-row-required">'.$field_required_message.'</span>';
						}
					$output .= '</div>';
				}
			$output .= '
			</div>';
			break;

		case 'select':
			$select_options = $field_settings['select_options'];
			$select_values = explode(',', $select_options);

				if ( !defined('WHITELAB_CUSTOM_SELECT') || is_admin() ) {
					$output .= '<div class="db-field-row'.$field_required.'">';
					if ( $field_title != '' ) {
						$output .= '<label class="db-field-row-label">'.$field_title.'</label>';
					}
					if ( !empty($select_values) ) {
						$output .= '<select class="'.$custom_class.'" name="'.$field_name.'">';
						if ( !in_array($field_default, $select_values) ) {
							$select_values[] = $field_default;
						}
						foreach ($select_values as $select_value) {
							$select_data = explode(':', $select_value);
							$is_selected = ($select_data['0']==$field_default?' selected':'');
							$output .= '<option value="'.$select_data['0'].'"'.$is_selected.'>'.(isset($select_data['1'])?$select_data['1']:$select_data['0']).'</option>';
						}
						$output .= '</select>';
					}
					if ( $field_description != '' || ( $field_settings['required'] == 'yes' && $field_required_message != '' ) ) {
						$output .= '<div class="db-field-meta">';
							if ( $field_description != '' ) {
								$output .= '<span class="db-field-row-description">'.$field_description.'</span>';
							}
							if ( $field_settings['required'] == 'yes' && $field_required_message != '' && !is_admin() ) {
								$output .= '<span class="db-field-row-required">'.$field_required_message.'</span>';
							}
						$output .= '</div>';
					}
				} else {
					$output .= '
					<div class="db-field-row'.$field_required.' custom-select">';
					if ( $field_title != '' ) {
						// $output .= '<label class="db-field-row-label">'.$field_title.'</label>';
					}

					$active_values = (isset($_GET[$field_name])?explode(',', sanitize_text_field($_GET[$field_name])):array( $field_default ));
					$active_value_shown = $active_value_hidden = '';
					if ( !empty($active_values) ) {
						$active_value_shown = implode(', ', $active_values);
						$active_value_hidden = implode(',', $active_values);
					}

					$output .= '
					<input type="text" class="dt-custom-select" placeholder="'.$field_title.'" value="'.$active_value_shown.'" readonly>
					<input type="hidden" class="'.$custom_class.'" name="'.$field_name.'" id="dt-search-search_category" value="'.$active_value_hidden.'">
					<div class="dt-custom-select-container">';
						$output .= '
						<div class="dt-custom-select-inner">
							<div class="dt-custom-select-search"><input type="text" placeholder="'.__('Search', 'directory-builder').'"></div>
							<div class="dt-custom-select-items">';
								if ( !empty($select_values) ) {
									foreach ($select_values as $select_value) {
										$select_data = explode( ':', $select_value );
										$selected_values = explode( ',', $field_default );
										$is_selected = (in_array($select_data['0'], $selected_values)?' active':'');
										$output .= '<div class="dt-custom-select-item'.$is_selected.'" data-value="'.$select_data['0'].'">'.(isset($select_data['1'])?$select_data['1']:$select_data['0']).'</div>';
									}
								}
							$output .= '
							</div>
							<div class="dt-custom-select-scrollbar-wrapper">
								<span class="dt-custom-select-scrollbar"></span>
							</div>
						</div>';
					$output .= '
					</div>';
					if ( $field_description != '' || ( $field_settings['required'] == 'yes' && $field_required_message != '' ) ) {
						$output .= '<div class="db-field-meta">';
							if ( $field_description != '' ) {
								$output .= '<span class="db-field-row-description">'.$field_description.'</span>';
							}
							if ( $field_settings['required'] == 'yes' && $field_required_message != '' && !is_admin() ) {
								$output .= '<span class="db-field-row-required">'.$field_required_message.'</span>';
							}
						$output .= '</div>';
					}
				}
			$output .= '
			</div>';
			break;

		case 'multi-select':
			$select_options = $field_settings['select_options'];
			$select_values = preg_split("/\\r\\n|\\r|\\n/", $select_options);

			if ( !defined('WHITELAB_CUSTOM_SELECT') || is_admin() ) {
				$output .= '<div class="db-field-row'.$field_required.'">';
				if ( $field_title != '' ) {
					$output .= '<label class="db-field-row-label">'.$field_title.'</label>';
				}
				if ( !empty($select_values) ) {
					$output .= '<select class="'.$custom_class.'" name="'.$field_name.'[]" multiple>';
					foreach ($select_values as $select_value) {
						$select_data = explode(':', $select_value);
						if ( is_array($field_default) ) {
							$selected_values = $field_default;
						} else {
							$selected_values = explode( ',', $field_default );
						}

						$is_selected = (in_array($select_data['0'], $selected_values)?' selected':'');
						$output .= '<option value="'.$select_data['0'].'"'.$is_selected.'>'.(isset($select_data['1'])?$select_data['1']:$select_data['0']).'</option>';
					}
					$output .= '</select>';
				}
				if ( $field_description != '' || ( $field_settings['required'] == 'yes' && $field_required_message != '' ) ) {
					$output .= '<div class="db-field-meta">';
						if ( $field_description != '' ) {
							$output .= '<span class="db-field-row-description">'.$field_description.'</span>';
						}
						if ( $field_settings['required'] == 'yes' && $field_required_message != '' && !is_admin() ) {
							$output .= '<span class="db-field-row-required">'.$field_required_message.'</span>';
						}
					$output .= '</div>';
				}
			} else {
				$output .= '
				<div class="db-field-row'.$field_required.' custom-select">';
				$active_values = (isset($_GET[$field_name])?explode(',', sanitize_text_field($_GET[$field_name])):(is_array($field_default)?$field_default:explode(',', $field_default)));
				$active_value_shown = $active_value_hidden = '';
				if ( !empty($active_values) ) {
					// $active_value_shown = implode(', ', $active_values);
					$active_value_hidden = implode(',', $active_values);

					$all_select_data = explode( '||', str_replace("\n", '||', $field_settings['select_options']) );
					$all_select_options = array();
					foreach ($all_select_data as $select_value) {
						$select_value_exploded = explode(':', $select_value);
						$all_select_options[$select_value_exploded['0']] = $select_value_exploded['1'];
					}

					$active_shown_values = array();
					if ( $active_values['0'] != '' ) {
						foreach ($active_values as $active_value) {
							$active_shown_values[] = $all_select_options[$active_value];
						}
					}

					$active_value_shown = implode( ', ', $active_shown_values );
				}

				$output .= '
				<input type="text" class="dt-custom-select" placeholder="'.$field_title.'" value="'.$active_value_shown.'" readonly>
				<input type="hidden" class="'.$custom_class.'" name="'.$field_name.'" id="dt-search-search_category" value="'.$active_value_hidden.'">
				<div class="dt-custom-select-container">';
					$output .= '
					<div class="dt-custom-select-inner">
						<div class="dt-custom-select-search"><input type="text" placeholder="'.__('Search', 'directory-builder').'"></div>
						<div class="dt-custom-select-items">';
							if ( !empty($select_values) ) {
								foreach ($select_values as $select_value) {
									$select_data = explode( ':', $select_value );
									$selected_values = (is_array($field_default)?$field_default:explode( ',', $field_default ));
									$is_selected = (in_array($select_data['0'], $selected_values)?' active':'');
									$output .= '<div class="dt-custom-select-item'.$is_selected.'" data-value="'.$select_data['0'].'">'.(isset($select_data['1'])?$select_data['1']:$select_data['0']).'</div>';
								}
							}
						$output .= '
						</div>
						<div class="dt-custom-select-scrollbar-wrapper">
							<span class="dt-custom-select-scrollbar"></span>
						</div>
					</div>';
				$output .= '
				</div>';
				if ( $field_description != '' || ( $field_settings['required'] == 'yes' && $field_required_message != '' ) ) {
					$output .= '<div class="db-field-meta">';
						if ( $field_description != '' ) {
							$output .= '<span class="db-field-row-description">'.$field_description.'</span>';
						}
						if ( $field_settings['required'] == 'yes' && $field_required_message != '' && !is_admin() ) {
							$output .= '<span class="db-field-row-required">'.$field_required_message.'</span>';
						}
					$output .= '</div>';
				}
			}
			$output .= '
			</div>';
			break;

		case 'file-upload':
			$allowed_types = (!empty($field_settings['allowed_types'])&&$field_settings['allowed_types']['0']!='*'?' accept="'.implode(',', $field_settings['allowed_types']).'"':'');

			$output .= '
			<div class="db-field-row'.$field_required.'">';
				if ( $field_title != '' ) {
					$output .= '<label class="db-field-row-label" for="'.$field_name.'">'.$field_title.'</label>';
				}
				$output .= '<input type="button" id="'.$field_name.'" class="db-upload-file" value="Upload file">
				<input type="hidden" name="'.$field_name.'" class="'.$custom_class.'" value="'.$field_default.'">'.$field_default;
				if ( $field_description != '' || ( $field_settings['required'] == 'yes' && $field_required_message != '' ) ) {
					$output .= '<div class="db-field-meta">';
						if ( $field_description != '' ) {
							$output .= '<span class="db-field-row-description">'.$field_description.'</span>';
						}
						if ( $field_settings['required'] == 'yes' && $field_required_message != '' && !is_admin() ) {
							$output .= '<span class="db-field-row-required">'.$field_required_message.'</span>';
						}
					$output .= '</div>';
				}
			$output .= '
			</div>';
			break;

		case 'date':
			$output .= '
			<div class="db-field-row'.$field_required.'">';
				if ( $field_title != '' ) {
					$output .= '<label class="db-field-row-label" for="'.$field_name.'">'.$field_title.'</label>';
				}
				$output .= '<input type="date" id="'.$field_name.'" name="'.$field_name.'" class="'.$custom_class.'" placeholder="'.$field_title.'" value="'.$field_default.'">';
				if ( $field_description != '' || ( $field_settings['required'] == 'yes' && $field_required_message != '' ) ) {
					$output .= '<div class="db-field-meta">';
						if ( $field_description != '' ) {
							$output .= '<span class="db-field-row-description">'.$field_description.'</span>';
						}
						if ( $field_settings['required'] == 'yes' && $field_required_message != '' && !is_admin() ) {
							$output .= '<span class="db-field-row-required">'.$field_required_message.'</span>';
						}
					$output .= '</div>';
				}
			$output .= '
			</div>';
			break;

		case 'time':
			$output .= '
			<div class="db-field-row'.$field_required.'">';
				if ( $field_title != '' ) {
					$output .= '<label class="db-field-row-label" for="'.$field_name.'">'.$field_title.'</label>';
				}
				$output .= '<input type="time" id="'.$field_name.'" name="'.$field_name.'" class="'.$custom_class.'" placeholder="'.$field_title.'" value="'.$field_default.'">';
				if ( $field_description != '' || ( $field_settings['required'] == 'yes' && $field_required_message != '' ) ) {
					$output .= '<div class="db-field-meta">';
						if ( $field_description != '' ) {
							$output .= '<span class="db-field-row-description">'.$field_description.'</span>';
						}
						if ( $field_settings['required'] == 'yes' && $field_required_message != '' && !is_admin() ) {
							$output .= '<span class="db-field-row-required">'.$field_required_message.'</span>';
						}
					$output .= '</div>';
				}
			$output .= '
			</div>';
			break;

		case 'email':
			$output .= '
			<div class="db-field-row'.$field_required.'">';
				if ( $field_title != '' ) {
					$output .= '<label class="db-field-row-label" for="'.$field_name.'">'.$field_title.'</label>';
				}
				$output .= '<input type="email" id="'.$field_name.'" name="'.$field_name.'" class="'.$custom_class.'" placeholder="'.$field_title.'" value="'.$field_default.'">';
				if ( $field_description != '' || ( $field_settings['required'] == 'yes' && $field_required_message != '' ) ) {
					$output .= '<div class="db-field-meta">';
						if ( $field_description != '' ) {
							$output .= '<span class="db-field-row-description">'.$field_description.'</span>';
						}
						if ( $field_settings['required'] == 'yes' && $field_required_message != '' && !is_admin() ) {
							$output .= '<span class="db-field-row-required">'.$field_required_message.'</span>';
						}
					$output .= '</div>';
				}
			$output .= '
			</div>';
			break;

		case 'url':
			$output .= '
			<div class="db-field-row'.$field_required.'">';
				if ( $field_title != '' ) {
					$output .= '<label class="db-field-row-label" for="'.$field_name.'">'.$field_title.'</label>';
				}
				$output .= '<input type="url" id="'.$field_name.'" name="'.$field_name.'" class="'.$custom_class.'" placeholder="'.$field_title.'" value="'.$field_default.'">';
				if ( $field_description != '' || ( $field_settings['required'] == 'yes' && $field_required_message != '' ) ) {
					$output .= '<div class="db-field-meta">';
						if ( $field_description != '' ) {
							$output .= '<span class="db-field-row-description">'.$field_description.'</span>';
						}
						if ( $field_settings['required'] == 'yes' && $field_required_message != '' && !is_admin() ) {
							$output .= '<span class="db-field-row-required">'.$field_required_message.'</span>';
						}
					$output .= '</div>';
				}
			$output .= '
			</div>';
			break;

		case 'html':
			$output .= '
			<div class="db-field-row'.$field_required.'">';
				if ( $field_title != '' ) {
					$output .= '<label class="db-field-row-label" for="'.$field_name.'">'.$field_title.'</label>';
				}
				$output .= '<textarea id="'.$field_name.'" name="'.$field_name.'" class="'.$custom_class.'">'.$field_default.'</textarea>';
				if ( $field_description != '' || ( $field_settings['required'] == 'yes' && $field_required_message != '' ) ) {
					$output .= '<div class="db-field-meta">';
						if ( $field_description != '' ) {
							$output .= '<span class="db-field-row-description">'.$field_description.'</span>';
						}
						if ( $field_settings['required'] == 'yes' && $field_required_message != '' && !is_admin() ) {
							$output .= '<span class="db-field-row-required">'.$field_required_message.'</span>';
						}
					$output .= '</div>';
				}
			$output .= '
			</div>';
			break;

		case 'hoursofoperation':
			$hop_values = explode('|', $field_default);
			$output .= '
			<div class="db-field-row db-hop-times-row'.$field_required.' clearfix">';
				if ( $field_title != '' ) {
					$output .= '<label class="db-field-row-label" for="'.$field_name.'">'.$field_title.'</label>';
				}
				$output .= '<label class="db-radio-label'.(isset($hop_values['0'])&&$hop_values['0']=='always'?' active': '').'"><input type="radio" name="hop-type[]" class="'.$field_name.'_type" class="'.$custom_class.'" value="always"'.(isset($hop_values['0'])&&$hop_values['0']=='always'?' checked': '').'>'.__('Always open', 'directory-builder').'</label>';
				$output .= '<label class="db-radio-label'.(isset($hop_values['0'])&&$hop_values['0']=='custom'?' active': '').'"><input type="radio" name="hop-type[]" class="'.$field_name.'_type" class="'.$custom_class.'" value="custom"'.(isset($hop_values['0'])&&$hop_values['0']=='custom'?' checked': '').'>'.__('Open in specific hours', 'directory-builder').'</label>';
				if ( isset($hop_values['0']) && $hop_values['0'] == 'custom' ) {
					$show_button = 'style="display: inline-none;"';
				} else {
					$show_button = 'style="display: none;"';
				}
				$output .= '
				<div class="db-custom-hop-times">
					<div class="db-hop-time-container" '.(!isset($hop_values['1'])?'style="display: none;"':'').'>
						<input type="hidden" name="'.$field_name.'" value="'.$field_default.'">';
						if ( isset($hop_values['1']) && $hop_values['1'] != '' ) {
							unset($hop_values['0']);
							foreach ($hop_values as $hop_key => $hop_value) {
								if ( $hop_value != '' ) {
									$hop_data = explode('==', $hop_value);
									$hop_days = str_replace('--', ' - ', $hop_data['0']);
									$hop_times = str_replace('-', ' - ', $hop_data['1']);
									
									$output .= '
									<div class="db-hop-day-row">
										<span class="db-hop-day-names">'.$hop_days.'</span>
										<span class="db-hop-day-times">'.$hop_times.'</span>
										<span class="db-hop-remove dbicon-cancel"></span>
									</div>';
								}
							}
						}
					$output .= '	
					</div>
					<a href="javascript:void(0)" class="db-add-new-hop button button-primary button-large" '.$show_button.'>'.__('Add hours', 'directory-builder').'</a>
					<div class="db-hop-dialog main-card" style="display: none;">
						<div class="db-hop-dialog-inner">
							<div class="db-hop-left">
								<label class="db-checkbox-label"><input type="checkbox" name="custom-hop-day[]" class="'.$custom_class.'" value="mon">'.__('Mon', 'directory-builder').'</label>
								<label class="db-checkbox-label"><input type="checkbox" name="custom-hop-day[]" class="'.$custom_class.'" value="tue">'.__('Tue', 'directory-builder').'</label>
								<label class="db-checkbox-label"><input type="checkbox" name="custom-hop-day[]" class="'.$custom_class.'" value="wed">'.__('Wed', 'directory-builder').'</label>
								<label class="db-checkbox-label"><input type="checkbox" name="custom-hop-day[]" class="'.$custom_class.'" value="thu">'.__('Thu', 'directory-builder').'</label>
								<label class="db-checkbox-label"><input type="checkbox" name="custom-hop-day[]" class="'.$custom_class.'" value="fri">'.__('Fri', 'directory-builder').'</label>
								<label class="db-checkbox-label"><input type="checkbox" name="custom-hop-day[]" class="'.$custom_class.'" value="sat">'.__('Sat', 'directory-builder').'</label>
								<label class="db-checkbox-label"><input type="checkbox" name="custom-hop-day[]" class="'.$custom_class.'" value="sun">'.__('Sun', 'directory-builder').'</label>
							</div>
							<div class="db-hop-right">
								<div class="db-hop-row clearfix">
									'.__('From:', 'directory-builder').' <input type="text" class="db-hop-from">
								</div>
								<div class="db-hop-row clearfix">
									'.__('Till:', 'directory-builder').' <input type="text" class="db-hop-till">
								</div>
								<a href="javascript:void(0)" class="db-hop-add-time button button-primary button-large">'.__('Add', 'directory-builder').'</a>
							</div>
							<div class="clearfix"></div>
						</div>
					</div>
				</div>';
				if ( $field_description != '' || ( $field_settings['required'] == 'yes' && $field_required_message != '' ) ) {
					$output .= '<div class="db-field-meta">';
						if ( $field_description != '' ) {
							$output .= '<span class="db-field-row-description">'.$field_description.'</span>';
						}
						if ( $field_settings['required'] == 'yes' && $field_required_message != '' && !is_admin() ) {
							$output .= '<span class="db-field-row-required">'.$field_required_message.'</span>';
						}
					$output .= '</div>';
				}
			$output .= '
			</div>';
			break;
		
		default:
			$output = '';
			break;
	}

	return $output;
}

function db_search_shortcode() {
	$main_settings = get_option( 'db_main_settings');
	$search_position = $main_settings['search_position'];

	if ( isset($_GET['mapontop']) ) {
		$search_position = 'bottom';
	}
	$search_fields = $main_settings['search_fields'];
	$search_layout = $main_settings['search_layout'];
	$search_layout = json_decode($search_layout, true);

	$output = '
	<div class="db-main-wrapper">';
		$output .= '<div class="db-search-side-one '.$search_position.'">';
			$output .= '<div id="db-main-search-map" style="width: 100%;height: 500px;"></div>';
		$output .= '</div>';
		$output .= '
		<div class="db-search-side-two '.$search_position.'">';
		$output .= '
			<div class="db-main-search">';
				if ( in_array('listing_name', $search_fields) && !isset($search_layout) ) {
					$output .= '<input type="text" class="db-search-listing_name" placeholder="'.__('Listing name', 'directory-builder').'" value="'.(isset($_GET['listing_name'])?sanitize_text_field($_GET['listing_name']):'').'">';
				}
				$output .= '
				<div class="clearfix"></div>';
				global $wpdb;
				$field_list = $wpdb->get_results('SELECT * FROM '.$wpdb->prefix.'directory_fields WHERE field_active="yes" ORDER BY field_order DESC');
				if ( !empty($field_list) ) {
					$output .= '<div class="db-search-custom-fields clearfix">';
					
					if ( !isset($search_layout) ) {
						foreach ($field_list as $field_value) {
							$field_settings = json_decode($field_value->field_settings, true);
							if ( in_array($field_settings['field_name'], $search_fields) ) {
								$field_value = (isset($_GET[$field_settings['field_name']])?sanitize_text_field($_GET[$field_settings['field_name']]):'');

								if ( $field_settings['field_name'] == 'listing_address' && $main_settings['search_radius_status'] == 'yes' ) {
									$output .= '<div class="db-address-row">';
								}

								$output .= db_get_custom_field( $field_settings, 'db-search-'.$field_settings['field_name'], $field_value );

								if ( $field_settings['field_name'] == 'listing_address' && $main_settings['search_radius_status'] == 'yes' ) {
									$output .= '
									<div class="db-field-row db-slider-field-wrapper">
										<label class="db-field-row-label" for="listing_search_radius">'.__('Search radius', 'directory-builder').' ('.($main_settings['search_radius_value']=='km'?__('Kilometers', 'directory-builder'):__('Miles', 'directory-builder')).')</label>
										<div class="db-slider-field" data-value=" '.($main_settings['search_radius_value']=='km'?__('km', 'directory-builder'):__('miles', 'directory-builder')).'">
											<span class="db-slider-left"></span>
											<input type="text" id="listing_search_radius" class="db-search-listing_search_radius" value="'.(isset($_GET['listing_search_radius'])?intval($_GET['listing_search_radius']):'100').'">
										</div>
									</div>';
									$output .= '</div>';
								}
							}
						}
					} else {
						$all_fields = array();
						foreach ($field_list as $field_value) {
							$field_settings = json_decode($field_value->field_settings, true);
							if ( in_array($field_settings['field_name'], $search_fields) ) {
								$all_fields[$field_settings['field_name']] = $field_settings;
							}
						}

						if ( !empty($search_layout) ) {
							foreach ($search_layout as $field_row) {
								$output .= '<div class="db-search-row clearfix">';
									foreach ($field_row as $field_name) {
										$field_value = (isset($_GET[$field_name])?sanitize_text_field($_GET[$field_name]):'');

										if ( $field_name == 'listing_name' ) {
											$output .= '
											<div class="db-field-row">
												<label class="db-field-row-label" for="listing_address">'.__('Listing name', 'directory-builder').'</label>
												<input type="text" class="db-search-listing_name" placeholder="'.__('Listing name', 'directory-builder').'" value="'.(isset($_GET['listing_name'])?sanitize_text_field($_GET['listing_name']):'').'">
											</div>';
										} else if ( $field_name == 'search_radius' && $main_settings['search_radius_status'] == 'yes' ) {
											$output .= '
											<div class="db-field-row db-slider-field-wrapper">
												<label class="db-field-row-label" for="listing_search_radius">'.__('Search radius', 'directory-builder').' ('.($main_settings['search_radius_value']=='km'?__('Kilometers', 'directory-builder'):__('Miles', 'directory-builder')).')</label>
												<div class="db-slider-field" data-value=" '.($main_settings['search_radius_value']=='km'?__('km', 'directory-builder'):__('miles', 'directory-builder')).'">
													<span class="db-slider-left"></span>
													<input type="text" id="listing_search_radius" class="db-search-listing_search_radius" data-default="'.$main_settings['search_radius_distance'].'" value="'.(isset($_GET['listing_search_radius'])?intval($_GET['listing_search_radius']):$main_settings['search_radius_distance']).'">
												</div>
											</div>';
										} else if ( $field_name == 'search_radius' && $main_settings['search_radius_status'] != 'yes' ) {
											continue;
										} else if ( $field_name == 'listing_categories' ) {
											$term_settings = array(
												'taxonomy' => 'listing_category',
												'hide_empty' => $main_settings['hide_empty_categories'],
												'order' => $main_settings['category_list_sort'],
												'orderby' => $main_settings['category_list_order']
											);
											$terms = get_terms( $term_settings );

											if ( !is_wp_error($terms) ) {
												if ( !defined('WHITELAB_CUSTOM_SELECT') ) {
													$output .= '<div class="db-search-categories"><ul>';
													foreach ($terms as $category_value) {
														if ( $category_value->parent == 0 ) {
															$category_count = ($main_settings['category_post_count']===true?'<span class="db-category-count">('.$category_value->count.')</span>':'');
															$onload = (isset($clickable_category)&&$clickable_category==$category_value->term_id?'onload':'');
															$output .= '<li>
																	<a href="javascript:void(0)" class="'.$onload.'" data-term-id="'.$category_value->term_id.'">'.$category_value->name.'</a>'.$category_count;
																	if ( $main_settings['only_parent_categories'] === false ) {
																		$term_settings['child_of'] = $category_value->term_id;
																		$child_terms = get_terms( $term_settings );
																		if ( !empty($child_terms) ) {
																			$output .= '<ul>';
																			foreach ($child_terms as $child_value) {
																				$onload = ($clickable_category&&$clickable_category==$child_value->term_id?'onload':'');
																				$category_count = ($main_settings['category_post_count']===true?'<span class="db-category-count">('.$child_value->count.')</span>':'');
																				$output .= '<li><a href="javascript:void(0)" class="'.$onload.'" data-term-id="'.$child_value->term_id.'">'.$child_value->name.'</a>'.$category_count.'</li>';
																			}
																			$output .= '</ul>';
																		}
																	}
																$output .= '    
																</li>';
														}
														
													}
													$output .= '</ul></div>';
												} else {
													$active_categories = (isset($_GET['search_category'])?explode(',', sanitize_text_field($_GET['search_category'])):array());
													$active_placeholder = '';
													if ( empty($active_categories) ) {
														$active_placeholder = '';
													} else {
														foreach ($terms as $cat_data) {
															if ( in_array($cat_data->term_id, $active_categories) ) {
																$active_placeholder .= $cat_data->name.', ';
															}
														}
														$active_placeholder = substr($active_placeholder, 0, -2);
													}
													$output .= '
													<div class="db-field-row db-search-categories custom-select">
														<input type="text" class="dt-custom-select" placeholder="'.esc_html__( 'Category', 'directory-builder' ).'" value="'.$active_placeholder.'" readonly>
														<input type="hidden" class="dt-custom-select-value" id="db-search-search_category" value="'.implode(',', $active_categories).'">
														<div class="dt-custom-select-container">';
															$output .= '
															<div class="dt-custom-select-inner">
																<div class="dt-custom-select-search"><input type="text" placeholder="Search"></div>
																<div class="dt-custom-select-items">';
																	foreach ($terms as $category_data) {
																		$output .= '
																		<div class="dt-custom-select-item '.(in_array($category_data->term_id, $active_categories)?'active':'').'" data-value="'.$category_data->term_id.'">'.$category_data->name.'</div>';
																	}
																$output .= '
																</div>
																<div class="dt-custom-select-scrollbar-wrapper">
																	<span class="dt-custom-select-scrollbar"></span>
																</div>
															</div>';
														$output .= '
														</div>
													</div>';
												}
											}
										} else {
											$output .= db_get_custom_field( $all_fields[$field_name], 'db-search-'.$field_name, $field_value );
										}
									}
								$output .= '</div>';
							}
						}
					}
					if ( isset($_GET['mapontop']) ) {
						$output .= '<input type="hidden" id="db-search-mapontop" value="true">';
					}
					$output .= '</div>';
				}

				$onload_click = $clickable_category = '';
				$get_variables = $_GET;
				unset($get_variables['page_id']);

				if ( !isset($_GET['search_category']) && !empty($get_variables) ) {
					$onload_click = ' onload';
				} else if ( isset($_GET['search_category']) ) {
					$clickable_category = sanitize_text_field($_GET['search_category']);
				}

				$output .= '
				<div class="clearfix"></div>
				<a href="javascript:void(0)" class="db-find-listings onload">'.__('Search', 'directory-builder').'</a>
			</div>';
			$custom_sorting = whitelab_get_listing_custom_fields( '', 'on_sorting' );
			if ( !defined('WHITELAB_CUSTOM_SELECT') ) {
				$output .= __('Sort by:', 'directory-builder').'
				<select class="db-search-sort">
					<option value="name">Name</option>
					<option value="date">Date</option>
					<option value="rating">Rating</option>';
					foreach ($custom_sorting as $field_name => $field_data) {
						$output .= '<option value="'.$field_name.'">'.$field_data['title'].'</option>';
					}
				$output .= '
				</select>';
			} else {
				$output .= '
				<div class="db-search-sort-container">
					<span class="db-found-count" data-found="0"> '.__('results', 'directory-builder').'</span>
					<div class="dt-sort-row single-select">
						<input type="text" class="dt-custom-select"  placeholder="'.__('Sort', 'directory-builder').'" readonly>
						<input type="hidden" class="dt-custom-select-value" id="db-search-sort">
						<div class="dt-custom-select-container">
							<div class="dt-custom-select-inner">
								<div class="dt-custom-select-items">
									<div class="dt-custom-select-item" data-value="name">Name</div>
									<div class="dt-custom-select-item" data-value="date">Date</div>
									<div class="dt-custom-select-item" data-value="rating">Rating</div>';
									foreach ($custom_sorting as $field_name => $field_data) {
										$output .= '<div class="dt-custom-select-item" data-value="'.$field_name.'">'.$field_data['title'].'</div>';
									}
								$output .= '
								</div>
								<div class="dt-custom-select-scrollbar-wrapper">
									<span class="dt-custom-select-scrollbar"></span>
								</div>
							</div>
						</div>
					</div>
					<div class="clearfix"></div>
				</div>';
			}
			$output .= '
			<div class="clearfix"></div>
			<div class="db-main-search-listings loading"></div>
		</div>';
	$output .= '
		<div class="clearfix"></div>
	</div>';

	return $output;
}
add_shortcode('directory_listings','db_search_shortcode');

// function db_check_listing_status( $post ) {
	// if ( get_post_type( $post['0']->ID ) == 'listings' && get_post_status( $post['0']->ID ) == 'publish' ) {
		// $order_data = get_post_meta( $post['0']->ID, 'db_order_info', true );

		// if ( isset($order_data['listing_expires']) && is_numeric($order_data['listing_expires']) && time() > $order_data['listing_expires'] ) {
		// 	wp_update_post( array( 'ID' => $post['0']->ID, 'post_status' => 'draft' ) );
		// }
	// }
// }
// add_action( 'posts_results', 'db_check_listing_status', 10, 1 );

function db_search_for_listings() {
	$output = '';
	$search_terms = ( isset($_POST['search_terms']) ? json_decode(stripslashes(sanitize_text_field($_POST['search_terms'])), true) : '' );
	$db_full_url = ( isset($_POST['db_full_url']) ? esc_url($_POST['db_full_url']) : '' );
	$db_parsed_url = parse_url( $db_full_url );
	$db_url_base = $db_parsed_url['scheme'].'://'.$db_parsed_url['host'].$db_parsed_url['path'];

	if ( !isset($search_terms['listing_address']) || ( isset($search_terms['listing_address']) && $search_terms['listing_address'] == '' ) ) {
		unset($search_terms['listing_search_radius']);
	}

	if ( strpos($db_full_url, 'amenities=') !== false ) { // Add amenities to the search parameters
		$url_parts = parse_url( $_POST['db_full_url'] );
		parse_str($url_parts['query'], $url_query);
		$search_terms['amenities'] = $url_query['amenities'];
	}

	if ( get_option('permalink_structure') ) {
		$db_new_url = $base_url.'?'.http_build_query($search_terms);
	} else {
		$url_params = explode('&', $db_parsed_url['query']);
		foreach ( $url_params as $url_value ) {
			$get_part = explode('=', $url_value);
			if ( $get_part['0'] == 'page_id' ) {
				$search_terms['page_id'] = $get_part['1'];
			}
		}

		$db_new_url = $base_url.'?'.http_build_query($search_terms);
		unset($search_terms['page_id']);
	}
	unset($search_terms['mapontop']);

	$all_listings = array();
	$all_markers = array();

	if ( !empty($search_terms) ) {
		global $wpdb;
		$main_settings = get_option( 'db_main_settings');
		
		$search_where = '';
		if ( isset($search_terms['listing_name']) && !isset($search_terms['search_category']) ) {
			$search_where .= ' && lower(post_title) LIKE "%'.$search_terms['listing_name'].'%"';
			unset($search_terms['listing_name']);
		}
		$search_listings = $wpdb->get_results('SELECT * FROM '.$wpdb->posts.' WHERE post_type="listings" && post_status="publish"'.$search_where);
		$search_distance = (isset($search_terms['listing_search_radius'])?$search_terms['listing_search_radius']:$main_settings['search_radius_distance']);
		unset($search_terms['listing_search_radius']);

		$map_new_center = false;
		if ( !empty($search_listings) ) {
			$field_list = db_get_active_fields();

			if ( isset($search_terms['listing_address']) && $search_terms['listing_address'] != '' ) {
				$search_address_data = db_get_coordinates( $search_terms['listing_address'] );

				$map_new_center = true;
			}

			$listings_matched = 0;
			foreach ($search_listings as $listing_value) {
				$custom_field_data = db_get_listing_custom_values($field_list, $listing_value->ID);
				$listing_value = array_merge((array)$listing_value, $custom_field_data);
				$show_listing = true;
				$listing_visible = false;

				if ( isset($search_terms['listing_address']) && $search_terms['listing_address'] != '' ) {
					if ( $search_address_data['type'] == 'fields' ) {
						if ( $search_address_data['field_type'] == 'country' && strpos($listing_value['listing_country'], $search_address_data['value']) !== false ) {
							$listing_visible = true;
						} else if ( $search_address_data['field_type'] == 'locality' && strpos($listing_value['listing_city'], $search_address_data['value']) !== false ) {
							$listing_visible = true;
						} else {
							$listing_visible = false;
						}
					} else {
						$db_search_distance = db_calculateDistanceFromLatLong($listing_value['listing_address_lat'], $listing_value['listing_address_lng'], $search_address_data['lat'], $search_address_data['lng'], $main_settings['search_radius_value']);

						if ( $main_settings['search_radius_status'] != 'yes' ) {
							$search_distance = '200';
						}
						if ( intval($db_search_distance) > intval($search_distance) ) {
							$listing_visible = false;
						} else {
							$listing_visible = true;
						}
					}

					if ( $listing_visible ) {
						$dist_show_listing = true;
					} else {
						$dist_show_listing = false;
					}
				}

				if ( !empty($search_terms) ) {
					$matched_settings = 0;

					foreach ($search_terms as $search_key => $search_value) {

						if ( isset($search_terms['listing_address']) && $search_terms['listing_address'] != '' && $search_key == 'listing_address' && $dist_show_listing ) {
							$matched_settings++;
							continue;
						}

						if ( $search_key == 'search_category' ) {
							$searched_categories = explode(',', $search_terms['search_category']);
							$has_category = false;
							foreach ($searched_categories as $cat_id) {
								if ( has_term($cat_id, 'listing_category', $listing_value['ID']) ) {
									$has_category = true;
									$matched_settings++;
									break;
								}
							}
							if ( !$has_category ) {
								$show_listing = false;
							}
						} else if ( $search_key == 'listing_name' ) {
							if ( strpos(strtolower($listing_value['post_title']), strtolower($search_value)) !== false ) {
								$show_listing = true;
								$matched_settings++;
							}
						} else if ( $search_key == 'listing_country' ) {
							$searched_countries = explode(',', $search_value);
							foreach ($searched_countries as $country_value) {
								if ( strtolower($country_value) == strtolower($listing_value[$search_key]) ) {
									$show_listing = true;
									$matched_settings++;
									break;
								} else {
									$show_listing = false;
								}
							}
						} else if ( $search_key == 'amenities' ) {
							$amenities_values = (is_array($listing_value[$search_key])?$listing_value[$search_key]:explode(',', $listing_value[$search_key]));
							if ( in_array($search_value, $amenities_values) ) {
								$show_listing = true;
								$matched_settings++;
								break;
							} else {
								$show_listing = false;
							}
						} else {
							if ( strtolower($listing_value[$search_key]) != strtolower($search_value) ) {
								$show_listing = false;
								break;
							} else {
								$matched_settings++;
							}
						}
					}
				}

				if ( $show_listing && $matched_settings == count($search_terms) ) {
					global $db_search_listing_data;
					$db_search_listing_data = $listing_value;

					$listings_matched++;					
					if ( $listings_matched > $main_settings['per_page'] ) {
						break;
					}

					$all_listings[$listing_value['ID']] = db_load_template( 'search-listing-item.php', true, false, $main_settings );
					if ( function_exists('whitelab_get_image_css') ) {
						$listing_category = get_the_terms($db_search_listing_data['ID'], 'listing_category');
						$img = wp_get_attachment_image_src( get_post_thumbnail_id( $db_search_listing_data['ID'] ), 'large' );
						$extra_css = '<style type="text/css">';
							if ( isset($img['0']) ) {
								$extra_css .= '.dt-featured-item-image.id-'.$listing_value['ID'].' { background: url('.$img['0'].') }';
							}
							$listing_category = get_the_terms($db_search_listing_data['ID'], 'listing_category');
							if ( isset($listing_category['0']) ) {
								$cat_meta = get_option( "listing_category_".$listing_category['0']->term_id);
								$tag_color = (isset($cat_meta['tag-category-color'])?$cat_meta['tag-category-color']:'#555');
								$extra_css .= '.dt-featured-listings-category.'.$listing_category['0']->slug.' { color: '.$tag_color.' }';
								$extra_css .= '.dt-featured-listings-category.'.$listing_category['0']->slug.':before { border-color: '.$tag_color.' }';
							}
						$extra_css .= '</style>';
						$all_listings[$listing_value['ID']] .= $extra_css;
					}

					$categories = wp_get_object_terms($listing_value['ID'], 'listing_category');
					$cat_meta = get_option( "listing_category_".$categories['0']->term_id);

					$custom_icon = '';
					if ( isset($cat_meta['tag-category-icon']) ) {
						$custom_icon = $cat_meta['tag-category-icon'];
					}

					$all_markers[] = array($listing_value['listing_address_lat'], $listing_value['listing_address_lng'], $custom_icon, $listing_value['ID']);

				}
			}
		}
	}

	$search_data = array('listing_html' => $all_listings, 'marker_data' => $all_markers, 'new_url' => $db_new_url, 'map_changed' => false );

	if ( empty( $all_markers ) && $map_new_center ) {
		$search_data['map_lat'] = $search_address_data['lat'];
		$search_data['map_lng'] = $search_address_data['lng'];
		$search_data['map_changed'] = true;
	}

	echo json_encode( $search_data );

	die(0);
}
add_action( 'wp_ajax_db_search_listings', 'db_search_for_listings' );
add_action( 'wp_ajax_nopriv_db_search_listings', 'db_search_for_listings' );

function db_get_custom_sorting() {
	$custom_sorting = whitelab_get_listing_custom_fields( '', 'on_sorting' );
	$sort_ints = array( 'number', 'date', 'time', 'phone' );
	$sorting_arr = array( 'name' => '[data-name]', 'date' => '[data-date] parseInt', 'rating' => '[data-rating] parseInt', 'featured' => '[data-featured] parseInt' );

	if ( !empty($custom_sorting) ) {
		foreach ($custom_sorting as $sorting_key => $sorting_value) {
			$sorting_arr[$sorting_key] = '[data-'.$sorting_key.']'.(in_array($sorting_value['type'], $sort_ints)?' parseInt':'');
		}
	}

	return json_encode( $sorting_arr );
}

function db_get_custom_sorting_dir() {
	$custom_sorting = whitelab_get_listing_custom_fields( '', 'on_sorting' );
	$sort_ints = array( 'number', 'date', 'time', 'phone' );
	$sorting_dir_arr = array( 'name' => true, 'date' => false, 'rating' => false, 'featured' => true );

	if ( !empty($custom_sorting) ) {
		foreach ($custom_sorting as $sorting_key => $sorting_value) {
			$sorting_dir_arr[$sorting_key] = (in_array($sorting_value['type'], $sort_ints)?false:true);
		}
	}

	return json_encode( $sorting_dir_arr );
}

function db_get_coordinates( $address ) {
	$address = str_replace(" ", "+", $address);
	$url = "http://maps.google.com/maps/api/geocode/json?sensor=false&address=$address";
	$response = wp_remote_get($url);
	$json = json_decode($response['body'],TRUE);

	if ( ( $json['results'][0]['types']['0'] == 'country' || $json['results'][0]['types']['0'] == 'locality' ) && $json['results'][0]['types']['1'] == 'political' ) {
		return array( 'type' => 'fields', 'field_type' => $json['results'][0]['types']['0'], 'value' => $json['results'][0]['address_components']['0']['long_name'], 'lat' => $json['results'][0]['geometry']['location']['lat'], 'lng' => $json['results'][0]['geometry']['location']['lng'] );
	} else {
		return array( 'type' => 'coordinates', 'lat' => $json['results'][0]['geometry']['location']['lat'], 'lng' => $json['results'][0]['geometry']['location']['lng'] );
	}
}

function db_calculate_distance($lat1, $lon1, $lat2, $lon2, $unit) {
	$theta = $lon1 - $lon2;
	$dist = sin(deg2rad($lat1)) * sin(deg2rad($lat2)) + cos(deg2rad($lat1)) * cos(deg2rad($lat2)) * cos(deg2rad($theta));
	$dist = acos($dist);
	$dist = rad2deg($dist);
	$miles = $dist * 60 * 1.1515;

	if ($unit == 'km') {
		return ($miles * 1.609344);
	} else if ($unit == 'N') {
		return ($miles * 0.8684);
	} else {
		return $miles;
	}
}

function db_getDistanceRadius( $uom = 'km' ) {
	//	Use Haversine formula to calculate the great circle distance between two points identified by longitude and latitude
	switch ( strtolower( $uom ) ):
		case 'km':
			$earthMeanRadius = 6371.009; // km
			break;
		case 'm':
		case 'meters':
			$earthMeanRadius = 6371.009 * 1000; // km
			break;
		case 'miles':
			$earthMeanRadius = 3958.761; // miles
			break;
		case 'yards':
		case 'yds':
			$earthMeanRadius = 3958.761 * 1760; // yards
			break;
		case 'feet':
		case 'ft':
			$earthMeanRadius = 3958.761 * 1760 * 3; // feet
			break;
		case 'nm':
			$earthMeanRadius = 3440.069; //  miles
			break;
		default:
			$earthMeanRadius = 3958.761; // miles
			break;
	endswitch;

	return $earthMeanRadius;
}

function db_calculateDistanceFromLatLong( $loc1_lat, $loc1_lng, $loc2_lat, $loc2_lng, $uom = 'km' ) {
	//	Use Haversine formula to calculate the great circle distance between two points identified by longitude and latitude

	$earthMeanRadius = db_getDistanceRadius( $uom );

	$deltaLatitude  = deg2rad( (float) $loc2_lat - (float) $loc1_lat );
	$deltaLongitude = deg2rad( (float) $loc2_lng - (float) $loc1_lng );
	$a              = sin( $deltaLatitude / 2 ) * sin( $deltaLatitude / 2 ) +
	                  cos( deg2rad( (float) $loc1_lat ) ) * cos( deg2rad( (float) $loc2_lat ) ) *
	                  sin( $deltaLongitude / 2 ) * sin( $deltaLongitude / 2 );
	$c              = 2 * atan2( sqrt( $a ), sqrt( 1 - $a ) );
	$distance       = $earthMeanRadius * $c;

	return $distance;

}

function db_get_active_fields() {
	$meta_values = array(
		'listing_address',
		'listing_address_lat',
		'listing_address_lng'
	);

	global $wpdb;
	$field_list = $wpdb->get_results('SELECT * FROM '.$wpdb->prefix.'directory_fields WHERE field_active="yes" ORDER BY field_order DESC');
	if ( !empty($field_list) ) {
		foreach ($field_list as $field_value) {
			$field_settings = json_decode($field_value->field_settings, true);
			$meta_values[] = $field_settings['field_name'];
		}
	}

	return $meta_values;
}

function db_get_listing_custom_values( $field_list, $post_id ) {
	$field_data = array();
	if ( !empty($field_list) ) {
		foreach ($field_list as $field_name) {
			$custom_field_value = get_post_meta( $post_id, $field_name, true );
			$field_data[$field_name] = ( !is_array( $custom_field_value ) ? sanitize_text_field( $custom_field_value ) : db_sanitize_array( $custom_field_value ) );
			if ( $field_name == 'listing_address' && $field_data[$field_name] == '' ) {
				$field_data[$field_name] = 'London';
			}
			if ( $field_name == 'listing_address_lat' && $field_data[$field_name] == '' ) {
				$field_data[$field_name] = '51.5073509';
			}
			if ( $field_name == 'listing_address_lng' && $field_data[$field_name] == '' ) {
				$field_data[$field_name] = '-0.12775829999998223';
			}
		}
	}
	
	return $field_data;
}

function db_get_active_details_fields() {
	$meta_values = array();

	global $wpdb;
	$field_list = $wpdb->get_results('SELECT * FROM '.$wpdb->prefix.'directory_fields WHERE field_active="yes" ORDER BY field_order DESC');
	if ( !empty($field_list) ) {
		foreach ($field_list as $field_value) {
			$field_settings = json_decode($field_value->field_settings, true);

			if ( $field_settings['on_listing'] == 'yes' ) {
				$meta_values[$field_settings['field_name']] = $field_settings['frontend_title'];
			}
		}
	}

	return $meta_values;
}

function db_settings_html() {
	if ( !current_user_can('manage_options') )  {
		wp_die( __('You do not have sufficient permissions to access this page.', 'directory-builder') );
	}
	$main_settings = get_option( 'db_main_settings');
	?>

	<div class="db-main-wrapper container-fluid" id="db-main-wrapper">
		<div class="db-main-content">
			<div class="db-box-wrapper">
				<div class="db-box-left">
					<div class="db-box-container col-md-12">
						<div class="db-box main-card">
							<div class="db-box-title">
								<h3 class="db-main-title">General settings</h3>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Per page limit at search</span>
									<div class="col-sm-9">
										<input type="number" class="db-settings-per_page" placeholder="Per page limit at search" value="<?php echo $main_settings['per_page']; ?>">
									</div>
								</div>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Include listing contact form on listing page?</span>
									<div class="col-sm-9">
										<div class="db-checkbox <?php echo ($main_settings['contact_form_status']=='true'?'active':''); ?>">
											<input type="checkbox" class="db-settings-contact_form_status" <?php echo ($main_settings['contact_form_status']=='true'?'checked':''); ?>>
										</div>
									</div>
								</div>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Contact form only for registered users?</span>
									<div class="col-sm-9">
										<div class="db-checkbox <?php echo ($main_settings['contact_form_registered']=='true'?'active':''); ?>">
											<input type="checkbox" class="db-settings-contact_form_registered" <?php echo ($main_settings['contact_form_registered']=='true'?'checked':''); ?>>
										</div>
									</div>
								</div>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Maximum contact form submissions per day</span>
									<div class="col-sm-9">
										<input type="number" class="db-settings-contact_form_max" placeholder="0" value="<?php echo $main_settings['contact_form_max']; ?>">
									</div>
								</div>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Include ratings for listings?</span>
									<div class="col-sm-9">
										<div class="db-checkbox <?php echo ($main_settings['listing_ratings']=='true'?'active':''); ?>">
											<input type="checkbox" class="db-settings-listing_ratings" <?php echo ($main_settings['listing_ratings']=='true'?'checked':''); ?>>
										</div>
									</div>
								</div>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Listing status after plugin uninstall</span>
									<div class="col-sm-9">
										<select class="db-settings-after_uninstall">
											<option value="nothing" <?php echo ($main_settings['after_uninstall']=='nothing'?'selected':''); ?>>Do not change</option>
											<option value="draft" <?php echo ($main_settings['after_uninstall']=='draft'?'selected':''); ?>>Draft</option>
											<option value="trash" <?php echo ($main_settings['after_uninstall']=='trash'?'selected':''); ?>>Trash</option>
										</select>
									</div>
								</div>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Listing no image</span>
									<div class="col-sm-9">
										<input type="button" value="Upload image" class="db-image-upload">
										<input type="button" class="db-image-delete" value="Delete image" <?php echo ($main_settings['default_listing_image']==''?'style="display: none;"':''); ?>>
										<div class="db-image-container">
											<?php echo ($main_settings['default_listing_image']!=''?'<img src="'.$main_settings['default_listing_image'].'" alt="">':''); ?>
										</div>
										<input type="hidden" class="db-settings-default_listing_image" value="<?php echo $main_settings['default_listing_image']; ?>">
									</div>
								</div>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Register on "Add listing" page</span>
									<div class="col-sm-9">
										<div class="db-checkbox <?php echo ($main_settings['add_listing_register']=='true'?'active':''); ?>">
											<input type="checkbox" class="db-settings-add_listing_register" <?php echo ($main_settings['add_listing_register']=='true'?'checked':''); ?>>
										</div>
									</div>
								</div>
							</div>
							<?php $all_pages = get_pages(); ?>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Login page</span>
									<div class="col-sm-9">
										<select class="db-settings-login_page_id">
										<?php
											foreach ($all_pages as $page_key => $page_value) {
												$is_selected = ($main_settings['login_page_id']==$page_value->ID?' selected':'');
												echo '<option value="'.$page_value->ID.'"'.$is_selected.'>'.$page_value->post_title.'</option>';
											}
										?>
										</select>
									</div>
								</div>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Listing search page</span>
									<div class="col-sm-9">
										<select class="db-settings-search_page_id">
										<?php
											foreach ($all_pages as $page_key => $page_value) {
												$is_selected = ($main_settings['search_page_id']==$page_value->ID?' selected':'');
												echo '<option value="'.$page_value->ID.'"'.$is_selected.'>'.$page_value->post_title.'</option>';
											}
										?>
										</select>
									</div>
								</div>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Add listing page</span>
									<div class="col-sm-9">
										<select class="db-settings-add_page_id">
										<?php
											foreach ($all_pages as $page_key => $page_value) {
												$is_selected = ($main_settings['add_page_id']==$page_value->ID?' selected':'');
												echo '<option value="'.$page_value->ID.'"'.$is_selected.'>'.$page_value->post_title.'</option>';
											}
										?>
										</select>
									</div>
								</div>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Listing author account page</span>
									<div class="col-sm-9">
										<select class="db-settings-account_page_id">
										<?php
											foreach ($all_pages as $page_key => $page_value) {
												$is_selected = ($main_settings['account_page_id']==$page_value->ID?' selected':'');
												echo '<option value="'.$page_value->ID.'"'.$is_selected.'>'.$page_value->post_title.'</option>';
											}
										?>
										</select>
									</div>
								</div>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Default location</span>
									<div class="col-sm-9">
										<input type="text" class="db-settings-default_location" value="<?php echo $main_settings['default_location']; ?>">
									</div>
								</div>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Google API key</span>
									<div class="col-sm-9">
										<input type="text" class="db-settings-google_key" value="<?php echo $main_settings['google_key']; ?>">
										<span>This key is needed for the google maps, without it google maps can't work.</p>
									</div>
								</div>
							</div>
						</div>
					</div>
					<div class="db-box-container col-md-12">
						<div class="db-box main-card">
							<div class="db-box-title">
								<h3 class="db-main-title">Permalink settings</h3>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Directory listing slug</span>
									<div class="col-sm-9">
										<input type="text" class="db-settings-directory_slug" placeholder="Directory listing slug" value="<?php echo $main_settings['directory_slug']; ?>">
									</div>
								</div>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Directory category slug</span>
									<div class="col-sm-9">
										<input type="text" class="db-settings-category_slug" placeholder="Directory category slug" value="<?php echo $main_settings['category_slug']; ?>">
									</div>
								</div>
							</div>
						</div>
					</div>
					<div class="db-box-container col-md-12">
						<div class="db-box main-card">
							<div class="db-box-title">
								<h3 class="db-main-title">Image settings</h3>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Allow images?</span>
									<div class="col-sm-9">
										<div class="db-checkbox <?php echo ($main_settings['allow_images']=='true'?'active':''); ?>">
											<input type="checkbox" class="db-settings-allow_images" <?php echo ($main_settings['allow_images']=='true'?'checked':''); ?>>
										</div>
									</div>
								</div>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Min image file size (KB)</span>
									<div class="col-sm-9">
										<input type="number" class="db-settings-image_min_size" placeholder="0" value="<?php echo $main_settings['image_min_size']; ?>">
									</div>
								</div>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Max image file size (KB)</span>
									<div class="col-sm-9">
										<input type="number" class="db-settings-image_max_size" placeholder="0" value="<?php echo $main_settings['image_max_size']; ?>">
									</div>
								</div>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Min image width (px)</span>
									<div class="col-sm-9">
										<input type="number" class="db-settings-image_min_width" placeholder="0" value="<?php echo $main_settings['image_min_width']; ?>">
									</div>
								</div>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Max image width (px)</span>
									<div class="col-sm-9">
										<input type="number" class="db-settings-image_max_width" placeholder="0" value="<?php echo $main_settings['image_max_width']; ?>">
									</div>
								</div>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Min image height (px)</span>
									<div class="col-sm-9">
										<input type="number" class="db-settings-image_min_height" placeholder="0" value="<?php echo $main_settings['image_min_height']; ?>">
									</div>
								</div>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Max image height (px)</span>
									<div class="col-sm-9">
										<input type="number" class="db-settings-image_max_height" placeholder="0" value="<?php echo $main_settings['image_max_height']; ?>">
									</div>
								</div>
							</div>
						</div>
					</div>
					<div class="db-box-container col-md-12">
						<div class="db-box main-card">
							<div class="db-box-title">
								<h3 class="db-main-title">User account settings</h3>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Users are allowed to</span>
									<div class="col-sm-9">
										<select class="db-settings-users_are_allowed" multiple>
											<option value="edit" <?php echo (in_array('edit', $main_settings['users_are_allowed'])?'selected':''); ?>>Edit listings</option>
											<option value="delete" <?php echo (in_array('delete', $main_settings['users_are_allowed'])?'selected':''); ?>>Delete listings</option>
										</select>
									</div>
								</div>
							</div>
						</div>
					</div>
				</div>
				<div class="db-box-right">
					<div class="db-box-container col-md-12">
						<div class="db-box main-card">
							<div class="db-box-title">
								<h3 class="db-main-title">Terms and conditions</h3>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Display terms and conditions</span>
									<div class="col-sm-9">
										<div class="db-checkbox <?php echo ($main_settings['terms_and_conditions_status']=='true'?'active':''); ?>">
											<input type="checkbox" class="db-settings-terms_and_conditions_status" <?php echo ($main_settings['terms_and_conditions_status']=='true'?'checked':''); ?>>
										</div>
									</div>
								</div>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Terms and conditions</span>
									<div class="col-sm-9">
										<textarea class="db-settings-terms_and_conditions"><?php echo $main_settings['terms_and_conditions']; ?></textarea>
									</div>
								</div>
							</div>
						</div>
					</div>
					<div class="db-box-container col-md-12">
						<div class="db-box main-card">
							<div class="db-box-title">
								<h3 class="db-main-title">Search settings</h3>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Search form display</span>
									<div class="col-sm-9">
										<select class="db-settings-search_position">
											<option value="left" <?php echo ($main_settings['search_position']=='left'?'selected':''); ?>>Left side</option>
											<option value="right" <?php echo ($main_settings['search_position']=='right'?'selected':''); ?>>Right side</option>
											<option value="bottom" <?php echo ($main_settings['search_position']=='bottom'?'selected':''); ?>>Below map</option>
										</select>
									</div>
								</div>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Include fields in search</span>
									<div class="col-sm-9">
										<select class="db-settings-search_fields" multiple>
											<option value="listing_name" <?php echo (in_array('listing_name', $main_settings['search_fields'])?'selected':''); ?>>Listing name</option>
											<option value="search_radius" <?php echo (in_array('search_radius', $main_settings['search_fields'])?'selected':''); ?>>Search radius</option>
											<option value="listing_categories" <?php echo (in_array('listing_categories', $main_settings['search_fields'])?'selected':''); ?>>Listing categories</option>
											<?php
												global $wpdb;
												$field_list = $wpdb->get_results('SELECT * FROM '.$wpdb->prefix.'directory_fields WHERE field_active="yes" ORDER BY field_order DESC');
												$field_data_list = array( 'listing_name' => 'Listing name', 'search_radius' => 'Search radius', 'listing_categories' => 'Listing categories' );
												if ( !empty($field_list) ) {
													foreach ($field_list as $field_value) {
														$field_settings = json_decode($field_value->field_settings, true);
														if ( $field_settings['field_type'] != 'fileupload' && $field_settings['field_type'] != 'html' ) {
															$is_selected = (in_array($field_settings['field_name'], $main_settings['search_fields'])?'selected':'');
															echo '<option value="'.$field_settings['field_name'].'" '.$is_selected.'>'.$field_settings['frontend_title'].'</option>';
															$field_data_list[$field_settings['field_name']] = $field_settings['frontend_title'];
														}
													}
												}
											?>
										</select>
										<a href="javascript:void(0)" class="db-change-layout db-button db-primary-button">Change field layout</a>
									</div>
								</div>
								<div class="db-search-field-layout-dialog" style="display: none;">
									<a href="javascript:void(0);" class="db-add-new-column db-button db-primary-button">Add row</a>
									<a href="javascript:void(0);" class="db-confirm-layout db-button db-primary-button">Confirm layout</a>
									<input type="hidden" class="db-settings-search_layout" value='<?php echo $main_settings['search_layout']; ?>'>
									<?php
									$search_layout = json_decode($main_settings['search_layout'], true);
									if ( isset($search_layout) && !empty($search_layout) ) {
										foreach ($search_layout as $row_value) {
											echo '<div class="column clearfix">';
											foreach ($row_value as $row_item) {
												echo '<div class="portlet" data-id="'.$row_item.'"><div class="portlet-header">'.$field_data_list[$row_item].'</div></div>';
											}
											echo '</div>';
										}
									} else { ?>
										<div class="column clearfix"></div>
									<?php } ?>
								</div>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Limit search radius</span>
									<div class="col-sm-9">
										<select class="db-settings-search_radius_status">
											<option value="no" <?php echo ($main_settings['search_radius_status']=='no'?'selected':''); ?>>No</option>
											<option value="yes" <?php echo ($main_settings['search_radius_status']=='yes'?'selected':''); ?>>Yes</option>
										</select>
									</div>
								</div>
							</div>
							<div class="db-row db-search-radius-options">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Search radius measurement</span>
									<div class="col-sm-9">
										<select class="db-settings-search_radius_value">
											<option value="km" <?php echo ($main_settings['search_radius_value']=='km'?'selected':''); ?>>Kilometers</option>
											<option value="mil" <?php echo ($main_settings['search_radius_value']=='mil'?'selected':''); ?>>Miles</option>
										</select>
									</div>
								</div>
							</div>
							<div class="db-row db-search-radius-options">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Search radius distance</span>
									<div class="col-sm-9">
										<input type="number" class="db-settings-search_radius_distance" value="<?php echo $main_settings['search_radius_distance']; ?>">
										<span>If search has "Listing address" field added, then while searching by address only listing in a given radius around the search address will be returned.</span>
									</div>
								</div>
							</div>
						</div>
					</div>
					<div class="db-box-container col-md-12">
						<div class="db-box main-card">
							<div class="db-box-title">
								<h3 class="db-main-title">Post/category settings</h3>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">New post status</span>
									<div class="col-sm-9">
										<select class="db-settings-new_post_status">
											<option value="pending" <?php echo ($main_settings['new_post_status']=='pending'?'selected':''); ?>>Pending</option>
											<option value="published" <?php echo ($main_settings['new_post_status']=='published'?'selected':''); ?>>Published</option>
										</select>
									</div>
								</div>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Order category list by</span>
									<div class="col-sm-9">
										<select class="db-settings-category_list_order">
											<option value="name" <?php echo ($main_settings['category_list_order']=='name'?'selected':''); ?>>Name</option>
											<option value="slug" <?php echo ($main_settings['category_list_order']=='slug'?'selected':''); ?>>Slug</option>
											<option value="count" <?php echo ($main_settings['category_list_order']=='count'?'selected':''); ?>>Count of listings</option>
										</select>
									</div>
								</div>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Sort category list</span>
									<div class="col-sm-9">
										<select class="db-settings-category_list_sort">
											<option value="asc" <?php echo ($main_settings['category_list_sort']=='asc'?'selected':''); ?>>Ascending</option>
											<option value="desc" <?php echo ($main_settings['category_list_sort']=='desc'?'selected':''); ?>>Descending</option>
										</select>
									</div>
								</div>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Show category post count?</span>
									<div class="col-sm-9">
										<div class="db-checkbox <?php echo ($main_settings['category_post_count']=='true'?'active':''); ?>">
											<input type="checkbox" class="db-settings-category_post_count" <?php echo ($main_settings['category_post_count']=='true'?'checked':''); ?>>
										</div>
									</div>
								</div>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Hide empty categories</span>
									<div class="col-sm-9">
										<div class="db-checkbox <?php echo ($main_settings['hide_empty_categories']=='true'?'active':''); ?>">
											<input type="checkbox" class="db-settings-hide_empty_categories" <?php echo ($main_settings['hide_empty_categories']=='true'?'checked':''); ?>>
										</div>
									</div>
								</div>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Show only parent categories in category list?</span>
									<div class="col-sm-9">
										<div class="db-checkbox <?php echo ($main_settings['only_parent_categories']=='true'?'active':''); ?>">
											<input type="checkbox" class="db-settings-only_parent_categories" <?php echo ($main_settings['only_parent_categories']=='true'?'checked':''); ?>>
										</div>
									</div>
								</div>
							</div>
						</div>
					</div>
					<div class="db-box-container col-md-12">
					<div class="db-box main-card">
						<div class="db-box-title">
							<h3 class="db-main-title">Listing packages</h3>
						</div>
						<div class="db-row">
							<div class="db-row-group clearfix">
								<span class="db-row-label col-sm-3">Default currency</span>
								<div class="col-sm-9">
									<select class="db-settings-default_currency">
										<?php
											$currencies = array(
												'AUD' => 'Australian Dollar',
												'BRL' => 'Brazilian Real',
												'CAD' => 'Canadian Dollar',
												'CZK' => 'Czech Koruna',
												'DKK' => 'Danish Krone',
												'EUR' => 'Euro',
												'HKD' => 'Hong Kong Dollar',
												'HUF' => 'Hungarian Forint',
												'ILS' => 'Israeli New Sheqel',
												'JPY' => 'Japanese Yen',
												'MYR' => 'Malaysian Ringgit',
												'MXN' => 'Mexican Peso',
												'NOK' => 'Norwegian Krone',
												'NZD' => 'New Zealand Dollar',
												'PHP' => 'Philippine Peso',
												'PLN' => 'Polish Zloty',
												'GBP' => 'Pound Sterling',
												'RUB' => 'Russian Ruble',
												'SGD' => 'Singapore Dollar',
												'SEK' => 'Swedish Krona',
												'CHF' => 'Swiss Franc',
												'TWD' => 'Taiwan New Dollar',
												'THB' => 'Thai Baht',
												'USD' => 'U.S. Dollar',
												);

											foreach ($currencies as $currency_key => $currency_value) {
												$is_selected = ($main_settings['default_currency']==$currency_key?' selected':'');
												echo '<option value="'.$currency_key.'"'.$is_selected.'>'.$currency_value.'</option>';
											}
										?>
									</select>
									<span class="db-field-required">This field is required</span>
								</div>
							</div>
						</div>
						<div class="db-row">
							<div class="db-row-group clearfix">
								<span class="db-row-label col-sm-3">Default currency symbol <span class="db-required">*</span></span>
								<div class="col-sm-9">
									<input type="text" class="db-settings-default_currency_symbol" placeholder="Default currency symbol" data-required="true" value="<?php echo $main_settings['default_currency_symbol']; ?>">
									<span class="db-field-required">This field is required</span>
								</div>
							</div>
						</div>
						<div class="db-row">
							<div class="db-row-group clearfix">
								<span class="db-row-label col-sm-3">Payment method</span>
								<div class="col-sm-9">
									<select class="db-settings-payment_method" multiple>
										<option value="paypal" <?php echo (in_array('paypal', $main_settings['payment_method'])?'selected':''); ?>>Paypal</option>
										<option value="authorize.net" <?php echo (in_array('authorize.net', $main_settings['payment_method'])?'selected':''); ?>>Authorize.Net</option>
									</select>
								</div>
							</div>
						</div>
						<div class="db-row">
							<div class="db-row-group clearfix">
								<span class="db-row-label col-sm-3">Active?</span>
								<div class="col-sm-9">
									<select class="db-settings-payment_active">
										<option value="yes" <?php echo ($main_settings['payment_active']=='yes'?'selected':''); ?>>Yes</option>
										<option value="no" <?php echo ($main_settings['payment_active']=='no'?'selected':''); ?>>No</option>
									</select>
								</div>
							</div>
						</div>
						<div class="db-row">
							<div class="db-row-group clearfix">
								<span class="db-row-label col-sm-3">Mode</span>
								<div class="col-sm-9">
									<select class="db-settings-payment_mode">
										<option value="live" <?php echo ($main_settings['payment_mode']=='live'?'selected':''); ?>>Live</option>
										<option value="sandbox" <?php echo ($main_settings['payment_mode']=='sandbox'?'selected':''); ?>>Test mode (sandbox)</option>
									</select>
								</div>
							</div>
						</div>
						<div class="db-row">
							<div class="db-row-group clearfix">
								<span class="db-row-label col-sm-3">Merchant ID <span class="db-required">*</span></span>
								<div class="col-sm-9">
									<input type="text" class="db-settings-paypal_merchant_id" placeholder="Merchant ID" data-required="true" value="<?php echo $main_settings['paypal_merchant_id']; ?>">
									<span>Your PayPal email where the money is sent to.</p>
									<span class="db-field-required">This field is required</span>
								</div>
							</div>
						</div>
						<div class="db-row">
							<div class="db-row-group clearfix">
								<span class="db-row-label col-sm-3">Cancel URL</span>
								<div class="col-sm-9">
									<input type="text" class="db-settings-paypal_cancel_url" placeholder="Cancel URL" value="<?php echo $main_settings['paypal_cancel_url']; ?>">
								</div>
							</div>
						</div>
						<div class="db-row">
							<div class="db-row-group clearfix">
								<span class="db-row-label col-sm-3">Return URL</span>
								<div class="col-sm-9">
									<input type="text" class="db-settings-paypal_return_url" placeholder="Return URL" value="<?php echo $main_settings['paypal_return_url']; ?>">
									<span>Also known as thank you page.</p>
								</div>
							</div>
						</div>
						<div class="db-row">
							<div class="db-row-group clearfix">
								<span class="db-row-label col-sm-3">Order success page</span>
								<div class="col-sm-9">
									<select class="db-settings-order_success_url">
										<?php
											$all_pages = get_pages();
											if ( !empty($all_pages) ) {
												foreach ($all_pages as $page_data) {
													echo '<option value="' . $page_data->ID . '"'.(isset($main_settings['order_success_url'])&&$main_settings['order_success_url']==$page_data->ID?' selected':'').'>' . $page_data->post_title . '</option>';
												}
											}
										?>
									</select>
									<span>This page will be used for free listings, otherwise "Return URL" option will be used!</p>
								</div>
							</div>
						</div>
						<div class="db-row">
							<div class="db-row-group clearfix">
								<span class="db-row-label col-sm-3">Authorize.net login ID</span>
								<div class="col-sm-9">
									<input type="text" class="db-settings-authorize_id" placeholder="Authorize.net login ID" value="<?php echo $main_settings['authorize_id']; ?>">
								</div>
							</div>
						</div>
						<div class="db-row">
							<div class="db-row-group clearfix">
								<span class="db-row-label col-sm-3">Authorize.net key</span>
								<div class="col-sm-9">
									<input type="text" class="db-settings-authorize_key" placeholder="Authorize.net key" value="<?php echo $main_settings['authorize_key']; ?>">
								</div>
							</div>
						</div>
					</div>
				</div>
				</div>
			</div>
			<div class="db-row-group col-md-12 clearfix">
				<input type="hidden" class="db-settings-db_theme_id" value="<?php echo $main_settings['db_theme_id']; ?>">
				<input type="hidden" class="db-settings-db_theme_path" value="<?php echo $main_settings['db_theme_path']; ?>">
				<input type="hidden" class="db-settings-db_theme_url" value="<?php echo $main_settings['db_theme_url']; ?>">
				<a href="javascript:void(0)" class="db-save-settings db-button db-primary-button">Save changes</a>
			</div>
		</div>
	</div>
	<?php
}

function db_load_template( $template_name, $load = false, $require_once = true, $theme_settings ) {
	if ( $template_name == '' ) {
		return;
	}

	if ( isset($theme_settings['db_theme_path']) && file_exists( $theme_settings['db_theme_path'].$template_name ) ) {
		$located = $theme_settings['db_theme_path'].$template_name;
	} else if ( file_exists( plugin_dir_path( __FILE__ ).'/template/'.$template_name ) ) {
		$located = plugin_dir_path( __FILE__ ).'/template/'.$template_name;
	}

	if ( $load && '' != $located ) {
		ob_start();
		load_template( $located, $require_once );
		$located = ob_get_clean();
	}

	return $located;
}

function db_get_categories( $post_id, $separator = ', ' ) {
	$categories = wp_get_object_terms($post_id, 'listing_category');
	$all_categories = array();
	if ( !empty($categories) ) {
		foreach ($categories as $category_value) {
			$all_categories[] = '<span class="db-search-listing-category">'.$category_value->name.'</span>';
		}
	}

	echo implode($separator, $all_categories);
}

function db_get_listing_custom_field_data( $listing_array, $custom_class = '', $echo = true ) {
	$active_fields = whitelab_get_listing_custom_fields( $listing_array['ID'], 'on_listing' );

	if ( !empty($active_fields) ) {
		foreach ($active_fields as $field_data) {
			if ( !empty($field_data['value']) ) {
				$field_value = (is_array($field_data['value'])?implode(', ', $field_data['value']):$field_data['value']);
			
				if ( $field_data['icon'] == '' ) {
					$field_title = '<span class="db-field-title">'.$field_data['title'].': </span>';
				} else {
					$field_title = '<span class="db-field-icon '.$field_data['icon'].'" title="'.$field_data['title'].'"></span>';
				}

				// Echo or return?
				if ( $echo === true ) {
					echo '<div class="'.$custom_class.'">'.$field_title.'<span class="db-field-value">'.$field_value.'</span></div>';
				} else if ( $echo === false ) {
					return '<div class="'.$custom_class.'">'.$field_title.'<span class="db-field-value">'.$field_value.'</span></div>';
				}
			}
		}
	}
}

function db_save_settings() {
	if ( !current_user_can('manage_options') ) die(0);

	global $wpdb;
	$db_settings = ( isset($_POST['db_settings']) ? sanitize_text_field($_POST['db_settings']) : '' );
	
	$db_settings_decoded = json_decode(stripslashes($db_settings), true);

	if ( isset($db_settings_decoded['default_location']) && $db_settings_decoded['default_location'] != '' ) {
		$response = wp_remote_get( "http://maps.google.com/maps/api/geocode/json?sensor=false&address=".str_replace(" ", "+", $db_settings_decoded['default_location']) );
		$json = json_decode( $response['body'], true );
		$db_settings_decoded['default_location_lat'] = $json['results'][0]['geometry']['location']['lat'];
		$db_settings_decoded['default_location_lng'] = $json['results'][0]['geometry']['location']['lng'];
	}
	
	if ( !empty($db_settings_decoded) ) {
		update_option( 'db_main_settings', $db_settings_decoded );
		echo '{"save_response": "0"}';
	} else {
		echo '{"save_response": "failed"}';
	}

	die(0);
}
add_action( 'wp_ajax_db_save_settings', 'db_save_settings' );

function db_package_html() {
	if ( !current_user_can('manage_options') )  {
		wp_die( __('You do not have sufficient permissions to access this page.', 'directory-builder') );
	}
	?>
	<div class="db-main-wrapper container-fluid" id="db-main-wrapper">
		<div class="db-main-content main-card">
			<?php if ( !isset($_GET['package_type']) && !isset($_GET['package_id']) ) { ?>
				<a href="<?php echo DB_PLUGIN_PACKAGE_PAGE_URL; ?>&package_type=new" class="db-add-new-package db-button db-primary-button">Add new</a>
				<table class="table table-striped table-hover">
					<thead>
						<tr>
							<th>ID</th>
							<th>Name</th>
							<th>Action</th>
						</tr>
					</thead>
					<tbody>
						<?php
						global $wpdb;
						$field_list = $wpdb->get_results('SELECT * FROM '.$wpdb->prefix.'directory_packages ORDER BY ID ASC');
						if ( !empty($field_list) ) {
							foreach ($field_list as $field_value) {
								$field_settings = json_decode($field_value->package_settings, true);
								echo '
								<tr>
									<td style="width: 5%;">'.$field_value->ID.'</td>
									<td style="width: 80%;">'.$field_settings['fee_label'].'</td>
									<td style="width: 15%;">
										<a href="'.DB_PLUGIN_PACKAGE_PAGE_URL.'&package_id='.$field_value->ID.'" class="db-edit-package">Edit</a>
										<a href="javascript:void(0)" class="db-delete-package" data-id="'.$field_value->ID.'">Delete</a>
									</td>
								</tr>';
							}
						}
						?>
					</tbody>
				</table>
			<?php } else if ( isset($_GET['package_type']) || isset($_GET['package_id']) ) {
				$field_settings = array();
				if ( isset($_GET['package_id']) ) {
					global $wpdb;
					$field_data = $wpdb->get_results('SELECT * FROM '.$wpdb->prefix.'directory_packages WHERE ID="'.intval($_GET['package_id']).'"');
					$field_settings = json_decode($field_data['0']->package_settings, true);
				}
				?>
				<div class="db-custom-field">
					<div class="db-box-title">
						<h3 class="db-main-title">Custom package</h3>
					</div>
					<div class="db-field-row <?php echo(isset($field_settings['fee_label'])&&$field_settings['fee_label']!=''?'active':''); ?> clearfix">
						<label class="field-label">Fee label</label>
						<div class="db-field-input">
							<input type="text" class="db-create-fee_label" value="<?php echo(isset($field_settings['fee_label'])?$field_settings['fee_label']:''); ?>">
						</div>
					</div>
					<div class="db-field-row <?php echo(isset($field_settings['fee_amount'])&&$field_settings['fee_amount']!=''?'active':''); ?> clearfix">
						<label class="field-label">Fee amount</label>
						<div class="db-field-input">
							<input type="number" class="db-create-fee_amount" value="<?php echo(isset($field_settings['fee_amount'])?$field_settings['fee_amount']:''); ?>">
						</div>
					</div>
					<div class="db-field-row active clearfix">
						<label class="field-label">Payment type</label>
						<div class="db-field-input">
							<select class="db-create-payment_type">
								<option value="onetime" <?php echo(isset($field_settings['payment_type'])&&$field_settings['payment_type']=='onetime'?'selected':''); ?>>One time payment</option>
								<option value="recurring" <?php echo(isset($field_settings['payment_type'])&&$field_settings['payment_type']=='recurring'?'selected':''); ?>>Recurring payment</option>
							</select>
						</div>
					</div>
					<div class="db-field-row active clearfix">
						<label class="field-label">Run listing for</label>
						<div class="db-field-input">
							<select class="db-create-listing_run_type">
								<option value="days" <?php echo(isset($field_settings['listing_run_type'])&&$field_settings['listing_run_type']=='days'?'selected':''); ?>>Set amount of days</option>
								<option value="forever" <?php echo(isset($field_settings['listing_run_type'])&&$field_settings['listing_run_type']=='forever'?'selected':''); ?>>Forever</option>
							</select>
						</div>
					</div>
					<div class="db-field-row <?php echo(isset($field_settings['listing_run_days'])&&$field_settings['listing_run_days']!=''?'active':(!isset($field_settings['listing_run_days'])?'active':'')); ?> clearfix">
						<label class="field-label">Run listing for (days)</label>
						<div class="db-field-input">
							<input type="number" class="db-create-listing_run_days" value="<?php echo(isset($field_settings['listing_run_days'])?$field_settings['listing_run_days']:'20'); ?>">
						</div>
					</div>
					<div class="db-field-row active clearfix">
						<label class="field-label">Payment cycle</label>
						<div class="db-field-input">
							<select class="db-create-payment_cycle">
								<option value="days" <?php echo(isset($field_settings['payment_cycle'])&&$field_settings['payment_cycle']=='days'?'selected':''); ?>>Days</option>
								<option value="weeks" <?php echo(isset($field_settings['payment_cycle'])&&$field_settings['payment_cycle']=='weeks'?'selected':''); ?>>Weeks</option>
								<option value="months" <?php echo(isset($field_settings['payment_cycle'])&&$field_settings['payment_cycle']=='months'?'selected':''); ?>>Months</option>
								<option value="years" <?php echo(isset($field_settings['payment_cycle'])&&$field_settings['payment_cycle']=='years'?'selected':''); ?>>Years</option>
							</select>
						</div>
					</div>
					<div class="db-field-row <?php echo(isset($field_settings['payment_interval'])&&$field_settings['payment_interval']!=''?'active':(!isset($field_settings['payment_interval'])?'active':'')); ?> clearfix">
						<label class="field-label">Payment cycle interval</label>
						<div class="db-field-input">
							<input type="number" class="db-create-payment_interval" value="<?php echo(isset($field_settings['payment_interval'])?$field_settings['payment_interval']:''); ?>">
						</div>
					</div>
					<div class="db-field-row <?php echo(isset($field_settings['image_amount'])&&$field_settings['image_amount']!=''?'active':''); ?> clearfix">
						<label class="field-label">Images allowed</label>
						<div class="db-field-input">
							<input type="number" class="db-create-image_amount" value="<?php echo(isset($field_settings['image_amount'])?$field_settings['image_amount']:''); ?>">
						</div>
					</div>
					<div class="db-field-row active clearfix">
						<label class="field-label">Package listings sticky (featured)?</label>
						<div class="db-field-input">
							<div class="db-checkbox <?php echo (isset($field_settings['listing_sticky'])&&$field_settings['listing_sticky']=='true'?'active':''); ?>">
								<input type="checkbox" class="db-create-listing_sticky" <?php echo (isset($field_settings['listing_sticky'])&&$field_settings['listing_sticky']=='true'?'checked':''); ?>>
							</div>
						</div>
					</div>
					<div class="db-field-row active clearfix">
						<label class="field-label">Apply to categories</label>
						<div class="db-field-input">
							<select class="db-create-apply_categories" multiple>
							<?php
							$categories = get_terms( array(
								'taxonomy' => 'listing_category',
								'hide_empty' => false
							));
							if ( !empty($categories) ) {
								foreach ($categories as $category_value) {
									$is_checked = (in_array($category_value->term_id, $field_settings['apply_categories'])?'selected':'');
									echo '<option value="'.$category_value->term_id.'" '.$is_checked.'>'.$category_value->name.'</option>';
								}
							}
							?>
							</select>
						</div>
					</div>
					<div class="db-field-row <?php echo(isset($field_settings['fee_description'])&&$field_settings['fee_description']!=''?'active':''); ?> clearfix">
						<label class="field-label">Fee description</label>
						<div class="db-field-input">
							<textarea class="db-create-fee_description"><?php echo(isset($field_settings['fee_description'])?$field_settings['fee_description']:''); ?></textarea>
						</div>
					</div>
					<div class="db-field-row active clearfix">
						<label class="field-label">Listing status after it expires</label>
						<div class="db-field-input">
							<select class="db-create-listing_status">
								<option value="draft" <?php echo(isset($field_settings['listing_status'])&&$field_settings['listing_status']=='draft'?'selected':''); ?>>Draft</option>
								<option value="trash" <?php echo(isset($field_settings['listing_status'])&&$field_settings['listing_status']=='trash'?'selected':''); ?>>Trash</option>
							</select>
						</div>
					</div>
					<div class="db-field-row active clearfix">
						<label class="field-label">Popular package?</label>
						<div class="db-field-input">
							<div class="db-checkbox <?php echo (isset($field_settings['listing_popular'])&&$field_settings['listing_popular']=='true'?'active':''); ?>">
								<input type="checkbox" class="db-create-listing_popular" <?php echo (isset($field_settings['listing_popular'])&&$field_settings['listing_popular']=='true'?'checked':''); ?>>
							</div>
						</div>
					</div>
					<div class="db-field-row active clearfix">
						<label class="field-label">Package image</label>
						<div class="db-field-input">
							<input type="button" value="Upload image" class="db-image-upload">
							<input type="button" class="db-image-delete" value="Delete image" <?php echo (!isset($field_settings['package_img'])||$field_settings['package_img']==''?'style="display: none;"':''); ?>s>
							<div class="db-image-container">
								<?php echo (isset($field_settings['package_img'])&&$field_settings['package_img']!=''?'<img src="'.$field_settings['package_img'].'" alt="">':''); ?>
							</div>
							<input type="hidden" class="db-create-package_img" value="<?php echo (isset($field_settings['package_img'])&&$field_settings['package_img']!=''?$field_settings['package_img']:''); ?>">
						</div>
					</div>

					<?php if ( !isset($_GET['package_id']) ) { ?>
						<a href="javascript:void(0)" class="db-save-package db-button db-primary-button" data-save="insert">Create package</a>
					<?php } else { ?>
						<a href="javascript:void(0)" class="db-save-package db-button db-primary-button" data-save="update" data-id="<?php echo esc_attr($_GET['package_id']); ?>">Save package</a>
					<?php } ?>
				</div>
			<?php } ?>
		</div>
	</div>
	<?php
}

function db_delete_package() {
	if ( !current_user_can('manage_options') ) die(0);

	global $wpdb;
	$package_id = ( isset($_POST['package_id']) ? intval($_POST['package_id']) : '' );

	if ( $wpdb->query('DELETE FROM '.$wpdb->prefix.'directory_packages WHERE ID="'.$package_id.'"') === false ) {
		echo '{"save_response": "failed"}';
	} else {
		echo '{"save_response": "'.$wpdb->insert_id.'"}';
	}

	die(0);
}
add_action( 'wp_ajax_db_delete_package', 'db_delete_package' );

function db_single_listing_template( $template ) {
	global $post;

	if ( $post->post_type == "listings" ) {
		$main_settings = get_option( 'db_main_settings');

		return db_load_template( 'single-listings.php', false, false, $main_settings );
	}

	return $template;
}
add_filter('single_template', 'db_single_listing_template');

function db_listing_rating_template( $comment_template ) {
	 global $post;
	 if ( !( is_singular() && ( have_comments() || 'open' == $post->comment_status ) ) ) {
		return;
	 }
	 if ( $post->post_type == 'listings' ) {
		$main_settings = get_option( 'db_main_settings');

		return db_load_template( 'single-listing-ratings.php', false, false, $main_settings );
	 }
}
add_filter( "comments_template", "db_listing_rating_template" );

function db_insert_review( $comment_id, $comment_object ) {
	if ( !isset($_POST['listing_rating']) || !isset($_POST['review-title']) ) {
		return;
	}

	$rating_value = (isset($_POST['listing_rating'])?intval($_POST['listing_rating']):1);
	$rating_title = (isset($_POST['review-title'])?sanitize_text_field($_POST['review-title']):'');

	add_comment_meta( $comment_id, 'listing_review_rating', $rating_value);
	add_comment_meta( $comment_id, 'listing_review_title', $rating_title);
	$post_id = $comment_object->comment_post_ID;

	if ( $comment_object->user_id == '0' ) {
		$user_id = $comment_object->user_id;
	} else {
		$user_id = 'anon-'.rand(100000,999999);
	}

	$listing_ratings = get_post_meta( $post_id, 'listing_ratings', true);
	if ( $listing_ratings == '' ) {
		update_post_meta( $post_id, 'listing_ratings', array( $user_id => $rating_value ) );
	} else {
		$listing_ratings[$user_id] = $rating_value;
		update_post_meta( $post_id, 'listing_ratings', $listing_ratings );
	}
}
add_action( 'wp_insert_comment', 'db_insert_review', 10, 2 );

function db_disable_comment_url($fields) { 
	unset($fields['url']);
	return $fields;
}
add_filter('comment_form_default_fields','db_disable_comment_url');

function db_review( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	$rating_value = get_comment_meta( $comment->comment_ID, 'listing_review_rating', true );
	
	switch ( $comment->comment_type ) :
		case 'pingback' :
		case 'trackback' :
	?>
	<li class="post pingback">
		<p><?php _e( 'Pingback:', 'directory-builder' ); ?> <?php comment_author_link(); ?><?php edit_comment_link( __( 'Edit', 'directory-builder' ), '<span class="edit-link button blue">', '</span>' ); ?></p>
	<?php
			break;
		default :
	?>
	
	<li <?php comment_class(); ?> id="li-review-<?php comment_ID(); ?>">
		<div id="review-<?php comment_ID(); ?>" class="review">
			<div class="review-meta">
				<div class="review-author vcard shadows">
					<?php
						$avatar_size = 70;
						echo get_avatar( $comment, $avatar_size );                          
					?>
				</div><!-- .review-author .vcard -->
			</div>

			<div class="review-content">
				<?php echo '<h4>' . get_comment_author_link() . '</h4>' ?>
				<?php if ( $comment->comment_approved == '0' ) { ?>
					<em class="review-awaiting-moderation"><?php _e( 'Your review is awaiting moderation.', 'directory-builder' ); ?></em>
				<?php } ?>
				<?php echo '<span class="db-listing-rating">'.__('Rating:', 'directory-builder').' '.$rating_value.db_get_rating_stars( $rating_value ).'</span>'; ?>
				<?php edit_comment_link( __( 'Edit', 'directory-builder' ), '<span class="edit-link button blue">', '</span>' ); ?>
				<?php comment_text(); ?>
				<div class="reply-edit-container">
					
				</div>
				<div class="clearfix"></div>
			</div>
			<div class="clearfix"></div>
		</div><!-- end of review -->

	<?php
			break;
	endswitch;
}

function db_get_rating_stars( $rating ) {
	$output = '';

	if ( !defined('WHITELAB_CUSTOM_STARS') ) {
		for ( $i=1; $i <= $rating; $i++ ) { 
			$output .= '<i class="dbicon-star"></i>';
		}
		
		if ( $rating != 5 ) {
			for ( $i=1; $i <= 5-$rating; $i++ ) { 
				$output .= '<i class="dbicon-star-empty"></i>';
			}
		}
	} else {
		$rating_star = '
		<svg width="16px" height="15px" viewBox="0 0 16 15" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
			<g stroke="none" stroke-width="1" fill="none" fill-rule="evenodd">
				<g id="Single-listing" transform="translate(-380.000000, -2797.000000)" stroke="#909FA5" fill="#FFFFFF">
					<g id="Listing" transform="translate(-1.000000, 172.000000)">
						<g id="Coments" transform="translate(151.000000, 2089.000000)">
							<g id="Comment-form" transform="translate(30.000000, 474.000000)">
								<g id="stars" transform="translate(120.000000, 63.000000)">
									<g id="star" transform="translate(81.000000, 0.000000)">
										<g  >
											<path d="M0.321780893,6.17123188 L2.50574108,8.42145652 L2.1280167,11.6264746 L2.12589942,11.6556304 C2.11037263,12.0718188 2.22649417,12.421029 2.46132506,12.6649674 C2.79557443,13.0122935 3.34150567,13.0825688 3.88292002,12.8381594 L6.78224162,11.2581413 L9.65700266,12.8257246 L9.68137501,12.8381594 C9.89954989,12.9364601 10.1142901,12.9864348 10.3202788,12.9864348 C10.6253566,12.9864348 10.903239,12.8720725 11.1027347,12.6649674 C11.3375656,12.421029 11.4537342,12.0718188 11.4382074,11.6556304 L11.0580834,8.42145652 L13.2126839,6.20533333 L13.2420436,6.17123188 C13.5430751,5.77477899 13.6379767,5.31996739 13.5024702,4.9238913 C13.3667755,4.52781522 13.0133764,4.22678986 12.5327047,4.09848551 L9.29649891,3.57613043 L7.88544334,0.734076087 L7.86417635,0.696771739 C7.58582341,0.27040942 7.17751597,0.0257173913 6.74384811,0.0257173913 C6.32693036,0.0257173913 5.93866659,0.243985507 5.65005656,0.639684783 L3.98116223,3.57537681 L1.0584093,4.06692754 L1.01827491,4.07601812 C0.541132045,4.21237681 0.191355884,4.51980797 0.0585312811,4.91969928 C-0.0743403731,5.31940217 0.0214551963,5.77576812 0.321780893,6.17123188 L0.321780893,6.17123188 Z M0.754978244,5.15186232 C0.809698405,4.98780797 0.967836376,4.85898551 1.2017733,4.78819203 L4.44682468,4.24228623 L6.25522483,1.05686232 C6.55028083,0.665684783 6.96362272,0.675481884 7.23863505,1.08187319 L8.80740512,4.24157971 L12.3604515,4.81296739 C12.5950471,4.87933333 12.7537027,5.00278623 12.8084228,5.16217754 C12.8626254,5.32053261 12.8134102,5.51449638 12.6705167,5.70992029 L10.2882371,8.15985507 L10.7051078,11.6968442 C10.7103775,11.8992391 10.6640324,12.0613623 10.5742123,12.1546703 C10.456444,12.2771341 10.2406687,12.2814203 9.99506316,12.1733225 L6.78200636,10.4211014 L3.56871431,12.1733225 C3.32263827,12.2812319 3.10691003,12.276663 2.98980042,12.1551413 C2.89974506,12.0614094 2.85339995,11.8992391 2.8586226,11.6968913 L3.27554035,8.15990217 L0.893731257,5.7102029 C0.749708547,5.51313043 0.700493338,5.31577536 0.754978244,5.15186232 L0.754978244,5.15186232 Z"  ></path>
										</g>
									</g>
								</g>
							</g>
						</g>
					</g>
				</g>
			</g>
		</svg>';

		$rating_star_filled = '
		<svg width="16px" height="15px" viewBox="0 0 16 15" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
			<g stroke="none" stroke-width="1" fill="none" fill-rule="evenodd">
				<g id="Single-listing" transform="translate(-380.000000, -2797.000000)" stroke="#247ba0" fill="#FFFFFF">
					<g id="Listing" transform="translate(-1.000000, 172.000000)">
						<g id="Coments" transform="translate(151.000000, 2089.000000)">
							<g id="Comment-form" transform="translate(30.000000, 474.000000)">
								<g id="stars" transform="translate(120.000000, 63.000000)">
									<g id="star" transform="translate(81.000000, 0.000000)">
										<g  >
											<path d="M0.321780893,6.17123188 L2.50574108,8.42145652 L2.1280167,11.6264746 L2.12589942,11.6556304 C2.11037263,12.0718188 2.22649417,12.421029 2.46132506,12.6649674 C2.79557443,13.0122935 3.34150567,13.0825688 3.88292002,12.8381594 L6.78224162,11.2581413 L9.65700266,12.8257246 L9.68137501,12.8381594 C9.89954989,12.9364601 10.1142901,12.9864348 10.3202788,12.9864348 C10.6253566,12.9864348 10.903239,12.8720725 11.1027347,12.6649674 C11.3375656,12.421029 11.4537342,12.0718188 11.4382074,11.6556304 L11.0580834,8.42145652 L13.2126839,6.20533333 L13.2420436,6.17123188 C13.5430751,5.77477899 13.6379767,5.31996739 13.5024702,4.9238913 C13.3667755,4.52781522 13.0133764,4.22678986 12.5327047,4.09848551 L9.29649891,3.57613043 L7.88544334,0.734076087 L7.86417635,0.696771739 C7.58582341,0.27040942 7.17751597,0.0257173913 6.74384811,0.0257173913 C6.32693036,0.0257173913 5.93866659,0.243985507 5.65005656,0.639684783 L3.98116223,3.57537681 L1.0584093,4.06692754 L1.01827491,4.07601812 C0.541132045,4.21237681 0.191355884,4.51980797 0.0585312811,4.91969928 C-0.0743403731,5.31940217 0.0214551963,5.77576812 0.321780893,6.17123188 L0.321780893,6.17123188 Z M0.754978244,5.15186232 C0.809698405,4.98780797 0.967836376,4.85898551 1.2017733,4.78819203 L4.44682468,4.24228623 L6.25522483,1.05686232 C6.55028083,0.665684783 6.96362272,0.675481884 7.23863505,1.08187319 L8.80740512,4.24157971 L12.3604515,4.81296739 C12.5950471,4.87933333 12.7537027,5.00278623 12.8084228,5.16217754 C12.8626254,5.32053261 12.8134102,5.51449638 12.6705167,5.70992029 L10.2882371,8.15985507 L10.7051078,11.6968442 C10.7103775,11.8992391 10.6640324,12.0613623 10.5742123,12.1546703 C10.456444,12.2771341 10.2406687,12.2814203 9.99506316,12.1733225 L6.78200636,10.4211014 L3.56871431,12.1733225 C3.32263827,12.2812319 3.10691003,12.276663 2.98980042,12.1551413 C2.89974506,12.0614094 2.85339995,11.8992391 2.8586226,11.6968913 L3.27554035,8.15990217 L0.893731257,5.7102029 C0.749708547,5.51313043 0.700493338,5.31577536 0.754978244,5.15186232 L0.754978244,5.15186232 Z"  ></path>
										</g>
									</g>
								</g>
							</g>
						</g>
					</g>
				</g>
			</g>
		</svg>';

		for ( $i=1; $i <= $rating; $i++ ) { 
			$output .= $rating_star_filled;
		}
		
		if ( $rating != 5 ) {
			for ( $i=1; $i <= 5-$rating; $i++ ) { 
				$output .= $rating_star;
			}
		}
	}
	
	return $output;
}

function db_send_contact_email() {
	$output = '';
	$db_author_email = ( isset($_POST['db_author']) ? sanitize_text_field($_POST['db_author']) : '' );
	$db_message = ( isset($_POST['db_message']) ? sanitize_text_field($_POST['db_message']) : '' );
	$db_name = ( isset($_POST['db_name']) ? sanitize_text_field($_POST['db_name']) : '' );
	$db_email = ( isset($_POST['db_email']) ? sanitize_text_field($_POST['db_email']) : '' );

	$subject = esc_html__( 'Contacting regarding your listing', 'directory-builder' );
	$message = esc_html__( 'Name:', 'directory-builder' ) . ' ' . $db_name . '<br />';
	$message .= esc_html__( 'Email:', 'directory-builder' ) . ' ' . $db_email . '<br />';
	$message .= esc_html__( 'Message:', 'directory-builder' ) . '<br />' . $db_message;

	$maintenance_email = wp_mail( $db_author_email, $subject, $message );
	
	if ( $maintenance_email ) {
		echo 'Your email was sent successfully!';
	} else {
		echo 'Something went wrong!';
	}

	die(0);
}
add_action( 'wp_ajax_db_send_contact_email', 'db_send_contact_email' );
add_action( 'wp_ajax_nopriv_db_send_contact_email', 'db_send_contact_email' );

add_action('init', 'db_check_form_actions');
function db_check_form_actions(){
	if( isset($_POST['login_user_email']) && sanitize_email($_POST['login_user_email']) != '' && isset($_POST['login_user_password']) && $_POST['login_user_password'] != '' ){
		$db_user_login = sanitize_email($_POST['login_user_email']);
		$user_password = esc_attr($_POST['login_user_password']);

		$user_creds = array(
			'user_login'    => $db_user_login,
			'user_password' => $user_password,
			'remember'      => true
		);

		global $db_user_login;
		$db_user_login = wp_signon( $user_creds );

		if ( !is_wp_error( $db_user_login ) ) {
			header("Refresh:0");
			exit;
		}
	}

	if ( isset($_POST['register_user_email']) && isset($_POST['register_user_password']) && isset($_POST['register_user_password_confirm']) ) {
		$user_email = sanitize_email($_POST['register_user_email']);
		$db_user_login = explode('@', $user_email);
		$user_password = esc_attr($_POST['register_user_password']);

		global $db_user_register;
		$db_user_register = wp_create_user( $db_user_login['0'], $user_password, $user_email );
		if ( !is_wp_error( $db_user_register ) ) {
			wp_update_user( array( 'ID' => $db_user_register, 'role' => 'db_listing_author' ) );
		}
	}
}

function db_check_authorize_card( $card_data ) {
	require 'vendor/autoload.php';
	require 'auth_autoload.php';
}

function db_checkout_html( $package_data = array(), $claim_listing = false ) {
	$main_settings = get_option( 'db_main_settings');

	if ( is_string( $main_settings['payment_method'] ) ) {
		$main_settings['payment_method'] = str_split( $main_settings['payment_method'] );
	}

	$output = '
	<div class="db-main-checkout-wrapper db-dialog-animation"><div class="db-main-checkout" data-return="'.$main_settings['paypal_return_url'].'" data-success="'.get_permalink($main_settings['order_success_url']).'">
		<h1 class="db-checkout-title">'.__('Checkout', 'directory-builder').'<span class="db-checkout-close"><img src="'.get_template_directory_uri().'/images/x.png" alt=""></span></h1>
		<p class="db-checkout-desc">'.__('Choose a payment option bellow and fill out the information', 'directory-builder').'</p>
		<div class="db-checkout-select">';
			if ( in_array('authorize.net', $main_settings['payment_method']) ) {
				$output .= '
				<div class="db-checkout-item active" data-type="credit-card">
					<img src="'.get_template_directory_uri().'/images/credit-card.png" alt="">
					<span>'.__('Credit card', 'directory-builder').'</span>
				</div>';
			}
			if ( in_array('paypal', $main_settings['payment_method']) ) {
				$output .= '
				<div class="db-checkout-item '.(count($main_settings['payment_method'])==1?'active':'').'" data-type="paypal">
					<img src="'.get_template_directory_uri().'/images/paypal.png" alt="">
					<span>'.__('PayPal', 'directory-builder').'</span>
				</div>';
			}
		$output .= '</div>';

		$billing_fields = '
		<div class="db-checkout-left">
			<h3>'.__('1. Billing information', 'directory-builder').'</h3>
			<div class="db-checkout-row">
				<span class="db-checkout-label">'.__('Full name *', 'directory-builder').'</span>
				<input type="text" class="db-checkout-field" name="x_full_name" placeholder="'.__('Full name *', 'directory-builder').'" required>
			</div>
			<div class="db-checkout-split two">
				<div class="db-checkout-row">
					<span class="db-checkout-label">'.__('Company name', 'directory-builder').'</span>
					<input type="text" class="db-checkout-field" name="x_company" placeholder="'.__('Company name', 'directory-builder').'">
				</div>
				<div class="db-checkout-row">
					<span class="db-checkout-label">'.__('Phone *', 'directory-builder').'</span>
					<input type="phone" class="db-checkout-field" name="x_phone" placeholder="'.__('Phone *', 'directory-builder').'" required>
				</div>
				<div class="db-checkout-row">
					<span class="db-checkout-label">'.__('Email *', 'directory-builder').'</span>
					<input type="email" class="db-checkout-field" name="x_email" placeholder="'.__('Email *', 'directory-builder').'" required>
				</div>
				<div class="db-checkout-row">
					<span class="db-checkout-label">'.__('Country *', 'directory-builder').'</span>
					<input type="text" class="db-checkout-field" name="x_country" placeholder="'.__('Country *', 'directory-builder').'" required>
				</div>
				<div class="clearfix"></div>
			</div>
			<div class="db-checkout-row">
				<span class="db-checkout-label">'.__('Address 1 *', 'directory-builder').'</span>
				<input type="text" class="db-checkout-field" name="x_address" placeholder="'.__('Address 1 *', 'directory-builder').'" required>
			</div>
			<div class="db-checkout-split two">
				<div class="db-checkout-row">
					<span class="db-checkout-label">'.__('City *', 'directory-builder').'</span>
					<input type="text" class="db-checkout-field" name="x_city" placeholder="'.__('City *', 'directory-builder').'" required>
				</div>
				<div class="db-checkout-row">
					<span class="db-checkout-label">'.__('State / County *', 'directory-builder').'</span>
					<input type="text" class="db-checkout-field" name="x_state" placeholder="'.__('State / County *', 'directory-builder').'" required>
				</div>
				<div class="clearfix"></div>
			</div>
			<div class="db-checkout-row">
				<span class="db-checkout-label">'.__('Postcode / ZIP *', 'directory-builder').'</span>
				<input type="text" class="db-checkout-field" name="x_zip" placeholder="'.__('Postcode / ZIP *', 'directory-builder').'" required>
			</div>';
			if ( $claim_listing ) {
				$billing_fields .= '<input type="hidden" name="db-claim-listing" value="true">';
			}
		$billing_fields .= '
		</div>';

		if ( in_array('authorize.net', $main_settings['payment_method']) ) {
			$output .= '
			<div class="db-checkout-option credit-card">
				<form id="authorize_form" method="post">
					'.$billing_fields.'
					<div class="db-checkout-right">
						<h3>'.__('2. Credit card info', 'directory-builder').'</h3>
						<div class="db-checkout-row">
							<span class="db-checkout-label">'.__('Name on card *', 'directory-builder').'</span>
							<input type="text" class="db-checkout-field" name="name_on_card" placeholder="'.__('Name on card *', 'directory-builder').'" required>
						</div>
						<div class="db-checkout-row">
							<span class="db-checkout-label">'.__('Card number *', 'directory-builder').'</span>
							<input type="text" class="db-checkout-field" name="x_card_num" placeholder="'.__('Card number *', 'directory-builder').'" required>
						</div>
						<div class="db-checkout-split three">
							<div class="db-checkout-row">
								<span class="db-checkout-label">'.__('CVV code *', 'directory-builder').'</span>
								<input type="text" class="db-checkout-field" name="x_cvv" placeholder="'.__('CVV code *', 'directory-builder').'" required>
							</div>
							<div class="db-checkout-row">
								<span class="db-checkout-label">'.__('Month *', 'directory-builder').'</span>
								<input type="text" class="db-checkout-field" name="x_month" placeholder="'.__('Month *', 'directory-builder').'" required>
							</div>
							<div class="db-checkout-row">
								<span class="db-checkout-label">'.__('Year *', 'directory-builder').'</span>
								<input type="text" class="db-checkout-field" name="x_year" placeholder="'.__('Year *', 'directory-builder').'" required>
							</div>
							<div class="clearfix"></div>
						</div>
						<div class="db-checkout-proceed">
							<input type="hidden" name="db-checkout" value="true">
							<input type="hidden" name="db-listing-id" value="'.get_the_ID().'">
							<input type="hidden" name="db-package-fee" value="">';
							if ( $main_settings['terms_and_conditions_status'] ) {
								$output .= '
								<div class="dt-form-row">
									<label for="db-agree-to-terms" class="dt-checkbox">
										<input type="checkbox" id="db-agree-to-terms" name="db-agree-to-terms" required="">'.esc_html__('I agree to all statements in', 'directory-builder').' <a href="javascript:void(0)" class="db-show-checkout-terms">'.esc_html__('terms and conditions', 'directory-builder').'</a>
										<div class="db-checkout-terms hidden">'.nl2br($main_settings['terms_and_conditions']).'</div>
									</label>
								</div>';
							}
							$output .= '
							<input type="submit" class="btn btn-primary" type="button" value="' . __('Pay with credit card', 'directory-builder') . '">
						</div>
					</div>
					<div class="clearfix"></div>
				</form>
			</div>';
		}
		if ( in_array('paypal', $main_settings['payment_method']) ) {
			$output .= '
			<div class="db-checkout-option paypal" '.(count($main_settings['payment_method'])>1?'style="display: none;"':'').'>';
				if ( $main_settings['payment_mode'] == 'sandbox' ) {
					$paypal_url = 'https://www.sandbox.paypal.com/cgi-bin/webscr';
				} else {
					$paypal_url = 'https://www.paypal.com/cgi-bin/webscr';
				}
				$new_listing_id = 0;
				$output .=
				'<form id="paypal-gateway" action="' . $paypal_url . '" method="post">
					'.$billing_fields.'
					<div class="db-checkout-right">
						<h3>'.__('2. PayPal', 'directory-builder').'</h3>
						<div class="db-checkout-proceed">
							<input type="hidden" name="db-checkout" value="true">
							<input type="hidden" name="db-listing-id" value="'.get_the_ID().'">
							<input type="hidden" name="cmd" value="_xclick">
							<input type="hidden" name="business" value="' . $main_settings['paypal_merchant_id'] . '">
							<input type="hidden" name="item_name" value="'.(isset($package_data['fee_label'])?$package_data['fee_label']:'').'">
							<input type="hidden" name="amount" value="'.(isset($package_data['fee_amount'])?$package_data['fee_amount']:'').'">
							<input type="hidden" name="no_shipping" value="1">
							<input type="hidden" name="no_note" value="1">
							<input type="hidden" name="currency_code" value="' . $main_settings['default_currency'] . '">
							<input type="hidden" name="return" value="' . $main_settings['paypal_return_url'] . '">
							<input type="hidden" name="notify_url" value="' . get_the_permalink() . '">
							<input type="hidden" name="custom" value="' . $new_listing_id . '">
							<input type="hidden" name="src" value="1">
							<input type="hidden" name="a3" value="'.(isset($package_data['fee_amount'])?$package_data['fee_amount']:'').'">
							<input type="hidden" name="p3" value="1">
							<input type="hidden" name="t3" value="M">';

							if ( $main_settings['terms_and_conditions_status'] ) {
								$output .= '
								<div class="dt-form-row">
									<label for="db-agree-to-terms" class="dt-checkbox">
										<input type="checkbox" id="db-agree-to-terms" name="db-agree-to-terms" required="">'.esc_html__('I agree to all statements in', 'directory-builder').' <a href="javascript:void(0)" class="db-show-checkout-terms">'.esc_html__('terms and conditions', 'directory-builder').'</a>
										<div class="db-checkout-terms hidden">'.nl2br($main_settings['terms_and_conditions']).'</div>
									</label>
								</div>';
							}
							$output .= '
							<input type="submit" class="btn btn-primary" type="button" value="' . __('Proceed to PayPal', 'directory-builder') . '">
						</div>
					</div>
					<div class="clearfix"></div>
				</form>
			</div>';
		}
	$output .= '</div></div><div class="db-dialog-overlay"></div>';

	return $output;
}

function db_add_listing_shortcode( $db_edit_listing = false ) {
	$main_settings = get_option( 'db_main_settings');
	$listing_categories = wp_dropdown_categories( array(
				'taxonomy'      => 'listing_category',
				'hide_empty'    => 0,
				'orderby'       => 'name',
				'order'         => 'ASC',
				'name'          => 'listing_category',
				'echo'          => '0'
			) );
	global $wpdb;
	$register_message = $output = '';

	if ( isset($_GET['edit-listing']) ) {
		$db_edit_listing = true;
	}

	if ( !$db_edit_listing ) {
		// Paypal IPN payment verification
		$post_input       = file_get_contents('php://input');
		$post_input_array = explode('&', $post_input);

		if ( $main_settings['payment_active'] == 'yes' && !empty($post_input) && $post_input_array[0] != 'wp_customize=on' && strpos($post_input_array['0'], 'listing_title') === false && strpos($post_input_array['0'], 'login_user_email') === false ) {
			include('paypal_ipn.php');
		}

		if ( $main_settings['payment_active'] == 'yes' && $main_settings['payment_method'] == 'authorize.net' && !empty($_REQUEST['x_response_code']) ) {
			require_once('authorize_relay.php');
		}
	}

	$package_data = array();
	if ( isset($_POST['listing_title']) && !$db_edit_listing ) {
		global $db_user_login;
		$ready_to_post = false;

		if ( is_user_logged_in() ) {
			$logged_in_user = get_current_user_id();
			$ready_to_post = true;
		} else if ( $db_user_login ) {
			if ( is_wp_error( $db_user_login ) ) {
				$register_message = '<p>'.$db_user_login->get_error_message().'</p>';
			} else {
				$logged_in_user = $db_user_login->data->ID;
				$ready_to_post = true;
			}
		} else if ( isset($_POST['register_user_email']) && sanitize_email($_POST['register_user_email']) != '' ) {
			$user_email = sanitize_email($_POST['register_user_email']);
			$db_user_login = explode('@', $user_email);

			$register_errors = register_new_user($db_user_login['0'], $user_email);

			if ( !is_wp_error($register_errors) ) {
				$logged_in_user = $register_errors;
				$ready_to_post = true;
			} else {
				$register_message = '<p>'.$register_errors->get_error_message().'</p>';
			}
		}

		$listing_values = array(
			'post_author' => $logged_in_user,
			'post_content' => sanitize_text_field($_POST['listing_content']),
			'post_title' => sanitize_text_field($_POST['listing_title']),
			'post_excerpt' => sanitize_text_field($_POST['listing_excerpt']),
			'post_status' => $main_settings['new_post_status'],
			'post_type' => 'listings',
			'comment_status' => 'open',
			'post_parent' => 0,
			'menu_order' => 0,
		);

		if ( $ready_to_post ) {
			$new_listing_id = wp_insert_post($listing_values);

			if ( $new_listing_id ) {
				$all_listing_values = $_POST;
				unset($all_listing_values['listing_title']);
				unset($all_listing_values['listing_content']);
				unset($all_listing_values['listing_excerpt']);
				unset($all_listing_values['listing_category']);
				unset($all_listing_values['listing_featured_img']);

				if ( isset($all_listing_values['listing_featured_img']) && esc_url($all_listing_values['listing_featured_img']) != '' ) {
					// DB_Generate_Featured_Image( content_url().'/directory-uploads/'.$all_listing_values['listing_featured_img'], $new_listing_id );
				}  

				// Add all custom data to the post
				foreach ($all_listing_values as $listing_value_key => $listing_key_value) {
					add_post_meta( $new_listing_id, sanitize_text_field($listing_value_key), ( !is_array( $listing_key_value ) ? sanitize_text_field( $listing_key_value ) : db_sanitize_array( $listing_key_value ) ), true );
				}

				// Add category to the listing
				wp_set_object_terms( $new_listing_id, intval($_POST['listing_category']), 'listing_category' );

				// Package payment
				$package_data = $wpdb->get_results('SELECT * FROM '.$wpdb->prefix.'directory_packages WHERE ID="'.intval($_POST['listing_package']).'"');
				if ( !empty($package_data) ) {
					$package_data = json_decode($package_data['0']->package_settings, true);
					if ( isset($package_data['listing_sticky']) && $package_data['listing_sticky'] === true ) {
						$sticky_listings = get_option('db_sticky_listings');
						if ( !isset($sticky_listings) || $sticky_listings == '' ) {
							$sticky_listings = array();
						}
						$sticky_listings[] = $new_listing_id;
						update_option('db_sticky_listings', $sticky_listings);
					}

					if ( $package_data['listing_run_type'] == 'forever' ) {
						$run_listing = __('Forever','directory-builder');
					} else {
						$run_listing = $package_data['listing_run_days'].' '.__('days','directory-builder');
					}

					// Add order info
					$order_data = array(
						'listing_package' => intval($_POST['listing_package']),
						'listing_package_name' => sanitize_text_field($package_data['fee_label']),
						'paid_amount' => $main_settings['default_currency_symbol'].$package_data['fee_amount'],
						'payment_history' => array(),
						'payment_status' => 'Processing',
						'category' => sanitize_text_field($_POST['listing_category']),
						'listing_run_type' => $package_data['listing_run_type'],
						'listing_run_days' => $package_data['listing_run_days'],
						'listing_sticky' => $package_data['listing_sticky'],
						'listing_expires' => 'Unknown'
					);
					add_post_meta( $new_listing_id, 'db_order_info', $order_data, true );
				} else {
					$output = '
					<div class="db-main-wrapper">
						<p>'.__('Your listing was successfully added, but your package couldn\'t be found!', 'directory-builder').'</p>
					</div>';
				}

				if ( $main_settings['db_theme_id'] == 'default' ) {
					$output .= db_checkout_html( $package_data );
				}

				// $payment_url = add_query_arg('db-payment', 'true', );
				$output .= '
				<script type="text/javascript">
				jQuery(document).ready(function($) {
					history.pushState({page: "'.get_permalink().'"}, "", "'.get_permalink().'");
				});
				</script>';

				return $output;
			} else {
				return '<div class="db-main-wrapper"><p>'.__('There was an issue while adding your listing!', 'directory-builder').'</p></div>';
			}
		}
	} else if ( isset($_POST['listing_title']) && $db_edit_listing ) {
		$db_listing = array(
			'ID'           => intval($_GET['edit-listing']),
			'post_title'  => esc_attr($_POST['listing_title']),
			'post_content' => esc_attr($_POST['listing_content']),
			'post_excerpt' => esc_attr($_POST['listing_excerpt'])
		);
		wp_update_post( $db_listing );

		$fields_to_save = $_POST;
		unset($fields_to_save['listing_title']);
		unset($fields_to_save['listing_content']);
		unset($fields_to_save['listing_excerpt']);

		foreach ($fields_to_save as $field_key => $field_value) {
			update_post_meta( esc_attr($_GET['edit-listing']), sanitize_key($field_key), (!is_array($field_value)?sanitize_text_field($field_value):$field_value));
		}

		$success_message = __('Listing updated successfully!', 'directory-builder');
	}

	if ( $db_edit_listing ) {
		$listing_information = get_post( intval($_GET['edit-listing']) );
		$listing_address = get_post_meta( intval($_GET['edit-listing']) , 'listing_address', true);
		$listing_address_lat = get_post_meta( intval($_GET['edit-listing']) , 'listing_address_lat', true);
		$listing_address_lng = get_post_meta( intval($_GET['edit-listing']) , 'listing_address_lng', true);
	}

	$output = '<div class="db-main-wrapper">';
		if ( isset($success_message) ) {
			$output .= '<div class="db-info-message success"><p>'.$success_message.'</p></div>';
		}

		if ( !$db_edit_listing && $main_settings['db_theme_id'] != 'default' ) {
			$output .= db_checkout_html( $package_data );
		}

		$output .= '
		<form method="post" id="db-add-listing-form">';
			$output .= '
			<div class="db-field-row required">
				<label for="listing_title">'.__('Listing title', 'directory-builder').'</label>
				<input type="text" name="listing_title" id="listing_title" placeholder="'.__('Listing title', 'directory-builder').'" value="'.(isset($listing_information->post_title)?$listing_information->post_title:(isset($_POST['listing_title'])?sanitize_text_field($_POST['listing_title']):'')).'">
				<div class="db-field-meta">
					<span class="db-field-row-required">'.__('This field is required!', 'directory-builder').'</span>
				</div>
			</div>
			<div class="db-field-row listing_excerpt">
				<label for="listing_excerpt">'.__('Listing short description', 'directory-builder').'</label>
				<textarea name="listing_excerpt" placeholder="'.__('Listing short description', 'directory-builder').'" id="listing_excerpt">'.(isset($listing_information->post_excerpt)?$listing_information->post_excerpt:(isset($_POST['listing_excerpt'])?sanitize_text_field($_POST['listing_excerpt']):'')).'</textarea>
			</div>
			<div class="db-field-row listing_content">
				<label for="listing_content">'.__('Listing long description', 'directory-builder').'</label>
				<textarea name="listing_content" placeholder="'.__('Listing long description', 'directory-builder').'" id="listing_content">'.(isset($listing_information->post_content)?$listing_information->post_content:(isset($_POST['listing_content'])?sanitize_text_field($_POST['listing_content']):'')).'</textarea>
			</div>';

			if ( !$db_edit_listing ) {
				if ( !defined('WHITELAB_CUSTOM_SELECT') ) {
					$output .= '
					<div class="db-field-row required">
						<label for="listing_address_lng">'.__('Listing category', 'directory-builder').'</label>
						'.$listing_categories.'
					</div>';
				} else {
					$term_settings = array(
						'taxonomy' => 'listing_category',
						'hide_empty' => false,
						'order' => 'asc',
						'orderby' => 'name'
					);
					$terms = get_terms( $term_settings );

					$output .= '
					<div class="db-field-row required listing_category single-select">
						<input type="text" class="dt-custom-select"  placeholder="'.__('Category', 'directory-builder').'" readonly>
						<input type="hidden" class="dt-custom-select-value" id="listing_category" name="listing_category">
						<div class="dt-custom-select-container">
							<div class="dt-custom-select-inner">
								<div class="dt-custom-select-items">';
									if ( !empty($terms) ) {
										foreach ($terms as $cat_data) {
											$output .= '<div class="dt-custom-select-item" data-value="'.$cat_data->term_id.'">'.$cat_data->name.'</div>';
										}
									}
								$output .= '
								</div>
								<div class="dt-custom-select-scrollbar-wrapper">
									<span class="dt-custom-select-scrollbar"></span>
								</div>
							</div>
						</div>
					</div>';
				}
			}
			
			$field_list = $wpdb->get_results('SELECT * FROM '.$wpdb->prefix.'directory_fields WHERE field_active="yes" ORDER BY field_order ASC');
			if ( !empty($field_list) ) {
				$default_location = $main_settings['default_location'];
				$default_location_lat = $main_settings['default_location_lat'];
				$default_location_lng = $main_settings['default_location_lng'];

				foreach ($field_list as $field_value) {
					$field_settings = json_decode($field_value->field_settings, true);

					$listing_field_default = '';
					if ( $db_edit_listing ) {
						$listing_field_default = get_post_meta( intval($_GET['edit-listing']), sanitize_text_field($field_settings['field_name']), true );
					}

					if ( $field_settings['field_name'] == 'listing_address' ) {
						$listing_field_default = $default_location;
					} else if ( $field_settings['field_name'] == 'listing_address_lat' ) {
						$listing_field_default = $default_location_lat;
					} else if ( $field_settings['field_name'] == 'listing_address_lng' ) {
						$listing_field_default = $default_location_lng;
					}

					if ( isset($_POST[$field_settings['field_name']]) ) {
						$listing_field_default = sanitize_text_field($_POST[$field_settings['field_name']]);
					}

					if ( $field_settings['field_name'] == 'listing_address' ) {
						$output .= '<div class="db-field-custom-row clearfix">';
					}

					if ( $field_settings['field_name'] == 'listing_address_lat' ) {
						$output .= '<div id="db-listing-map" style="width: calc(66.66% - 10px); height: 300px;"></div>';
						$output .= '<div class="db-map-row">';
					}

					$output .= db_get_custom_field( $field_settings, '', $listing_field_default, true );

					if ( $field_settings['field_name'] == 'listing_country' ) {
						$output .= '</div>';
					}

					if ( $field_settings['field_name'] == 'listing_address_lng' ) {
						$output .= '<a href="javascript:void(0)" class="db-set-address dt-button dt-button-invert">'.__('Set address on map', 'directory-builder').'</a>';
						$output .= '</div>';

						$output .= '<div class="db-field-upload-row-wrapper clearfix">';
							$output .= '<div class="db-field-upload-row">';
								$output .= '<h3>'.__('Featured image', 'directory-builder').'</h3>';
								$output .= '
								<div class="db-field-upload-container dropzone-upload dropzone-featured">
									<span class="db-upload-placeholder">'.__('Drag an image here or <a>browse</a> for the image to upload.', 'directory-builder').'</span>
									<div class="clearfix"></div>
									<input type="hidden" name="listing_featured_img" value="">
								</div>
								<span class="db-file-upload-hint">'.__('JPG, GIF or PNG. Featured images are 1000x1000 pixels.', 'directory-builder').'</span>';
							$output .= '</div>';
							$output .= '<div class="db-field-upload-row">';
								$output .= '<h3>'.__('Gallery images', 'directory-builder').'</h3>';
								$output .= '
								<div class="db-field-upload-container dropzone-upload dropzone-gallery">
									<span class="db-upload-placeholder">'.__('Drag an image here or <a>browse</a> for the image to upload.', 'directory-builder').'</span>
									<div class="clearfix"></div>
									<input type="hidden" name="listing_gallery_img" value="">
								</div>
								<span class="db-file-upload-hint">'.__('JPG, GIF or PNG. Featured images are 1000x1000 pixels.', 'directory-builder').'</span>';
							$output .= '</div>';
							$output .= '<div class="clearfix"></div>';
						$output .= '</div>';
					}
				}
			}

			if ( !$db_edit_listing && !is_user_logged_in() ) {
				$register_setting = $main_settings['add_listing_register'];

				$login_required = (!$register_setting?' required':'');

				global $db_user_login;
				if ( !$register_setting && $db_user_login ) {
					if ( is_wp_error( $db_user_login ) ) {
						$register_message = '<p>'.$db_user_login->get_error_message().'</p>';
					}
				}

				$output .= '
				<div class="db-register-wrapper">'
					.$register_message.'
					<div class="db-register-login">';
						if ( !$register_setting ) {
							$output .= '
							<div class="db-field-row db-login-username">'
								. __('Already have an account? Go ahead and sign in now!', 'directory-builder').'
								<label class="db-field-row-label" for="register_user_email">'.__('Your username', 'directory-builder').'</label>
								<input type="text" name="login_user_email" placeholder="'.__('Your username', 'directory-builder').'"'.$login_required.'>
							</div>
							<div class="db-field-row">
								<label class="db-field-row-label" for="login_user_password">'.__('Your password', 'directory-builder').'</label>
								<input type="password" name="login_user_password" placeholder="'.__('Your password', 'directory-builder').'"'.$login_required.'>
								<input type="submit" name="db-sign-in" value="'.__('Sign in', 'directory-builder').'">
							</div>';
						}
					if ( $register_setting ) {
						$login_url = get_permalink($main_settings['login_page_id']);
						$output .= '
						<div class="db-field-row db-register-email">'.
							__('Already have an account? Go ahead and', 'directory-builder').' <a href="'.$login_url.'">'.__('sign in', 'directory-builder').'</a> '.__('now!', 'directory-builder').' '.
							__('Or you can simply register with your email address below!', 'directory-builder').'
							<label class="db-field-row-label" for="register_user_email">'.__('Your email address', 'directory-builder').'</label>
							<input type="email" name="register_user_email" placeholder="'.__('example@email.com', 'directory-builder').'">
						</div>';
					}
				$output .= '
					</div>
				</div>';

				// if ( !$register_setting ) {
				// 	$output .= '</div>';
				// 	return $output;
				// }
			}

			if ( $main_settings['payment_active'] == 'yes' && !$db_edit_listing ) {
				$package_list = $wpdb->get_results('SELECT * FROM '.$wpdb->prefix.'directory_packages ORDER BY ID ASC');
				if ( !empty($package_list) ) {
					$output .= '<div class="db-field-row"><h3>'.__('Listing package', 'directory-builder').'</h3>';
					$output .= '<ul class="db-payment-packages">';

					$output .= '<li data-for="" style="display: none;width: 100%;">
							<p>Please select a category to see the available plans for it!</p>
						</li>';

					foreach ($package_list as $package_value) {
						$package_settings = json_decode($package_value->package_settings, true);
						$output .= '
						<li data-for="'.implode(',', isset($package_settings['apply_categories'])?$package_settings['apply_categories']:array()).'" class="'.($package_settings['listing_popular']?'popular':'').'" style="display: none;">
							<div class="db-package-inner">
								<label for="db-package-'.$package_value->ID.'"><input type="radio" id="db-package-'.$package_value->ID.'" name="listing_package" value="'.$package_value->ID.'"> '.$package_value->package_name.'</label>';
								if ( $package_settings['fee_description'] != '' ) {
									if ( $package_settings['listing_run_type'] == 'forever' ) {
										$run_listing = __('forever','directory-builder');
									} else {
										$run_listing = $package_settings['listing_run_days'].' '.__('days','directory-builder');
									}
									if ( !defined('WHITELAB_CUSTOM_ADD_LISTING') ) {
										$output .= '<div class="db-fee-description">
											<span class="db-fee-status-description">'.$package_settings['fee_description'].'</span>
											<span class="db-fee-status-name">'.__('Package price','directory-builder').': '.$main_settings['default_currency_symbol'].$package_settings['fee_amount'].'</span>
											<span class="db-fee-status-name">'.__('Run listing for','directory-builder').': '.$run_listing.'</span>
											<span class="db-fee-status-name">'.__('Images allowed','directory-builder').': '.$package_settings['image_amount'].'</span>
											<span class="db-fee-status-name">'.__('Listing sticky?','directory-builder').': '.$package_settings['listing_sticky'].'</span>
										</div>';
									} else {
										$output .= '
										<div class="db-fee-description">';
											if ( isset($package_settings['package_img']) && $package_settings['package_img'] != '' ) {
												$output .= '<img src="'.$package_settings['package_img'].'" class="db-fee-image">';
											}
											$output .= '
											<span class="db-fee-value">'.($package_settings['fee_amount']!='0'?$main_settings['default_currency_symbol'].$package_settings['fee_amount']:__('Free', 'directory-builder')).'</span>
											<span class="db-fee-description">'.$package_settings['fee_description'].'</span>
											<span class="db-fee-pay">'.__('One Time Payment','directory-builder').'</span>
											<span class="db-fee-run-for">'.__('Run listing for','directory-builder').' '.$run_listing.'</span>
											<span class="db-fee-images">'.$package_settings['image_amount'].' '.__('Images allowed','directory-builder').'</span>';
											if ( $package_settings['listing_sticky'] === true ) {
												$output .= '<span class="db-fee-sticky">'.__('Sticky listing','directory-builder').'</span>';
											}
										$output .= '
											<a href="javascript:void(0)" class="db-choose-package" data-id="'.$package_value->ID.'">'.__('Choose', 'directory-builder').'</a>
										</div>';
									}
								}
						$output .= '
							</div>   
						</li>';
					}
					$output .= '</ul><input type="hidden" name="db-active-package" value=""><div class="clearfix"></div></div>';
				} else {
					$output .= '<ul class="db-payment-packages">';

					$output .= '<li data-for="" style="width: 100%;">
							<p><strong>Please add some packages in the directory builder settings.</strong></p>
						</li>
						</ul>';
				}
			} elseif (($main_settings['payment_active'] == 'no' && !$db_edit_listing) || ($main_settings['payment_active'] == NULL && !$db_edit_listing)) {
				$output .= '<ul class="db-payment-packages">';

					$output .= '<li data-for="" style="width: 100%;">
							<p><strong>Payments are turned off in the settings, can\'t add listing. Please turn on payments in the directory builder settings.</strong></p>
						</li>
						</ul>';
			}

			if ( $main_settings['terms_and_conditions_status'] && !$db_edit_listing && $main_settings['db_theme_id'] != 'db_theme' ) {
				$output .= '<div class="db-field-row terms-and-conditions required">
					<label>'.__('Terms and conditions', 'directory-builder').'</label>
					<div class="db-terms-and-conditions">'.$main_settings['terms_and_conditions'].'</div>
					<label for="listing_terms_and_conditions"><input type="checkbox" id="listing_terms_and_conditions">'.__('I accept terms and conditions!', 'directory-builder').'</label>
				</div>';
			}

		$output .= '
			<input type="submit" value="'.(!$db_edit_listing?__('Add listing', 'directory-builder'):__('Save listing', 'directory-builder')).'" '.($db_edit_listing?'style="display: block;" class="db-edit-listing"':'').'>
		</form>';

	$output .= '</div>';

	return $output;
}
add_shortcode('directory_add_listing','db_add_listing_shortcode');

function db_inspect_scripts() {
	global $wp_scripts;

	if ( !empty($wp_scripts->registered) ) {
		foreach ($wp_scripts->registered as $script_key => $script_value) {
			if ( strpos($script_value->src, 'maps.googleapis.com/maps') !== false && $script_key != 'db-google-maps' ) {
				wp_dequeue_script( $script_key );
			}
			
		}
	}
}
add_action( 'wp_print_scripts', 'db_inspect_scripts' );

function db_add_listing_columns( $columns_ ) {
	$columns = array();

	foreach ( $columns_ as $k => $v ) {
		$columns[ $k ] = $v;
		if ( $k == 'cb' ) {
			$columns['payment_status'] = __( 'Status', 'directory-builder' );
		} else if ( $k == 'title' ) {
			$columns['listing_address'] = __( 'Address', 'directory-builder' );
			$columns['listing_author'] = __( 'Author', 'directory-builder' );
		}
	}

	return $columns;
}
add_action( 'manage_listings_posts_columns', 'db_add_listing_columns' );

function db_add_listing_payment_column( $column_name, $listing_id ) {
	if ( $column_name == 'payment_status' ) {
		$listing_data = get_post_meta( $listing_id, 'db_order_info', true );
		$status_class = 'dbicon-info-circled';
		$payment_status = (isset($listing_data['payment_status'])?$listing_data['payment_status']:'');
		
		if ( $payment_status == 'Pending' ) {
			$status_class = 'dbicon-cancel-circled2';
		} else if ( $payment_status == 'Completed' ) {
			$status_class = 'dbicon-ok-circled2';
		} else if ( $payment_status == 'Refunded' ) {
			$status_class = 'dbicon-cancel-circled2';
		}
		
		echo '<span class="db-listing-status '.$status_class.' '.strtolower($payment_status).'"></span><div class="row-actions"><span class="db-listing-payment-status">'.($payment_status?$payment_status:__('Processing', 'directory-builder')).'</span></div>';
	} else if ( $column_name == 'listing_author' ) {
		echo '<a href="'.admin_url('user-edit.php?user_id='.get_the_author_meta('ID')).'">'.get_the_author_meta('nicename', get_the_author_meta('ID')).'</a>';
	} else if ( $column_name == 'listing_address' ) {
		echo get_post_meta( $listing_id, 'listing_address', true );
	}
}
add_action( 'manage_listings_posts_custom_column', 'db_add_listing_payment_column', 10, 2 );

function db_change_package_func() {
	if ( !current_user_can('manage_options') ) die(0);

	$listing_id = ( isset($_POST['listing_id']) ? intval($_POST['listing_id']) : '' );
	$package_id = ( isset($_POST['package_id']) ? intval($_POST['package_id']) : '' );
	$package_name = ( isset($_POST['package_name']) ? sanitize_text_field($_POST['package_name']) : '' );

	$listing_info = get_post_meta( $listing_id, 'db_order_info', true );

	$listing_info['listing_package'] = $package_id;
	$listing_info['listing_package_name'] = $package_name;

	if ( update_post_meta( $listing_id, 'db_order_info', $listing_info ) ) {
		echo '{"save_response": "0", "package_name": "'.$package_name.'"}';
	} else {
		echo '{"save_response": "failed"}';
	}

	die(0);
}
add_action( 'wp_ajax_db_change_package', 'db_change_package_func' );

function db_change_expiration_func() {
	if ( !current_user_can('manage_options') ) die(0);

	$listing_id = ( isset($_POST['listing_id']) ? intval($_POST['listing_id']) : '' );
	$new_date = ( isset($_POST['new_date']) ? sanitize_text_field($_POST['new_date']) : '' );

	$listing_info = get_post_meta( $listing_id, 'db_order_info', true );
	global $wpdb;
	$save_expiration = false;

	$listing_info['listing_expires'] = strtotime($new_date);
	$save_expiration = update_post_meta( $listing_id, 'db_order_info', $listing_info );

	if ( $save_expiration ) {
		echo '{"save_response": "0", "package_name": "'.date( get_option('date_format'), $listing_info['listing_expires']).'"}';
	} else {
		echo '{"save_response": "failed"}';
	}

	die(0);
}
add_action( 'wp_ajax_db_change_expiration', 'db_change_expiration_func' );

function db_check_my_profile_form() {
	global $update_message;

	if ( isset($_POST['action']) && sanitize_key($_POST['action']) == 'edit-profile' ) {
		$user_new_data = array(
			'ID' => get_current_user_id(),
			'display_name' => sanitize_text_field($_POST['display_name']),
			'user_email' => sanitizee_email($_POST['user_email'])
			);

		$proceed_with_update = true;
		if ( isset($_POST['user_password']) && $_POST['user_password'] != '' ) {
			if ( isset($_POST['user_conf_password']) && $_POST['user_password'] == $_POST['user_conf_password'] ) {
				$user_new_data['user_pass'] = $_POST['user_password'];
			} else {
				$update_message = '<span class="db-update-message error">'.__('Passwords did not match!', 'directory-builder').'</span>';
				$proceed_with_update = false;
			}
		}

		if ( $proceed_with_update ) {
			$user_update = wp_update_user( $user_new_data );

			if ( is_wp_error( $user_update ) ) {
				$update_message = '<span class="db-update-message error">'.$user_update->get_error_message().'</span>';
			} else {
				$update_message = '<span class="db-update-message success">'.__('Your profile was successfully updated!', 'directory-builder').'</span>';
			}
		}
	}
}
add_action('init', 'db_check_my_profile_form');

function db_account_shortcode( $atts, $content = null ) {
	$main_settings = get_option( 'db_main_settings');

	$output = '<div class="db-main-wrapper">
		<link href="https://fonts.googleapis.com/css?family=Open+Sans:300,400,600" rel="stylesheet">';
	if ( !is_user_logged_in() ) {
		$output .= '<p>'.__('Only logged in users can access this page!', 'directory-builder').'</p>';
	} else {
		global $wpdb;
		if ( !isset($_GET['edit-listing']) ) {
			$listing_limit = '6';
			if ( isset($_GET['my-listings']) ) {
				$listing_limit = '9999';
			}
			$user_listings = $wpdb->get_results('SELECT * FROM '.$wpdb->posts.' WHERE post_type="listings" && ( post_status != "auto-draft" && post_status != "trash" ) && post_author="'.get_current_user_id().'" ORDER BY id DESC LIMIT '.$listing_limit);
		} else {
			$user_listings = $wpdb->get_results('SELECT * FROM '.$wpdb->posts.' WHERE id="'.intval($_GET['edit-listing']).'" && post_author="'.get_current_user_id().'" ORDER BY id DESC');
		}

		$users_are_allowed = $main_settings['users_are_allowed'];

		$output .= '
		<div class="db-account-wrapper">
		<ul class="db-account-menu">
			<li><a href="'.get_permalink().'" class="'.(empty($_GET)?'active':'').'">'.__('Dashboard', 'directory-builder').'</a></li>
			<li><a href="'.add_query_arg('my-profile', '', get_permalink()).'" class="'.(isset($_GET['my-profile'])?'active':'').'">'.__('Edit profile', 'directory-builder').'</a></li>';
			if ( $main_settings['add_page_id'] != '' ) {
				$output .= '<li><a href="'.get_permalink($main_settings['add_page_id']).'">'.__('Add new listing', 'directory-builder').'</a></li>';
			}
			$output .= '
			<li><a href="'.add_query_arg('my-listings', '', get_permalink()).'" class="'.(isset($_GET['my-listings'])?'active':'').'">'.__('My listings', 'directory-builder').'</a></li>
			<li><a href="'.add_query_arg('my-favorites', '', get_permalink()).'" class="'.(isset($_GET['my-favorites'])?'active':'').'">'.__('My favorites', 'directory-builder').'</a></li>
		</ul>';

		if ( !isset($_GET['my-listings']) && !isset($_GET['my-favorites']) && !isset($_GET['edit-listing']) && !isset($_GET['my-profile']) ) {
			$output .= '<p class="db-account-intro">'.__('Welcome to your dashboard! From here you can manage all  your listings, check your favorites and edit your profile.', 'directory-builder').'</p>';

			$user_data = get_userdata(get_current_user_id());
			$output .= '
			<h2 class="db-account-title">'.__('Profile', 'directory-builder').'</h2>
			<div class="db-account-profile-intro">
				<span class="db-account-row">
					<span class="db-account-label">'.__('Username', 'directory-builder').':</span>
					<span class="db-account-value">'.$user_data->data->display_name.'</span>
				</span>
				<span class="db-account-row">
					<span class="db-account-label">'.__('Email', 'directory-builder').':</span>
					<span class="db-account-value">'.$user_data->data->user_email.'</span>
				</span>
				<span class="db-account-row">
					<span class="db-account-label">'.__('Password', 'directory-builder').':</span>
					<span class="db-account-value">**********</span>
				</span>
				<a href="'.add_query_arg('my-profile', '', get_permalink()).'">'.__('Edit profile', 'directory-builder').'</a>
				<div class="clearfix"></div>
			</div>';
		}
		
		if ( !isset($_GET['edit-listing']) && !isset($_GET['my-profile']) ) {
			if ( !isset($_GET['my-favorites']) && !empty($user_listings) ) {
				$output .= db_checkout_html();
				$output .= '
				<h2 class="db-account-title">'.__('Listings', 'directory-builder').'</h2>
				<table class="db-account-listings table table-striped table-hover">
					<thead>
						<tr>
							<th style="width: 28.6%;">'.__('Name', 'directory-builder').'</th>
							<th style="width: 12.5%;">'.__('Status', 'directory-builder').'</th>
							<th style="width: 15%;">'.__('Package', 'directory-builder').'</th>
							<th style="width: 20%;">'.__('Expires on', 'directory-builder').'</th>
							<th style="width: 10%;">'.__('Sticky', 'directory-builder').'</th>
							<th style="width: 15%;"></th>
						</tr>
					</thead>
					<tbody>';
						$listing_loop = 1;
						foreach ($user_listings as $listing_data) {
							$order_options = get_post_meta( $listing_data->ID, 'db_order_info', true );
							if ( $order_options == '' ) {
								$order_options = array();
							}
							$ratings = get_post_meta( $listing_data->ID, 'listing_ratings', true);
							if ( $ratings == '' ) {
								$rating_stars = '<i class="dbicon-star-empty"></i><i class="dbicon-star-empty"></i><i class="dbicon-star-empty"></i><i class="dbicon-star-empty"></i><i class="dbicon-star-empty"></i>';
							} else {
								$listing_rating = 0;
								foreach ($ratings as $rating_value) {
									$listing_rating += $rating_value;
								}
								$listing_rating = $listing_rating/count($ratings);
								$rating_stars = db_get_rating_stars(round($listing_rating, 0, PHP_ROUND_HALF_DOWN));
							}

							if ( isset($order_options['listing_package']) ) {
								$package_list = $wpdb->get_results('SELECT * FROM '.$wpdb->prefix.'directory_packages WHERE ID="'.$order_options['listing_package'].'"');
								if ( !empty($package_list) ) {
									$field_settings = json_decode($package_list['0']->package_settings, true);

									if ( $field_settings['listing_run_type'] == 'forever' ) {
										$listing_expiration = __('Never', 'directory-builder');
									} else if ( $field_settings['listing_run_type'] == 'days' && $order_options['listing_expires'] != 'Unknown' ) {
										$listing_expiration = date( get_option('date_format'), $order_options['listing_expires']);
									} else {
										$listing_expiration = __('Unknown', 'directory-builder');
									}

									$package_amount = $field_settings['fee_amount'];
									$package_run_type = $field_settings['listing_run_type'];
								}
							} else {
								$listing_expiration = __('Unknown', 'directory-builder');
							}

							$sticky_listings = get_option('db_sticky_listings', array());

							$output .= '
							<tr>
								<td>'.$listing_data->post_title.'</td>
								<td class="db-align-center">'.(isset($order_options['payment_status'])?$order_options['payment_status']:$listing_data->post_status).'</td>
								<td class="db-align-center">'.(isset($order_options['listing_package_name'])?$order_options['listing_package_name']:__('Unknown', 'directory-builder')).'</td>
								<td class="db-align-center">'.$listing_expiration.'</td>
								<td class="db-align-center">'.(in_array($listing_data->ID, $sticky_listings)?__('Yes', 'directory-builder'):__('No', 'directory-builder')).'</td>
								<td>';
									if ( isset($order_options['completed_on']) && is_numeric($order_options['completed_on']) && $package_amount != '0' && $package_run_type == 'days' ) {
										$output .= '<a href="javascript:void(0)" data-id="'.$order_options['listing_package'].'" data-list-id="'.$listing_data->ID.'" class="db-account-listing-option renew"><span class="db-account-listing-option-hover">'.esc_html__('Renew', 'directory-builder').'</span><svg width="14px" height="14px" viewBox="0 0 14 14" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"><g stroke="none" stroke-width="1" fill="none" fill-rule="evenodd"><g   transform="translate(-1125.000000, -858.000000)" fill="#247BA0"><g id="listings" transform="translate(149.000000, 683.000000)"><g id="add" transform="translate(951.000000, 123.000000)"><g   transform="translate(25.000000, 52.000000)"><g id="Group"><path d="M13.5826638,0 L3.09598309,0 C2.87399577,0 2.69640592,0.177589852 2.69640592,0.399577167 L2.69640592,10.8862579 C2.69640592,11.1082452 2.87399577,11.2858351 3.09598309,11.2858351 L13.5826638,11.2858351 C13.8046512,11.2858351 13.982241,11.1082452 13.982241,10.8862579 L13.982241,0.399577167 C13.982241,0.177589852 13.8046512,0 13.5826638,0 L13.5826638,0 Z M13.1830867,10.4866808 L3.49556025,10.4866808 L3.49556025,0.799154334 L13.1830867,0.799154334 L13.1830867,10.4866808 L13.1830867,10.4866808 L13.1830867,10.4866808 Z"  ></path><path d="M10.8862579,13.1830867 L0.799154334,13.1830867 L0.799154334,3.09598309 C0.799154334,2.87399577 0.621564482,2.69640592 0.399577167,2.69640592 C0.177589852,2.69640592 0,2.87399577 0,3.09598309 L0,13.5826638 C0,13.8046512 0.177589852,13.982241 0.399577167,13.982241 L10.8862579,13.982241 C11.1082452,13.982241 11.2858351,13.8046512 11.2858351,13.5826638 C11.2858351,13.3606765 11.1082452,13.1830867 10.8862579,13.1830867 L10.8862579,13.1830867 Z"  ></path><path d="M6.07357294,6.04397463 L7.93826638,6.04397463 L7.93826638,7.90866808 C7.93826638,8.13065539 8.11585624,8.30824524 8.33784355,8.30824524 C8.55983087,8.30824524 8.73742072,8.13065539 8.73742072,7.90866808 L8.73742072,6.04397463 L10.605074,6.04397463 C10.8270613,6.04397463 11.0046512,5.86638478 11.0046512,5.64439746 C11.0046512,5.42241015 10.8270613,5.2448203 10.605074,5.2448203 L8.73742072,5.2448203 L8.73742072,3.37716702 C8.73742072,3.1551797 8.55983087,2.97758985 8.33784355,2.97758985 C8.11585624,2.97758985 7.93826638,3.1551797 7.93826638,3.37716702 L7.93826638,5.2448203 L6.07357294,5.2448203 C5.85158562,5.2448203 5.67399577,5.42241015 5.67399577,5.64439746 C5.67399577,5.86638478 5.85158562,6.04397463 6.07357294,6.04397463 L6.07357294,6.04397463 Z"  ></path></g></g></g></g></g></g></svg></a>';
									}

									$view_text = '';
									$view_url = '#';
									if ( $listing_data->post_status == 'publish' ) {
										$view_text = __('View', 'directory-builder');
										$view_url = get_permalink($listing_data->ID);
									} else {
										$view_text = __('Preview', 'directory-builder');
										$view_url = add_query_arg('preview', 'true', get_permalink($listing_data->ID));
									}
									

									$output .= '
									<a href="'.$view_url.'" class="db-account-listing-option view">
										<span class="db-account-listing-option-hover">'.$view_text.'</span>
										<svg width="18px" height="12px" viewBox="0 0 18 12" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"><g stroke="none" stroke-width="1" fill="none" fill-rule="evenodd"><g   transform="translate(-1164.000000, -859.000000)" fill="#53666D"><g id="listings" transform="translate(149.000000, 683.000000)"><g id="eye-copy" transform="translate(1008.000000, 166.000000)"><g id="eye-(2)" transform="translate(7.000000, 10.000000)"><g id="Layer_1"><g id="Group"><path d="M17.9640352,5.82672414 C16.4323125,2.29437931 12.9136289,0.011862069 9,0.011862069 C5.08637109,0.011862069 1.56775781,2.29431034 0.0359648437,5.82672414 C-0.0119882812,5.93727586 -0.0119882812,6.06213793 0.0359648437,6.17268966 C1.56765234,9.70544828 5.08630078,11.9881379 9,11.9881379 C12.9138047,11.9881379 16.432418,9.70544828 17.9640352,6.17268966 C18.0119883,6.06213793 18.0119883,5.93727586 17.9640352,5.82672414 L17.9640352,5.82672414 Z M9,11.1042069 C5.51271094,11.1042069 2.37104297,9.10689655 0.942503906,5.99975862 C2.37107813,2.89293103 5.51281641,0.895827586 9,0.895827586 C12.4872539,0.895827586 15.628957,2.89293103 17.0574961,5.99968966 C15.628957,9.10682759 12.4872891,11.1042069 9,11.1042069 L9,11.1042069 Z"  ></path><path d="M9,2.61465517 C7.09685156,2.61465517 5.54857031,4.13331034 5.54857031,5.99996552 C5.54857031,7.86662069 7.09688672,9.38527586 9,9.38527586 C10.9031133,9.38527586 12.4514297,7.86665517 12.4514297,5.99996552 C12.4514297,4.13327586 10.9031133,2.61465517 9,2.61465517 L9,2.61465517 Z M9,8.50141379 C7.59382031,8.50141379 6.44976563,7.37927586 6.44976563,6.00003448 C6.44976563,4.6207931 7.59382031,3.49865517 9,3.49865517 C10.4061797,3.49865517 11.5502344,4.6207931 11.5502344,6.00003448 C11.5502344,7.37927586 10.4061797,8.50141379 9,8.50141379 L9,8.50141379 Z"  ></path><path d="M9,4.20268966 C7.98964453,4.20268966 7.16755078,5.00896552 7.16755078,6.00003448 C7.16755078,6.24410345 7.36924219,6.442 7.61814844,6.442 C7.86705469,6.442 8.06874609,6.24410345 8.06874609,6.00003448 C8.06874609,5.49637931 8.48647266,5.08662069 9,5.08662069 C9.24890625,5.08662069 9.45059766,4.88872414 9.45059766,4.64465517 C9.45059766,4.40051724 9.24883594,4.20268966 9,4.20268966 L9,4.20268966 Z"  ></path></g></g></g></g></g></g></g></svg>
									</a>';
									if ( in_array('delete', $users_are_allowed) ) {
										$output .= '
										<a href="javascript:void(0)" class="db-delete-listing db-account-listing-option delete" data-id="'.$listing_data->ID.'">
											<span class="db-account-listing-option-hover">'.__('Delete', 'directory-builder').'</span>
											<svg width="11px" height="14px" viewBox="0 0 11 14" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"><g stroke="none" stroke-width="1" fill="none" fill-rule="evenodd"><g   transform="translate(-1208.000000, -858.000000)" fill="#53666D"><g id="listings" transform="translate(149.000000, 683.000000)"><g id="rubbish-bin-copy" transform="translate(1049.000000, 166.000000)"><g   transform="translate(10.000000, 9.000000)"><g id="Group"><path d="M10.0372757,1.64692387 L8.1821876,1.64692387 L8.1821876,0.433385806 C8.1821876,0.189117419 7.98646656,0 7.7438385,0 C7.72029527,0 7.7045938,0.00791225806 7.69693148,0.0158064516 C7.68907178,0.00791225806 7.67337031,0 7.66552855,0 L3.30559869,0 L3.2743752,0 L3.24297227,0 C3.00034421,0 2.81248287,0.189117419 2.81248287,0.433385806 L2.81248287,1.64694194 L0.949553018,1.64694194 C0.417192496,1.64694194 0.00238662316,2.06452129 0.00238662316,2.60044129 L0.00238662316,3.29388387 L0.00238662316,4.16063742 L0.824300163,4.16063742 L0.824300163,13.0411535 C0.824300163,13.5770916 1.23126427,13.9867587 1.7636248,13.9867587 L9.22322186,13.9867587 C9.75558238,13.9867587 10.1703703,13.5770916 10.1703703,13.0411535 L10.1703703,4.16063742 L10.9844421,4.16063742 L10.9844421,3.29388387 L10.9844421,2.60044129 C10.9844421,2.06452129 10.5694747,1.64692387 10.0372757,1.64692387 L10.0372757,1.64692387 Z M3.67347961,0.866753548 L7.3133491,0.866753548 L7.3133491,1.64692387 L3.67347961,1.64692387 L3.67347961,0.866753548 L3.67347961,0.866753548 Z M9.30153181,13.0411716 C9.30153181,13.0964671 9.27798858,13.1199871 9.22322186,13.1199871 L1.7636248,13.1199871 C1.70885808,13.1199871 1.68531485,13.096449 1.68531485,13.0411716 L1.68531485,4.16061935 L9.30153181,4.16061935 L9.30153181,13.0411716 L9.30153181,13.0411716 Z M10.1156036,3.29386581 L0.871225122,3.29386581 L0.871225122,2.60042323 C0.871225122,2.54527226 0.894768352,2.51367742 0.949535073,2.51367742 L10.0372757,2.51367742 C10.0920604,2.51367742 10.1156036,2.54527226 10.1156036,2.60042323 L10.1156036,3.29386581 L10.1156036,3.29386581 Z"  ></path><rect id="Rectangle-path" x="7.0707031" y="5.17716387" width="0.868838499" height="7.17056516"></rect><rect id="Rectangle-path" x="5.06683687" y="5.17716387" width="0.868838499" height="7.17056516"></rect><rect id="Rectangle-path" x="3.06295269" y="5.17716387" width="0.868838499" height="7.17056516"></rect></g></g></g></g></g></g></svg>
										</a>';
									}
									if ( in_array('edit', $users_are_allowed) ) {
										$output .= '
										<a href="'.add_query_arg('edit-listing', $listing_data->ID, get_permalink($main_settings['add_page_id'])).'" class="db-edit-listing db-account-listing-option edit" data-id="'.$listing_data->ID.'">
											<span class="db-account-listing-option-hover">'.__('Edit', 'directory-builder').'</span>
											<svg width="14px" height="14px" viewBox="0 0 14 14" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"><g stroke="none" stroke-width="1" fill="none" fill-rule="evenodd"><g   transform="translate(-1248.000000, -858.000000)" fill="#53666D"><g id="listings" transform="translate(149.000000, 683.000000)"><g id="edit-copy" transform="translate(1090.000000, 166.000000)"><g   transform="translate(9.000000, 9.000000)"><path d="M13.0745404,0.905621277 C11.8711362,-0.300761702 9.91411489,-0.300761702 8.71071064,0.905621277 L0.709859574,8.90349362 C0.647306383,8.96604681 0.608582979,9.04647234 0.596668085,9.13285532 L0.00390212766,13.5234936 C-0.0139702128,13.6486 0.0307106383,13.7737064 0.117093617,13.8600894 C0.191561702,13.9345574 0.295817021,13.9792383 0.40007234,13.9792383 C0.417944681,13.9792383 0.435817021,13.9792383 0.453689362,13.9762596 L3.09879574,13.6188128 C3.31922128,13.5890255 3.47411489,13.3864723 3.44432766,13.1660468 C3.41454043,12.9456213 3.21198723,12.7907277 2.9915617,12.8205149 L0.870710638,13.1064723 L1.28475319,10.0443447 L4.50773191,13.2673234 C4.5822,13.3417915 4.68645532,13.3864723 4.79071064,13.3864723 C4.89496596,13.3864723 4.99922128,13.3447702 5.07368936,13.2673234 L13.0745404,5.26945106 C13.6583702,4.68562128 13.9800723,3.91115319 13.9800723,3.08604681 C13.9800723,2.26094043 13.6583702,1.48647234 13.0745404,0.905621277 L13.0745404,0.905621277 Z M8.86560426,1.8886 L10.2090085,3.23200426 L2.90815745,10.5328553 L1.56475319,9.18945106 L8.86560426,1.8886 L8.86560426,1.8886 Z M4.79368936,12.4154085 L3.48007234,11.1017915 L10.7809234,3.80094043 L12.0945404,5.11455745 L4.79368936,12.4154085 L4.79368936,12.4154085 Z M12.6545404,4.53966383 L9.44049787,1.32562128 C9.84858298,0.989025532 10.3579447,0.804344681 10.8941149,0.804344681 C11.5047532,0.804344681 12.0766681,1.04264255 12.508583,1.47157872 C12.9404979,1.90051489 13.175817,2.47540851 13.175817,3.08604681 C13.175817,3.62519574 12.9911362,4.13157872 12.6545404,4.53966383 L12.6545404,4.53966383 Z"  ></path></g></g></g></g></g></svg>
										</a>';
									}
									$output .= ' ';
								$output .= '    
								</td>
							</tr>';
							if ( $listing_loop == 5 && !isset($_GET['my-listings']) ) {
								break;
							}
							$listing_loop++;
						}
						$output .= '
					</tbody>
				</table>';
				if ( count($user_listings) > 5 && !isset($_GET['my-listings']) ) {
					$output .= '<a href="'.add_query_arg('my-listings', '', get_permalink()).'" class="db-see-all-listing dt-button dt-button-invert">'.__('See all listings', 'directory-builder').'</a><div class="clearfix"></div>';
				}
			}
			if ( !isset($_GET['my-listings']) ) {
				$favorite_limit = '3';
				if ( isset($_GET['my-favorites']) ) {
					$favorite_limit = '9999';
				}
				$output .= '
				<div class="db-account-favorites"'.(isset($_GET['my-favorites'])?' style="margin-top: 0;"':'').'>
					<h2 class="db-account-title">'.__('Favorites', 'directory-builder').'</h2>
					'.do_shortcode('[directory_featured_listings limit="'.$favorite_limit.'" type="favorites"]');
					if ( !isset($_GET['my-favorites']) ) {
						$output .= '<a href="'.add_query_arg('my-favorites', '', get_permalink()).'" class="db-see-all-favorites dt-button dt-button-invert">'.__('See all favorites', 'directory-builder').'</a><div class="clearfix"></div>';
					}
				$output .= '
				</div>';
			}
		} else if ( isset($_GET['my-profile']) ) {
			$user_data = get_userdata(get_current_user_id());
			global $update_message;

			$output .= '
			<div class="db-account-profile">
				<h2 class="db-account-title">'.__('My profile', 'directory-builder').'</h2>'
				.$update_message.
				'<form method="post" id="db-edit-profile">
					<div class="db-field-row">
						<label for="display_name">'.__('Username', 'directory-builder').'</label>
						<input type="text" name="display_name" id="display_name" placeholder="'.__('Username', 'directory-builder').'" value="'.(isset($_POST['display_name'])?sanitize_text_field($_POST['display_name']):$user_data->data->display_name).'">
					</div>
					<div class="db-field-row">
						<label for="user_email">'.__('Email', 'directory-builder').'</label>
						<input type="email" name="user_email" id="user_email" placeholder="'.__('Email', 'directory-builder').'" value="'.(isset($_POST['user_email'])?sanitizee_email($_POST['user_email']):$user_data->data->user_email).'">
					</div>
					<div class="db-field-row">
						<label for="user_password">'.__('Password', 'directory-builder').'</label>
						<input type="password" name="user_password" id="user_password" placeholder="'.__('Password', 'directory-builder').'" value="">
					</div>
					<div class="db-field-row">
						<label for="user_conf_password">'.__('Confirm password', 'directory-builder').'</label>
						<input type="password" name="user_conf_password" id="user_conf_password" placeholder="'.__('Confirm password', 'directory-builder').'" value="">
					</div>
					<input type="hidden" name="action" value="edit-profile">
					<input type="submit" value="'.__('Save', 'directory-builder').'">
				</form>';
		}
	}
	$output .= '</div></div>';

	return $output;
}
add_shortcode('directory_account','db_account_shortcode');

function db_account_delete_listing_func() {
	if ( !current_user_can('manage_options') ) die(0);

	$listing_id = ( isset($_POST['listing_id']) ? intval($_POST['listing_id']) : '' );
	$deleting = false;

	global $wpdb;
	$package_list = $wpdb->get_results('SELECT * FROM '.$wpdb->posts.' WHERE ID="'.$listing_id.'" && post_author="'.get_current_user_id().'"');
	if ( !empty($package_list) ) {
		$deleting = wp_delete_post( $package_list['0']->ID, true );
	}

	if ( $deleting ) {
		echo '{"save_response": "0"}';
	} else {
		echo '{"save_response": "failed"}';
	}

	die(0);
}
add_action( 'wp_ajax_db_account_delete_listing', 'db_account_delete_listing_func' );

function db_add_to_url( $name, $value ) {
	$params = $_GET;
	unset($params[$name]);
	$params[$name] = $value;
	return basename($_SERVER['PHP_SELF']).'?'.http_build_query($params);
}

function db_install_theme( $file ) {
	require_once plugin_dir_path( __FILE__ ) . 'includes/file_system.php';
	$themes_dir = wp_normalize_path( WP_CONTENT_DIR . '/db-plugin-themes/' );
	list( $temp_dir, $unzipped_dir, ) = WPDB_FS::unzip_to_temp_dir( $file );
	$package_dir = $unzipped_dir;

	// Search for a dir containing 'theme.json'.
	$files = WPDB_FS::ls( $unzipped_dir, 'recursive=1' );
	foreach ( $files as $f ) {
		if ( 'theme_data.json' == basename( $f ) ) {
			$package_dir = dirname( $f );
			break;
		}
	}

	if ( ! file_exists( WPDB_FS::join( $package_dir, 'theme_data.json' ) ) ) {
		WPDB_FS::rmdir( $temp_dir );
		return __( 'ZIP file is not a valid Directory builder theme file.', 'directory-builder' );
	}

	if ( ! WPDB_FS::mkdir( $themes_dir ) ) {
		WPDB_FS::rmdir( $temp_dir );
		return __( 'Could not create themes directory.', 'directory-builder' );
	}

	$dest_dir = $themes_dir . basename( $package_dir );

	if ( ! WPDB_FS::rmdir( $dest_dir ) ) {
		WPDB_FS::rmdir( $temp_dir );
		return sprintf( __( 'Could not remove previous theme directory "%s".', 'directory-builder' ), $dest_dir );
	}

	if ( ! WPDB_FS::movedir( $package_dir, $themes_dir ) ) {
		WPDB_FS::rmdir( $temp_dir );
		return __( 'Could not move new theme into theme directory.', 'directory-builder');
	}

	WPDB_FS::rmdir( $temp_dir );

	return '';
}

function db_upload_theme( $theme_file ) {
	$file_extension = pathinfo($theme_file['name'], PATHINFO_EXTENSION);

	if ( $file_extension != 'zip' || !is_uploaded_file( $theme_file['tmp_name'] ) || UPLOAD_ERR_OK != $theme_file['error'] ) {
		return '<p class="db-theme-status-inner error">'.__('This is not a valid Directory builder plugin theme!', 'directory-builder').'</p>';
	}

	$dest = wp_normalize_path( untrailingslashit( get_temp_dir() ) . DIRECTORY_SEPARATOR . $theme_file['name'] );

	if ( ! move_uploaded_file( $theme_file['tmp_name'], $dest ) ) {
		return '<p class="db-theme-status-inner error">'.$res->get_error_message().'</p>';
	}

	$res = db_install_theme( $dest );

	if ( is_wp_error( $res ) ) {
		return '<p class="db-theme-status-inner error">'.$res->get_error_message().'</p>';
	} else {
		return $res;
	}
}

function db_theme_html() {
	if ( !current_user_can('manage_options') )  {
		wp_die( __('You do not have sufficient permissions to access this page.', 'directory-builder') );
	}
	$main_settings = get_option( 'db_main_settings');
	$error_message = '';
	?>

	<?php
	if ( isset( $_FILES['db-theme-zip'] ) ) {
		$theme_file = isset( $_FILES['db-theme-zip'] ) ? $_FILES['db-theme-zip'] : false;

		if ( $theme_file !== false ) {
			$error_message = db_upload_theme( $theme_file );
		}

	}
	?>

	<div class="db-main-wrapper container-fluid" id="db-main-wrapper">
		<div class="db-main-content main-card clearfix">
			<div class="db-box-title">
				<h3 class="db-main-title">Theme settings</h3>
			</div>
			<div class="db-theme-status"><?php echo $error_message; ?></div>
			<div class="db-row-group clearfix">
				<span class="db-row-label col-sm-2">Upload theme</span>
				<div class="col-sm-10">
					<form action="" method="post" enctype="multipart/form-data">
						<input type="file" name="db-theme-zip">
						<input type="submit" value="Upload">
					</form>
				</div>
			</div>
		</div>
		<div class="db-theme-list">
			<?php
				$theme_list = db_get_theme_list();
				$theme_list_output = '';

				foreach ( $theme_list as $theme_value ) {
					$theme_list_output .= '
					<div class="db-theme-list-item col-md-4">
						<div class="db-theme-list-inner main-card">
							<div class="db-box-title">
								<h3 class="db-main-title">'.(isset($theme_value['theme_name'])?$theme_value['theme_name']:__('No name', 'directory-builder')).'</h3>';
								if ( ( $main_settings['db_theme_id'] != '' && $main_settings['db_theme_id'] == $theme_value['theme_id'] ) ) {
									$theme_list_output .= '<span class="db-active-theme db-button db-default-button non-clickable">'.__('Active', 'directory-builder').'</span>';
								} else {
									$theme_list_output .= '<a href="javascript:void(0)" class="db-activate-theme db-button db-primary-button" data-id="'.$theme_value['theme_id'].'" data-path="'.$theme_value['theme_path'].'" data-url="'.$theme_value['theme_url'].'">'.__('Activate', 'directory-builder').'</a>';
								}
							$theme_list_output .= '
							</div>
							<div class="db-theme-list-overlay clearfix">
								<img src="'.$theme_value['theme_image'].'">
								<div class="db-theme-info">';
									if ( isset($theme_value['theme_version']) ) {
										$theme_list_output .= '
										<div class="db-theme-list-row">
											<span class="db-theme-row-label">'.__('Version', 'directory-builder').':</span>
											<span class="db-theme-row-value">'.$theme_value['theme_version'].'</span>
										</div>';
									}
									if ( isset($theme_value['updated']) ) {
										$theme_list_output .= '
										<div class="db-theme-list-row">
											<span class="db-theme-row-label">'.__('Updated', 'directory-builder').':</span>
											<span class="db-theme-row-value">'.$theme_value['updated'].'</span>
										</div>';
									}
									if ( isset($theme_value['theme_author']) ) {
										$theme_list_output .= '
										<div class="db-theme-list-row">
											<span class="db-theme-row-label">'.__('Author', 'directory-builder').':</span>
											<span class="db-theme-row-value">'.$theme_value['theme_author'].'</span>
										</div>';
									}
									if ( isset($theme_value['theme_description']) ) {
										$theme_list_output .= '
										<div class="db-theme-list-row description">
											<span class="db-theme-row-value">'.$theme_value['theme_description'].'</span>
										</div>';
									}
							$theme_list_output .= '
								</div>
							</div>
						</div>
					</div>';
				}

				echo $theme_list_output;
			?>
		</div>
	</div>
	<?php
}

function db_get_theme_list() {
	$available_themes = array();

	// Check plugin theme
	if ( file_exists( plugin_dir_path( __FILE__ ).'/template/theme_data.json' ) ) {
		$theme_info = json_decode( file_get_contents( plugin_dir_path( __FILE__ ).'/template/theme_data.json' ), true );
		$theme_info['theme_image'] = plugin_dir_url( __FILE__ ).'template/theme_preview.jpg';
		$theme_info['theme_path'] = plugin_dir_path( __FILE__ ).'template/';
		$theme_info['theme_url'] = plugin_dir_url( __FILE__ ).'template/';

		$available_themes[] = $theme_info;
	}

	// Check WordPress theme
	if ( file_exists( get_template_directory().'/directory-template/theme_data.json' ) ) {
		$theme_info = json_decode( file_get_contents( get_template_directory().'/directory-template/theme_data.json' ), true );
		$theme_info['theme_image'] = get_template_directory_uri().'/directory-template/theme_preview.jpg';
		$theme_info['theme_path'] = get_template_directory().'/directory-template/';
		$theme_info['theme_url'] = get_template_directory_uri().'/directory-template/';

		$available_themes[] = $theme_info;
	}

	// Check uploaded themes
	$themes_dir = wp_normalize_path( WP_CONTENT_DIR . '/db-plugin-themes/' );
	if ( file_exists( $themes_dir ) ) {
		$themes_dir_url = WP_CONTENT_URL . '/db-plugin-themes/';
		$plugin_custom_themes = scandir($themes_dir);
		unset($plugin_custom_themes['0']);
		unset($plugin_custom_themes['1']);
		
		if ( !empty($plugin_custom_themes) ) {
			foreach ($plugin_custom_themes as $file_directory) {
				if ( file_exists($themes_dir.$file_directory.'/theme_data.json') ) {
					$theme_info = json_decode( file_get_contents( $themes_dir.$file_directory.'/theme_data.json' ), true );
					$theme_info['theme_image'] = $themes_dir_url.$file_directory.'/theme_preview.jpg';
					$theme_info['theme_path'] = $themes_dir.$file_directory.'/';
					$theme_info['theme_url'] = $themes_dir_url.$file_directory.'/';

					$available_themes[] = $theme_info;
				}
			}
		}
	}

	return $available_themes;
}

function db_activate_theme() {
	if ( !current_user_can('manage_options') ) die(0);

	global $wpdb;
	$theme_id = ( isset($_POST['theme_id']) ? sanitize_text_field($_POST['theme_id']) : '' );
	$theme_path = ( isset($_POST['theme_path']) ? sanitize_text_field($_POST['theme_path']) : '' );
	$theme_url = ( isset($_POST['theme_url']) ? esc_url($_POST['theme_url']) : '' );
	$main_settings = get_option( 'db_main_settings');

	$main_settings['db_theme_id'] = $theme_id;
	$main_settings['db_theme_path'] = $theme_path;
	$main_settings['db_theme_url'] = $theme_url;

	if ( !update_option( 'db_main_settings', $main_settings ) ) {
		echo '{"save_response": "failed"}';
	} else {
		echo '{"save_response": "0"}';
	}


	die(0);
}
add_action( 'wp_ajax_db_activate_theme', 'db_activate_theme' );

function db_directory_login_shortcode() {
	global $db_user_login;

	$output = '
	<div class="db-main-wrapper">';
		if ( is_wp_error($db_user_login) ) {
			$output .= '<p>'.$db_user_login->get_error_message().'</p>';
		}
		$output .= '
		<form method="post" id="db-login-form">
			<input type="text" name="login_user_email" placeholder="'.__('Your username', 'directory-builder').'" value="'.(isset($_POST['login_user_email'])?sanitize_email($_POST['login_user_email']):'').'" required>
			<input type="password" name="login_user_password" placeholder="'.__('Your password', 'directory-builder').'" value="'.(isset($_POST['login_user_password'])?$_POST['login_user_password']:'').'" required>
			<input type="submit" name="db-sign-in" value="'.__('Sign in', 'directory-builder').'">
		</form>';
	$output .= '</div>';

	if ( !is_user_logged_in() ) {
		return $output;
	} else {
		$current_user = wp_get_current_user();
		return '<p>'.__('Nice to see you back', 'directory-builder').', '.$current_user->data->display_name.'. '.__('Not you?', 'directory-builder').' <a href="'.wp_logout_url().'">'.__('Logout', 'directory-builder').'</a></p>';
	}
}
add_shortcode('directory_login','db_directory_login_shortcode');

function db_directory_register_shortcode() {
	global $db_user_register;

	$output = '
	<div class="db-main-wrapper">';
		if ( is_wp_error($db_user_register) ) {
			$output .= '<p><b>'.__('ERROR', 'directory-builder').':</b> '.$db_user_register->get_error_message().'</p>';
		} else if ( isset($db_user_register) ) {
			$output .= '<p>'.__('You\'re successfully registered. You can now', 'directory-builder').' <a href="'.wp_login_url().'">'.__('Sign in', 'directory-builder').'</a>!</p>';
		}
		$output .= '
		<form method="post" id="db-register-form">
			<input type="email" name="register_user_email" placeholder="'.__('Your email address', 'directory-builder').'" value="'.(isset($_POST['register_user_email'])?sanitize_email($_POST['register_user_email']):'').'" required>
			<input type="password" name="register_user_password" placeholder="'.__('Your password', 'directory-builder').'" required>
			<input type="password" name="register_user_password_confirm" placeholder="'.__('Confirm your password', 'directory-builder').'" required>
			<input type="submit" name="db-register" value="'.__('Register', 'directory-builder').'">
		</form>';
	$output .= '</div>';

	return $output;
}
add_shortcode('directory_register','db_directory_register_shortcode');

function db_change_status_func() {
	if ( !current_user_can('manage_options') ) die(0);

	$listing_id = ( isset($_POST['listing_id']) ? intval($_POST['listing_id']) : '' );
	$listing_status = ( isset($_POST['listing_status']) ? sanitize_text_field($_POST['listing_status']) : '' );

	$listing_info = get_post_meta( $listing_id, 'db_order_info', true );

	$listing_info['payment_status'] = $listing_status;
	if ( $listing_status == 'Completed' ) {
		$listing_info['completed_on'] = time();
	} else {
		if ( isset($listing_info['completed_on']) ) {
			unset($listing_info['completed_on']);
		}
	}

	if ( update_post_meta( $listing_id, 'db_order_info', $listing_info ) ) {
		$db_listing = array( 'ID' => $listing_id );
		if ( $listing_status == 'Processing' || $listing_status == 'Pending' || $listing_status == 'Refunded' ) {
			$db_listing['post_status'] = 'pending';
		} else if ( $listing_status == 'Completed' ) {
			$db_listing['post_status'] = 'publish';
		}
		wp_update_post( $db_listing );

		echo '{"save_response": "0", "listing_status": "'.$listing_status.'"}';
	} else {
		echo '{"save_response": "failed"}';
	}

	die(0);
}
add_action( 'wp_ajax_db_change_status', 'db_change_status_func' );

function db_body_classes($classes) {

	if ( is_page_template('template-listing_search.php') ) {
		$main_settings = get_option( 'db_main_settings');

		if ( $main_settings['search_position'] == 'bottom' || isset($_GET['mapontop']) ) {
			$classes[] = 'db-bottom-search';
		}
	}

	return $classes;
}
add_filter('body_class', 'db_body_classes');

function db_upload_images_func() {

	require_once( ABSPATH . 'wp-admin/includes/image.php' );
	require_once( ABSPATH . 'wp-admin/includes/file.php' );
	require_once( ABSPATH . 'wp-admin/includes/media.php' );

	$attachment_id = media_handle_upload( 'file', '0' );
	
	if ( !is_wp_error( $attachment_id ) ) {
		echo '{"save_status": "true", "save_msg": "File successfully uploaded", "attachment_id": "'.$attachment_id.'"}';
	} else {
		echo '{"save_status": "false", "save_msg": "Sorry, there was an error uploading your file"}';
	}

	die(0);
}
add_action( 'wp_ajax_db_upload_images', 'db_upload_images_func' );
add_action( 'wp_ajax_nopriv_db_upload_images', 'db_upload_images_func' );

function db_search_marker_window() {
	$output = '';
	$marker_id = ( isset($_POST['marker_id']) ? sanitize_text_field($_POST['marker_id']) : '' );

	if ( $marker_id == '' ) {
		die(0);
	}

	$listing_ratings = get_post_meta( $marker_id, 'directory_post_likes', true);
	if ( $listing_ratings != '' ) {
		$liked = $listing_ratings;
	} else {
		$liked = array();
	}

	$listing_phone = get_post_meta($marker_id, 'listingphone', true);
	$listing_address = get_post_meta($marker_id, 'listing_address', true);
	$listing_category = get_the_terms($marker_id, 'listing_category');
	$img = wp_get_attachment_image_src( get_post_thumbnail_id($marker_id), 'medium_large' );

	$output .= '<div class="dt-featured-listings-item">';
		$output .= '<div class="dt-featured-listings-item-inner">';
			$output .= '<div class="dt-featured-listings-image">';
				$output .= '<a href="'.get_the_permalink($marker_id).'" class="dt-featured-item-image" '.(isset($img['0'])?'style="background: url('.$img['0'].')"':'').'></a>';
				$output .= '<div class="dt-featured-image-overlay"></div>';
				$output .= '<span class="dt-featured-listings-image-note">'.__('Featured', 'directory-builder').'</span>';
				$output .= '<div class="dt-featured-listings-image-meta">';
					if ( isset($listing_phone) && $listing_phone != '' ) {
						$output .= '<span class="dt-featured-listings-phone"><img src="'.DIRECTORY_PUBLIC.'images/phone.svg">'.$listing_phone.'</span>';
					}
					if ( isset($listing_address) && $listing_address != '' ) {
						$output .= '<span class="dt-featured-listings-address"><img src="'.DIRECTORY_PUBLIC.'images/location.svg">'.$listing_address.'</span>';
					}
				$output .= '</div>';
			$output .= '</div>';
			$output .= '<div class="dt-featured-listings-data">';
				$output .= '<a href="'.get_the_permalink($marker_id).'" class="dt-featured-listings-title">'.get_the_title($marker_id).'</a>';
				$output .= '<p class="dt-featured-listings-description">'.(get_the_excerpt($marker_id)!=''?get_the_excerpt($marker_id):strip_shortcodes(strip_tags(get_post_field('post_content', $marker_id)))).'</p>';
				$output .= '<div class="dt-featured-listings-meta clearfix">';
					if ( isset($listing_category['0']) ) {
						$cat_meta = get_option( "listing_category_".$listing_category['0']->term_id);
						$tag_color = (isset($cat_meta['tag-category-color'])?$cat_meta['tag-category-color']:'#555');
						$output .= '
						<a href="'.get_permalink($main_settings['search_page_id']).'?search_category='.$listing_category['0']->term_id.'" class="dt-featured-listings-category '.$listing_category['0']->slug.'" style="color: '.$tag_color.'"><style type="text/css">.dt-featured-listings-category.'.$listing_category['0']->slug.':before { border-color: '.$tag_color.'; }</style>'.$listing_category['0']->name.'</a>';
					}
					$ratings = get_post_meta( $marker_id, 'listing_ratings', true);

					if ( $ratings == '' ) {
						$rating_stars = '<img src="'.DIRECTORY_PUBLIC.'images/star-empty.svg"><img src="'.DIRECTORY_PUBLIC.'images/star-empty.svg"><img src="'.DIRECTORY_PUBLIC.'images/star-empty.svg"><img src="'.DIRECTORY_PUBLIC.'images/star-empty.svg"><img src="'.DIRECTORY_PUBLIC.'images/star-empty.svg">';
						$listing_rating = 0;
					} else {
						$listing_rating = 0;
						$valid_ratings = 0;
						foreach ($ratings as $rating_value) {
							if ( $rating_value != null ) {
								$listing_rating += $rating_value;
								$valid_ratings++;
							}
						}
	
						$listing_rating = round(($listing_rating/$valid_ratings), 0, PHP_ROUND_HALF_DOWN);
						$rating_stars = '';
						for ($i=0; $i < $listing_rating; $i++) { 
							$rating_stars .= '<img src="'.DIRECTORY_PUBLIC.'images/star-colored.svg">';
						}
						if ( $listing_rating < 5 ) {
							for ($i=0; $i < 5-$listing_rating; $i++) { 
								$rating_stars .= '<img src="'.DIRECTORY_PUBLIC.'images/star-empty.svg">';
							}
						}
					}

					if ( !isset($_COOKIE['dt-data']) ) {
						$can_rate = true;
					} else {
						$rated_listings = json_decode(stripslashes($_COOKIE['dt-data']));
						if ( !in_array($marker_id, $rated_listings) ) {
							$can_rate = true;
						} else {
							$can_rate = false;
						}
					}

					$output .= '<span class="dt-featured-listings-rating'.(!$can_rate?' rated':'').'" data-original="'.$listing_rating.'" data-id="'.$marker_id.'">'.$rating_stars.'</span>';
				$output .= '</div>';
			$output .= '</div>';
		$output .= '</div>';
	$output .= '</div>';

	echo $output;

	die(0);
}
add_action( 'wp_ajax_db_marker_window', 'db_search_marker_window' );
add_action( 'wp_ajax_nopriv_db_marker_window', 'db_search_marker_window' );

function db_featured_status_func() {
	if ( !current_user_can('manage_options') ) die(0);

	global $wpdb;
	$listing_id = ( isset($_POST['listing_id']) ? intval($_POST['listing_id']) : '' );
	$featured_status = ( isset($_POST['featured_status']) ? sanitize_text_field($_POST['featured_status']) : '' );
	
	$featured_listings = get_option('db_sticky_listings', array());
	$featured_changed = false;

	if ( $featured_status == 'No' ) {
		if( ($key = array_search($listing_id, $featured_listings)) !== false ) {
			unset($featured_listings[$key]);
			$featured_changed = true;
		}
	} else if ( $featured_status == 'Yes' ) {
		if ( array_search($listing_id, $featured_listings) === false ) {
			$featured_listings[] = $listing_id;
			$featured_changed = true;
		}
	}
	
	if ( $featured_changed ) {
		update_option('db_sticky_listings', $featured_listings);
		echo '{"save_response": "0"}';
	} else {
		echo '{"save_response": "failed"}';
	}

	die(0);
}
add_action( 'wp_ajax_db_featured_status', 'db_featured_status_func' );

function db_do_cities_autocomplete() {
	$city_value = ( isset($_POST['city_value']) ? esc_attr($_POST['city_value']) : '' );
	global $wpdb;
	$prepared_data = array();
	$cities = $wpdb->get_results('SELECT DISTINCT meta_value as city FROM ' . $wpdb->prefix . 'postmeta WHERE meta_key="listing_city" && meta_value LIKE "%' . $city_value . '%"');
	
	if ( !empty($cities) ) {
		foreach ($cities as $city_value) {
			$prepared_data[] =  $city_value->city;
		}

		echo json_encode( $prepared_data );
	} else {
		echo 'failed';
	}
	
	die(0);
}
add_action( 'wp_ajax_db_city_autocomplete', 'db_do_cities_autocomplete' );
add_action( 'wp_ajax_nopriv_db_city_autocomplete', 'db_do_cities_autocomplete' );

function db_do_address_autocomplete() {
	$address_value = ( isset($_POST['address_value']) ? esc_attr($_POST['address_value']) : '' );
	global $wpdb;
	$prepared_data = array();
	$addresses = $wpdb->get_results('SELECT DISTINCT meta_key, meta_value FROM ' . $wpdb->prefix . 'postmeta WHERE meta_key IN ("listing_address","listing_city","listing_neighborhood","listing_zip","listing_state","listing_country") && meta_value LIKE "%' . $address_value . '%"');

	if ( !empty($addresses) ) {
		$simplified_data = array();
		foreach ($addresses as $address_data) {
			if ( $address_data->meta_key != 'listing_address' ) {
				$simplified_data[] = $address_data->meta_value;
			} else {
				$exploded_address = explode(', ', $address_data->meta_value);
				if ( strpos(strtolower($exploded_address['0']), strtolower($address_value)) !== false ) {
					$simplified_data[] = $exploded_address['0'];
				}
			}
		}

		echo json_encode( array_unique( $simplified_data ) );
	} else {
		echo 'failed';
	}
	
	die(0);
}
add_action( 'wp_ajax_db_address_autocomplete', 'db_do_address_autocomplete' );
add_action( 'wp_ajax_nopriv_db_address_autocomplete', 'db_do_address_autocomplete' );

function db_setup_vc_modules() {
	// Extend Visual Composer
	if ( defined('WPB_VC_VERSION') ) {
		vc_map( array(
			"name" => __("Directory builder search", "directory-builder" ),
			"base" => "directory_listings",
			"class" => "",
			"icon" => "icon-wpb-ui-gap-content",
			"category" => __( "by Directory builder", "directory-builder" ),
			"show_settings_on_create" => false
		));

		vc_map( array(
			"name" => __("Directory builder add listing", "directory-builder" ),
			"base" => "directory_add_listing",
			"class" => "",
			"icon" => "icon-wpb-ui-gap-content",
			"category" => __( "by Directory builder", "directory-builder" ),
			"show_settings_on_create" => false
		));

		vc_map( array(
			"name" => __("Directory builder author dashboard", "directory-builder" ),
			"base" => "directory_account",
			"class" => "",
			"icon" => "icon-wpb-ui-gap-content",
			"category" => __( "by Directory builder", "directory-builder" ),
			"show_settings_on_create" => false
		));

		vc_map( array(
			"name" => __("Directory builder login", "directory-builder" ),
			"base" => "directory_login",
			"class" => "",
			"icon" => "icon-wpb-ui-gap-content",
			"category" => __( "by Directory builder", "directory-builder" ),
			"show_settings_on_create" => false
		));

		vc_map( array(
			"name" => __("Directory builder register", "directory-builder" ),
			"base" => "directory_register",
			"class" => "",
			"icon" => "icon-wpb-ui-gap-content",
			"category" => __( "by Directory builder", "directory-builder" ),
			"show_settings_on_create" => false
		));
	}	
}
add_action('after_setup_theme', 'db_setup_vc_modules');